@@ -15,6 +15,7 @@
 #include "shared/source/helpers/common_types.h"
 #include "shared/source/helpers/definitions/command_encoder_args.h"
 #include "shared/source/helpers/heap_base_address_model.h"
+#include "shared/source/memory_manager/graphics_allocation.h"
 #include "shared/source/memory_manager/prefetch_manager.h"
 #include "shared/source/unified_memory/unified_memory.h"
 #include "shared/source/utilities/stackvec.h"
@@ -132,12 +133,19 @@ struct CommandList : _ze_command_list_handle_t {
                                                         const ze_group_count_t groupCounts,
                                                         const ze_group_size_t groupSizes,
 
-                                                        const void **pArguments,
+                                                        void **pArguments,
                                                         const void *pNext,
                                                         ze_event_handle_t hSignalEvent,
                                                         uint32_t numWaitEvents,
                                                         ze_event_handle_t *phWaitEvents) = 0;
 
+    virtual ze_result_t appendLaunchKernelWithParameters(ze_kernel_handle_t hKernel,
+                                                         const ze_group_count_t *pGroupCounts,
+                                                         const void *pNext,
+                                                         ze_event_handle_t hSignalEvent,
+                                                         uint32_t numWaitEvents,
+                                                         ze_event_handle_t *phWaitEvents) = 0;
+
     virtual ze_result_t appendMemAdvise(ze_device_handle_t hDevice, const void *ptr, size_t size,
                                         ze_memory_advice_t advice) = 0;
     virtual ze_result_t executeMemAdvise(ze_device_handle_t hDevice,
@@ -220,10 +228,23 @@ struct CommandList : _ze_command_list_handle_t {
                                         bool internalUsage, NEO::EngineGroupType engineGroupType,
                                         ze_result_t &resultValue);
 
+    static CommandList *createImmediate(uint32_t productFamily, Device *device,
+                                        const ze_command_queue_desc_t *desc,
+                                        bool internalUsage, NEO::EngineGroupType engineGroupType, NEO::CommandStreamReceiver *csr,
+                                        ze_result_t &resultValue);
+
     static CommandList *fromHandle(ze_command_list_handle_t handle) {
         return static_cast<CommandList *>(handle);
     }
 
+    static bool isExternalHostPtrAlloc(NEO::GraphicsAllocation *alloc) {
+        return alloc && alloc->getAllocationType() == NEO::AllocationType::externalHostPtr;
+    }
+
+    static ze_result_t setKernelState(Kernel *kernel, const ze_group_size_t groupSizes, void **arguments);
+    static ze_result_t cloneAppendKernelExtensions(const ze_base_desc_t *desc, void *&outPnext);
+    static void freeClonedAppendKernelExtensions(void *outPnext);
+
     inline ze_command_list_handle_t toHandle() { return this; }
 
     uint32_t getCommandListPerThreadScratchSize(uint32_t slotId) const {
@@ -463,6 +484,24 @@ struct CommandList : _ze_command_list_handle_t {
         this->isWalkerWithProfilingEnqueued = false;
         return retVal;
     }
+    uint32_t getFrontEndPatchListCount() const {
+        return frontEndPatchListCount;
+    }
+    size_t getTotalNoopSpace() const {
+        return totalNoopSpace;
+    }
+
+    void forceDisableInOrderWaits() { inOrderWaitsDisabled = true; }
+
+    ze_command_list_flags_t getCmdListFlags() const {
+        return flags;
+    }
+
+    virtual void setPatchingPreamble(bool value) {}
+
+    uint32_t getActiveScratchPatchElements() const {
+        return activeScratchPatchElements;
+    }
 
   protected:
     NEO::GraphicsAllocation *getAllocationFromHostPtrMap(const void *buffer, uint64_t bufferSize, bool copyOffload);
@@ -506,10 +545,12 @@ struct CommandList : _ze_command_list_handle_t {
     CommandQueue *cmdQImmediateCopyOffload = nullptr;
     Device *device = nullptr;
     NEO::ScratchSpaceController *usedScratchController = nullptr;
+    Graph *captureTarget = nullptr;
 
     size_t minimalSizeForBcsSplit = 4 * MemoryConstants::megaByte;
     size_t cmdListCurrentStartOffset = 0;
-    size_t maxFillPaternSizeForCopyEngine = 0;
+    size_t maxFillPatternSizeForCopyEngine = 0;
+    size_t totalNoopSpace = 0;
 
     uint32_t commandListPerThreadScratchSize[2]{};
 
@@ -525,6 +566,8 @@ struct CommandList : _ze_command_list_handle_t {
     uint32_t defaultMocsIndex = 0;
     int32_t defaultPipelinedThreadArbitrationPolicy = NEO::ThreadArbitrationPolicy::NotPresent;
     uint32_t maxLocalSubRegionSize = 0;
+    uint32_t frontEndPatchListCount = 0;
+    uint32_t activeScratchPatchElements = 0;
 
     bool isSyncModeQueue = false;
     bool isTbxMode = false;
@@ -563,8 +606,7 @@ struct CommandList : _ze_command_list_handle_t {
     bool closedCmdList = false;
     bool isWalkerWithProfilingEnqueued = false;
     bool shouldRegisterEnqueuedWalkerWithProfiling = false;
-
-    Graph *captureTarget = nullptr;
+    bool inOrderWaitsDisabled = false;
 };
 
 using CommandListAllocatorFn = CommandList *(*)(uint32_t);
