@@ -9,14 +9,17 @@
 
 #include "shared/source/command_container/implicit_scaling.h"
 #include "shared/source/command_stream/command_stream_receiver.h"
+#include "shared/source/execution_environment/execution_environment.h"
 #include "shared/source/execution_environment/root_device_environment.h"
 #include "shared/source/helpers/aligned_memory.h"
+#include "shared/source/helpers/driver_model_type.h"
 #include "shared/source/helpers/gfx_core_helper.h"
 #include "shared/source/helpers/ptr_math.h"
 #include "shared/source/memory_manager/allocation_properties.h"
 #include "shared/source/memory_manager/memory_manager.h"
 #include "shared/source/memory_manager/memory_operations_handler.h"
 #include "shared/source/memory_manager/unified_memory_manager.h"
+#include "shared/source/os_interface/os_interface.h"
 #include "shared/source/utilities/cpu_info.h"
 
 #include "level_zero/core/source/cmdlist/cmdlist.h"
@@ -31,6 +34,8 @@
 #include "level_zero/core/source/module/module.h"
 #include "level_zero/driver_experimental/zex_memory.h"
 
+#include <string.h>
+
 namespace NEO {
 enum class AtomicAccessMode : uint32_t;
 } // namespace NEO
@@ -75,15 +80,15 @@ ContextImp::ContextImp(DriverHandle *driverHandle) {
     }
     contextSettings.enableSvmHeapReservation = platformSupportSvmHeapReservation;
 
-    bool pidfdOrSocket = true;
+    bool useOpaqueHandle = true;
     for (auto &device : this->driverHandle->devices) {
         auto &productHelper = device->getNEODevice()->getProductHelper();
         if (!productHelper.isPidFdOrSocketForIpcSupported()) {
-            pidfdOrSocket = false;
+            useOpaqueHandle = false;
             break;
         }
     }
-    contextSettings.enablePidfdOrSockets = pidfdOrSocket;
+    contextSettings.enablePidfdOrSockets = useOpaqueHandle;
 }
 
 ContextImp::~ContextImp() {
@@ -135,6 +140,7 @@ ze_result_t ContextImp::allocHostMem(const ze_host_mem_alloc_desc_t *hostDesc,
             *ptr = getMemHandlePtr(this->devices.begin()->second,
                                    lookupTable.sharedHandleType.fd,
                                    NEO::AllocationType::bufferHostMemory,
+                                   0u,
                                    flags);
             if (nullptr == *ptr) {
                 return ZE_RESULT_ERROR_INVALID_ARGUMENT;
@@ -143,7 +149,7 @@ ze_result_t ContextImp::allocHostMem(const ze_host_mem_alloc_desc_t *hostDesc,
             UNRECOVERABLE_IF(!lookupTable.sharedHandleType.isNTHandle);
             *ptr = this->driverHandle->importNTHandle(this->devices.begin()->second,
                                                       lookupTable.sharedHandleType.ntHandle,
-                                                      NEO::AllocationType::bufferHostMemory);
+                                                      NEO::AllocationType::bufferHostMemory, 0);
             if (*ptr == nullptr) {
                 return ZE_RESULT_ERROR_INVALID_ARGUMENT;
             }
@@ -266,6 +272,7 @@ ze_result_t ContextImp::allocDeviceMem(ze_device_handle_t hDevice,
             *ptr = getMemHandlePtr(hDevice,
                                    lookupTable.sharedHandleType.fd,
                                    NEO::AllocationType::buffer,
+                                   0u,
                                    flags);
             if (nullptr == *ptr) {
                 return ZE_RESULT_ERROR_INVALID_ARGUMENT;
@@ -274,7 +281,8 @@ ze_result_t ContextImp::allocDeviceMem(ze_device_handle_t hDevice,
             UNRECOVERABLE_IF(!lookupTable.sharedHandleType.isNTHandle);
             *ptr = this->driverHandle->importNTHandle(hDevice,
                                                       lookupTable.sharedHandleType.ntHandle,
-                                                      NEO::AllocationType::buffer);
+                                                      NEO::AllocationType::buffer,
+                                                      0);
             if (*ptr == nullptr) {
                 return ZE_RESULT_ERROR_INVALID_ARGUMENT;
             }
@@ -289,7 +297,12 @@ ze_result_t ContextImp::allocDeviceMem(ze_device_handle_t hDevice,
 
     deviceBitfields[rootDeviceIndex] = neoDevice->getDeviceBitfield();
     NEO::SVMAllocsManager::UnifiedMemoryProperties unifiedMemoryProperties(InternalMemoryType::deviceUnifiedMemory, alignment, this->driverHandle->rootDeviceIndices, deviceBitfields);
-    unifiedMemoryProperties.allocationFlags.flags.shareable = isShareableMemory(deviceMemDesc->pNext, static_cast<uint32_t>(lookupTable.exportMemory), neoDevice);
+    if (NEO::debugManager.flags.EnableShareableWithoutNTHandle.get()) {
+        unifiedMemoryProperties.allocationFlags.flags.shareableWithoutNTHandle = 1;
+    }
+    auto &productHelper = neoDevice->getProductHelper();
+    unifiedMemoryProperties.allocationFlags.flags.shareableWithoutNTHandle &= productHelper.canShareMemoryWithoutNTHandle();
+    unifiedMemoryProperties.allocationFlags.flags.shareable = isShareableMemory(deviceMemDesc->pNext, static_cast<uint32_t>(lookupTable.exportMemory), neoDevice, unifiedMemoryProperties.allocationFlags.flags.shareableWithoutNTHandle);
     unifiedMemoryProperties.device = neoDevice;
     unifiedMemoryProperties.allocationFlags.flags.compressedHint = isAllocationSuitableForCompression(lookupTable, *device, size);
 
@@ -298,7 +311,6 @@ ze_result_t ContextImp::allocDeviceMem(ze_device_handle_t hDevice,
     }
 
     if (lookupTable.rayTracingMemory == true) {
-        auto &productHelper = neoDevice->getProductHelper();
         unifiedMemoryProperties.allocationFlags.flags.resource48Bit = productHelper.is48bResourceNeededForRayTracing();
     }
 
@@ -741,9 +753,15 @@ ze_result_t ContextImp::getIpcHandleFromFd(uint64_t handle, ze_ipc_mem_handle_t
     auto lock = this->driverHandle->lockIPCHandleMap();
     ipcHandleIterator = this->driverHandle->getIPCHandleMap().find(handle);
     if (ipcHandleIterator != this->driverHandle->getIPCHandleMap().end()) {
-        using IpcDataT = IpcMemoryData;
-        IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(pIpcHandle->data);
-        ipcData = ipcHandleIterator->second->ipcData;
+        if (ipcHandleIterator->second->opaqueIpcHandle) {
+            using IpcDataT = IpcOpaqueMemoryData;
+            IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(pIpcHandle->data);
+            ipcData = ipcHandleIterator->second->opaqueData;
+        } else {
+            using IpcDataT = IpcMemoryData;
+            IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(pIpcHandle->data);
+            ipcData = ipcHandleIterator->second->ipcData;
+        }
     } else {
         return ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY;
     }
@@ -751,11 +769,23 @@ ze_result_t ContextImp::getIpcHandleFromFd(uint64_t handle, ze_ipc_mem_handle_t
 }
 
 ze_result_t ContextImp::getFdFromIpcHandle(ze_ipc_mem_handle_t ipcHandle, uint64_t *pHandle) {
-    using IpcDataT = IpcMemoryData;
-    IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(ipcHandle.data);
+    IpcHandleType handleType = IpcHandleType::maxHandle;
+    bool useOpaqueHandle = isOpaqueHandleSupported(&handleType);
+    uint64_t handle = 0;
+    if (useOpaqueHandle && handleType == IpcHandleType::fdHandle) {
+        using IpcDataOpaqueT = IpcOpaqueMemoryData;
+        IpcDataOpaqueT &ipcData = *reinterpret_cast<IpcDataOpaqueT *>(ipcHandle.data);
+        memcpy(&handle, &ipcData.handle.fd, sizeof(ipcData.handle.fd));
+    } else if (!useOpaqueHandle) {
+        using IpcDataT = IpcMemoryData;
+        IpcDataT &ipcData = *reinterpret_cast<IpcDataT *>(ipcHandle.data);
+        memcpy(&handle, &ipcData.handle, sizeof(ipcData.handle));
+    } else {
+        return ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY;
+    }
     std::map<uint64_t, IpcHandleTracking *>::iterator ipcHandleIterator;
     auto lock = this->driverHandle->lockIPCHandleMap();
-    ipcHandleIterator = this->driverHandle->getIPCHandleMap().find(ipcData.handle);
+    ipcHandleIterator = this->driverHandle->getIPCHandleMap().find(handle);
     if (ipcHandleIterator != this->driverHandle->getIPCHandleMap().end()) {
         *pHandle = ipcHandleIterator->first;
     } else {
@@ -799,7 +829,8 @@ ze_result_t ContextImp::getIpcMemHandlesImpl(const void *ptr,
         ipcType = InternalIpcMemoryType::hostUnifiedMemory;
     }
 
-    bool pidfdOrSocket = contextSettings.enablePidfdOrSockets;
+    IpcHandleType handleType = IpcHandleType::maxHandle;
+    bool useOpaqueHandle = isOpaqueHandleSupported(&handleType);
     uint32_t loopCount = numIpcHandles ? *numIpcHandles : 1u;
     for (uint32_t i = 0u; i < loopCount; i++) {
         uint64_t handle = 0;
@@ -810,12 +841,12 @@ ze_result_t ContextImp::getIpcMemHandlesImpl(const void *ptr,
 
         memoryManager->registerIpcExportedAllocation(alloc);
 
-        if (pidfdOrSocket) {
+        if (useOpaqueHandle) {
             IpcOpaqueMemoryData &ipcData = *reinterpret_cast<IpcOpaqueMemoryData *>(pIpcHandles[i].data);
-            setIPCHandleData<IpcOpaqueMemoryData>(alloc, handle, ipcData, reinterpret_cast<uint64_t>(ptr), static_cast<uint8_t>(ipcType), usmPool);
+            setIPCHandleData<IpcOpaqueMemoryData>(alloc, handle, ipcData, reinterpret_cast<uint64_t>(ptr), static_cast<uint8_t>(ipcType), usmPool, handleType);
         } else {
             IpcMemoryData &ipcData = *reinterpret_cast<IpcMemoryData *>(pIpcHandles[i].data);
-            setIPCHandleData<IpcMemoryData>(alloc, handle, ipcData, reinterpret_cast<uint64_t>(ptr), static_cast<uint8_t>(ipcType), usmPool);
+            setIPCHandleData<IpcMemoryData>(alloc, handle, ipcData, reinterpret_cast<uint64_t>(ptr), static_cast<uint8_t>(ipcType), usmPool, handleType);
         }
     }
     return ZE_RESULT_SUCCESS;
@@ -837,11 +868,12 @@ ze_result_t ContextImp::openIpcMemHandle(ze_device_handle_t hDevice,
                                          const ze_ipc_mem_handle_t &pIpcHandle,
                                          ze_ipc_memory_flags_t flags,
                                          void **ptr) {
-    using IpcDataT = IpcMemoryData;
-    const IpcDataT &ipcData = *reinterpret_cast<const IpcDataT *>(pIpcHandle.data);
+    uint64_t handle;
+    uint8_t type;
+    unsigned int processId;
+    uint64_t poolOffset;
 
-    uint64_t handle = ipcData.handle;
-    uint8_t type = ipcData.type;
+    getDataFromIpcHandle(hDevice, pIpcHandle, handle, type, processId, poolOffset);
 
     NEO::AllocationType allocationType = NEO::AllocationType::unknown;
     if (type == static_cast<uint8_t>(InternalIpcMemoryType::deviceUnifiedMemory)) {
@@ -855,12 +887,13 @@ ze_result_t ContextImp::openIpcMemHandle(ze_device_handle_t hDevice,
     *ptr = getMemHandlePtr(hDevice,
                            handle,
                            allocationType,
+                           processId,
                            flags);
     if (nullptr == *ptr) {
         return ZE_RESULT_ERROR_INVALID_ARGUMENT;
     }
 
-    *ptr = ptrOffset(*ptr, ipcData.poolOffset);
+    *ptr = ptrOffset(*ptr, poolOffset);
 
     return ZE_RESULT_SUCCESS;
 }
@@ -873,12 +906,15 @@ ze_result_t ContextImp::openIpcMemHandles(ze_device_handle_t hDevice,
     std::vector<NEO::osHandle> handles;
     handles.reserve(numIpcHandles);
 
-    using IpcDataT = IpcMemoryData;
     for (uint32_t i = 0; i < numIpcHandles; i++) {
-        const IpcDataT &ipcData = *reinterpret_cast<const IpcDataT *>(pIpcHandles[i].data);
-        uint64_t handle = ipcData.handle;
+        uint64_t handle;
+        uint8_t type;
+        unsigned int processId;
+        [[maybe_unused]] uint64_t poolOffset;
 
-        if (ipcData.type != static_cast<uint8_t>(InternalIpcMemoryType::deviceUnifiedMemory)) {
+        getDataFromIpcHandle(hDevice, pIpcHandles[i], handle, type, processId, poolOffset);
+
+        if (type != static_cast<uint8_t>(InternalIpcMemoryType::deviceUnifiedMemory)) {
             return ZE_RESULT_ERROR_INVALID_ARGUMENT;
         }
 
