@@ -61,9 +61,9 @@ struct BcsSplit {
         Events(BcsSplit &bcsSplit) : bcsSplit(bcsSplit) {}
     } events;
 
-    std::vector<CommandQueue *> cmdQs;
-    std::vector<CommandQueue *> h2dCmdQs;
-    std::vector<CommandQueue *> d2hCmdQs;
+    std::vector<CommandList *> cmdLists;
+    std::vector<CommandList *> h2dCmdLists;
+    std::vector<CommandList *> d2hCmdLists;
 
     template <GFXCORE_FAMILY gfxCoreFamily, typename T, typename K>
     ze_result_t appendSplitCall(CommandListCoreFamilyImmediate<gfxCoreFamily> *cmdList,
@@ -76,9 +76,9 @@ struct BcsSplit {
                                 bool performMigration,
                                 bool hasRelaxedOrderingDependencies,
                                 NEO::TransferDirection direction,
-                                std::function<ze_result_t(T, K, size_t, ze_event_handle_t)> appendCall) {
+                                size_t estimatedCmdBufferSize,
+                                std::function<ze_result_t(CommandListCoreFamilyImmediate<gfxCoreFamily> *, T, K, size_t, ze_event_handle_t)> appendCall) {
         ze_result_t result = ZE_RESULT_SUCCESS;
-        const bool hasStallingCmds = !hasRelaxedOrderingDependencies;
 
         auto markerEventIndexRet = this->events.obtainForSplit(Context::fromHandle(cmdList->getCmdListContext()), MemoryConstants::pageSize64k / sizeof(typename CommandListCoreFamilyImmediate<gfxCoreFamily>::GfxFamily::TimestampPacketType));
         if (!markerEventIndexRet.has_value()) {
@@ -92,10 +92,10 @@ struct BcsSplit {
             cmdList->appendSignalEvent(this->events.barrier[markerEventIndex]->toHandle(), false);
         }
 
-        auto subcopyEventIndex = markerEventIndex * this->cmdQs.size();
-        StackVec<ze_event_handle_t, 4> eventHandles;
+        auto subcopyEventIndex = markerEventIndex * this->cmdLists.size();
+        StackVec<ze_event_handle_t, 16> eventHandles;
 
-        auto &cmdQsForSplit = this->getCmdQsForSplit(direction);
+        auto &cmdListsForSplit = this->getCmdListsForSplit(direction);
 
         auto signalEvent = Event::fromHandle(hSignalEvent);
 
@@ -106,17 +106,25 @@ struct BcsSplit {
         const auto aggregatedEventsMode = this->events.aggregatedEventsMode;
 
         auto totalSize = size;
-        auto engineCount = cmdQsForSplit.size();
-        for (size_t i = 0; i < cmdQsForSplit.size(); i++) {
+        auto engineCount = cmdListsForSplit.size();
+        for (size_t i = 0; i < cmdListsForSplit.size(); i++) {
+            auto subCmdList = static_cast<CommandListCoreFamilyImmediate<gfxCoreFamily> *>(cmdListsForSplit[i]);
+
+            subCmdList->checkAvailableSpace(numWaitEvents, hasRelaxedOrderingDependencies, estimatedCmdBufferSize, false);
+
             if (barrierRequired) {
                 auto barrierEventHandle = this->events.barrier[markerEventIndex]->toHandle();
-                cmdList->addEventsToCmdList(1u, &barrierEventHandle, nullptr, hasRelaxedOrderingDependencies, false, true, false, false);
+                subCmdList->addEventsToCmdList(1u, &barrierEventHandle, nullptr, hasRelaxedOrderingDependencies, false, true, false, false);
             }
 
-            cmdList->addEventsToCmdList(numWaitEvents, phWaitEvents, nullptr, hasRelaxedOrderingDependencies, false, true, false, false);
+            if (cmdList->hasInOrderDependencies()) {
+                auto &inOrderExecInfo = cmdList->getInOrderExecInfo();
+                subCmdList->appendWaitOnInOrderDependency(inOrderExecInfo, nullptr, inOrderExecInfo->getCounterValue(), inOrderExecInfo->getAllocationOffset(), hasRelaxedOrderingDependencies, false, false, false, false);
+            }
+            subCmdList->addEventsToCmdList(numWaitEvents, phWaitEvents, nullptr, hasRelaxedOrderingDependencies, false, false, false, false);
 
             if (signalEvent && i == 0u) {
-                cmdList->appendEventForProfilingAllWalkers(signalEvent, nullptr, nullptr, true, true, false, true);
+                subCmdList->appendEventForProfilingAllWalkers(signalEvent, nullptr, nullptr, true, true, false, true);
             }
 
             auto localSize = totalSize / engineCount;
@@ -125,9 +133,8 @@ struct BcsSplit {
 
             auto copyEventIndex = aggregatedEventsMode ? markerEventIndex : subcopyEventIndex + i;
             auto eventHandle = this->events.subcopy[copyEventIndex]->toHandle();
-            result = appendCall(localDstPtr, localSrcPtr, localSize, eventHandle);
-
-            cmdList->executeCommandListImmediateWithFlushTaskImpl(performMigration, hasStallingCmds, hasRelaxedOrderingDependencies, NEO::AppendOperations::nonKernel, true, cmdQsForSplit[i], nullptr, nullptr);
+            result = appendCall(subCmdList, localDstPtr, localSrcPtr, localSize, eventHandle);
+            subCmdList->flushImmediate(result, true, !hasRelaxedOrderingDependencies, hasRelaxedOrderingDependencies, NEO::AppendOperations::nonKernel, false, nullptr, true, nullptr, nullptr);
 
             if ((aggregatedEventsMode && i == 0) || !aggregatedEventsMode) {
                 eventHandles.push_back(eventHandle);
@@ -137,7 +144,7 @@ struct BcsSplit {
             engineCount--;
 
             if (signalEvent) {
-                signalEvent->appendAdditionalCsr(static_cast<CommandQueueImp *>(cmdQsForSplit[i])->getCsr());
+                signalEvent->appendAdditionalCsr(subCmdList->getCsr(false));
             }
         }
 
@@ -162,9 +169,9 @@ struct BcsSplit {
         return result;
     }
 
-    bool setupDevice(NEO::CommandStreamReceiver *csr);
+    bool setupDevice(NEO::CommandStreamReceiver *csr, bool copyOffloadEnabled);
     void releaseResources();
-    std::vector<CommandQueue *> &getCmdQsForSplit(NEO::TransferDirection direction);
+    std::vector<CommandList *> &getCmdListsForSplit(NEO::TransferDirection direction);
     void setupEnginesMask(NEO::BcsSplitSettings &settings);
     bool setupQueues(const NEO::BcsSplitSettings &settings);
 
