@@ -96,7 +96,9 @@ struct DeviceImp : public Device, NEO::NonCopyableAndNonMovableClass {
     ze_result_t activateMetricGroupsDeferred(uint32_t count,
                                              zet_metric_group_handle_t *phMetricGroups) override;
 
-    DriverHandle *getDriverHandle() override;
+    DriverHandle *getDriverHandle() final {
+        return this->driverHandle;
+    }
     void setDriverHandle(DriverHandle *driverHandle) override;
     NEO::PreemptionMode getDevicePreemptionMode() const override;
     const NEO::DeviceInfo &getDeviceInfo() const override;
@@ -137,7 +139,6 @@ struct DeviceImp : public Device, NEO::NonCopyableAndNonMovableClass {
     uint32_t maxNumHwThreads = 0;
     uint32_t numSubDevices = 0;
     std::vector<Device *> subDevices;
-    std::unordered_map<uint32_t, bool> crossAccessEnabledDevices;
     DriverHandle *driverHandle = nullptr;
     FabricVertex *fabricVertex = nullptr;
     CommandList *pageFaultCommandList = nullptr;
@@ -181,9 +182,9 @@ struct DeviceImp : public Device, NEO::NonCopyableAndNonMovableClass {
     uint32_t getCopyEngineOrdinal() const;
     std::optional<uint32_t> tryGetCopyEngineOrdinal() const;
     void bcsSplitReleaseResources() override;
+    static bool queryPeerAccess(NEO::Device &device, NEO::Device &peerDevice, bool &canAccess);
 
   protected:
-    ze_result_t queryPeerAccess(DeviceImp *peerDevice);
     bool submitCopyForP2P(DeviceImp *hPeerDevice, ze_result_t &result);
     ze_result_t getGlobalTimestampsUsingSubmission(uint64_t *hostTimestamp, uint64_t *deviceTimestamp);
     ze_result_t getGlobalTimestampsUsingOsInterface(uint64_t *hostTimestamp, uint64_t *deviceTimestamp);
