@@ -89,6 +89,15 @@ void DriverImp::initialize(ze_result_t *result) {
         auto driverHandle = DriverHandle::create(std::move(devices), envVariables, result);
         if (driverHandle) {
             globalDriverHandles->push_back(driverHandle);
+
+            auto &devicesToExpose = static_cast<DriverHandleImp *>(driverHandle)->devicesToExpose;
+            std::vector<NEO::Device *> neoDeviceToExpose;
+            neoDeviceToExpose.reserve(devicesToExpose.size());
+            for (auto deviceToExpose : devicesToExpose) {
+                neoDeviceToExpose.push_back(Device::fromHandle(deviceToExpose)->getNEODevice());
+            }
+
+            NEO::Device::initializePeerAccessForDevices(DeviceImp::queryPeerAccess, neoDeviceToExpose);
         }
     }
 
