@@ -233,7 +233,6 @@ DriverHandleImp::~DriverHandleImp() {
         this->externalSemaphoreController.reset();
     }
 
-    this->stagingBufferManager.reset();
     if (memoryManager != nullptr) {
         memoryManager->peekExecutionEnvironment().prepareForCleanup();
         if (this->svmAllocsManager) {
@@ -248,6 +247,7 @@ DriverHandleImp::~DriverHandleImp() {
         }
         delete device;
     }
+    this->stagingBufferManager.reset();
 
     for (auto &fabricVertex : this->fabricVertices) {
         delete fabricVertex;
@@ -479,28 +479,20 @@ ze_result_t DriverHandleImp::getDevice(uint32_t *pCount, ze_device_handle_t *phD
 bool DriverHandleImp::findAllocationDataForRange(const void *buffer,
                                                  size_t size,
                                                  NEO::SvmAllocationData *&allocData) {
-
-    size_t offset = 0;
-    if (size > 0) {
-        offset = size - 1;
-    }
-
-    // Make sure the host buffer does not overlap any existing allocation
-    const char *baseAddress = reinterpret_cast<const char *>(buffer);
+    uint64_t baseAddress = castToUint64(buffer);
     NEO::SvmAllocationData *beginAllocData = svmAllocsManager->getSVMAlloc(buffer);
-    NEO::SvmAllocationData *endAllocData = offset == 0 ? beginAllocData : svmAllocsManager->getSVMAlloc(static_cast<const void *>(baseAddress + offset));
-
-    if (beginAllocData) {
-        allocData = beginAllocData;
-    } else {
-        allocData = endAllocData;
+    if (!beginAllocData) {
+        allocData = nullptr;
+        return false;
     }
-
-    // Return true if the whole range requested is covered by the same allocation
-    if (beginAllocData && endAllocData &&
-        (beginAllocData->gpuAllocations.getDefaultGraphicsAllocation() == endAllocData->gpuAllocations.getDefaultGraphicsAllocation())) {
+    // for size <= 1 we do not need to do bounds checking as pointer is confirmed to be valid
+    if (size <= 1 || (baseAddress + size <= beginAllocData->gpuAllocations.getDefaultGraphicsAllocation()->getGpuAddress() + beginAllocData->size)) {
+        allocData = beginAllocData;
         return true;
     }
+
+    // we have base allocation, but it doesn't cover whole size, it means we deal with virtual memory pointers, check if we have whole range covered
+
     bool allocationRangeCovered = false;
     // If memory accessed is part of a virtual reservation, then return the first allocation data within the range.
     auto allocDataVec = findAllocationsWithinRange(buffer, size, &allocationRangeCovered);
@@ -894,12 +886,13 @@ NEO::GraphicsAllocation *DriverHandleImp::getPeerAllocation(Device *device,
     return alloc;
 }
 
-void *DriverHandleImp::importNTHandle(ze_device_handle_t hDevice, void *handle, NEO::AllocationType allocationType) {
+void *DriverHandleImp::importNTHandle(ze_device_handle_t hDevice, void *handle, NEO::AllocationType allocationType, uint32_t parentProcessId) {
     auto neoDevice = Device::fromHandle(hDevice)->getNEODevice();
 
     bool isHostIpcAllocation = (allocationType == NEO::AllocationType::bufferHostMemory) ? true : false;
 
     NEO::MemoryManager::OsHandleData osHandleData{handle};
+    osHandleData.parentProcessId = parentProcessId;
     NEO::AllocationProperties properties{neoDevice->getRootDeviceIndex(),
                                          MemoryConstants::pageSize,
                                          allocationType,
@@ -925,23 +918,6 @@ void *DriverHandleImp::importNTHandle(ze_device_handle_t hDevice, void *handle,
     return reinterpret_cast<void *>(alloc->getGpuAddress());
 }
 
-ze_result_t DriverHandleImp::checkMemoryAccessFromDevice(Device *device, const void *ptr) {
-    auto allocation = svmAllocsManager->getSVMAlloc(ptr);
-    if (allocation == nullptr) {
-        return ZE_RESULT_ERROR_INVALID_ARGUMENT;
-    }
-
-    if (allocation->memoryType == InternalMemoryType::hostUnifiedMemory ||
-        allocation->memoryType == InternalMemoryType::sharedUnifiedMemory)
-        return ZE_RESULT_SUCCESS;
-
-    if (allocation->gpuAllocations.getGraphicsAllocation(device->getRootDeviceIndex()) != nullptr) {
-        return ZE_RESULT_SUCCESS;
-    }
-
-    return ZE_RESULT_ERROR_INVALID_ARGUMENT;
-}
-
 void DriverHandleImp::initializeVertexes() {
     for (auto &device : this->devices) {
         auto deviceImpl = static_cast<DeviceImp *>(device);
