@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -9,7 +9,7 @@
 #include "shared/source/gen12lp/hw_info_rkl.h"
 
 #include "level_zero/core/source/cmdqueue/cmdqueue_hw.inl"
-#include "level_zero/core/source/cmdqueue/cmdqueue_hw_skl_to_tgllp.inl"
+#include "level_zero/core/source/cmdqueue/cmdqueue_hw_gen12lp.inl"
 
 namespace L0 {
 template struct CommandQueueHw<IGFX_GEN12LP_CORE>;
