@@ -72,7 +72,7 @@ KernelImmutableData::~KernelImmutableData() {
 }
 
 ze_result_t KernelImmutableData::initialize(NEO::KernelInfo *kernelInfo, Device *device, uint32_t computeUnitsUsedForSratch,
-                                            NEO::GraphicsAllocation *globalConstBuffer, NEO::GraphicsAllocation *globalVarBuffer,
+                                            NEO::SharedPoolAllocation *globalConstBuffer, NEO::SharedPoolAllocation *globalVarBuffer,
                                             bool internalKernel) {
 
     UNRECOVERABLE_IF(kernelInfo == nullptr);
@@ -136,21 +136,22 @@ ze_result_t KernelImmutableData::initialize(NEO::KernelInfo *kernelInfo, Device
 
         patchWithImplicitSurface(crossThreadDataArrayRef, surfaceStateHeapArrayRef,
                                  static_cast<uintptr_t>(globalConstBuffer->getGpuAddressToPatch()),
-                                 *globalConstBuffer, kernelDescriptor->payloadMappings.implicitArgs.globalConstantsSurfaceAddress,
-                                 *neoDevice, deviceImp->isImplicitScalingCapable());
-        this->residencyContainer.push_back(globalConstBuffer);
+                                 *globalConstBuffer->getGraphicsAllocation(), globalConstBuffer->getGpuAddress(), globalConstBuffer->getSize(),
+                                 kernelDescriptor->payloadMappings.implicitArgs.globalConstantsSurfaceAddress, *neoDevice, deviceImp->isImplicitScalingCapable());
+        this->residencyContainer.push_back(globalConstBuffer->getGraphicsAllocation());
     } else if (nullptr != globalConstBuffer) {
-        this->residencyContainer.push_back(globalConstBuffer);
+        this->residencyContainer.push_back(globalConstBuffer->getGraphicsAllocation());
     }
 
     if (globalConstBuffer && NEO::isValidOffset(kernelDescriptor->payloadMappings.implicitArgs.globalConstantsSurfaceAddress.bindless)) {
-        if (!neoDevice->getMemoryManager()->allocateBindlessSlot(globalConstBuffer)) {
+        UNRECOVERABLE_IF(globalConstBuffer->getGraphicsAllocation()->getUnderlyingBufferSize() != globalConstBuffer->getSize());
+        if (!neoDevice->getMemoryManager()->allocateBindlessSlot(globalConstBuffer->getGraphicsAllocation())) {
             return ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY;
         }
-        auto &ssInHeap = globalConstBuffer->getBindlessInfo();
+        auto &ssInHeap = globalConstBuffer->getGraphicsAllocation()->getBindlessInfo();
 
         patchImplicitArgBindlessOffsetAndSetSurfaceState(crossThreadDataArrayRef, surfaceStateHeapArrayRef,
-                                                         globalConstBuffer, kernelDescriptor->payloadMappings.implicitArgs.globalConstantsSurfaceAddress,
+                                                         globalConstBuffer->getGraphicsAllocation(), kernelDescriptor->payloadMappings.implicitArgs.globalConstantsSurfaceAddress,
                                                          *neoDevice, deviceImp->isImplicitScalingCapable(), ssInHeap, kernelInfo->kernelDescriptor);
     }
 
@@ -159,38 +160,39 @@ ze_result_t KernelImmutableData::initialize(NEO::KernelInfo *kernelInfo, Device
 
         patchWithImplicitSurface(crossThreadDataArrayRef, surfaceStateHeapArrayRef,
                                  static_cast<uintptr_t>(globalVarBuffer->getGpuAddressToPatch()),
-                                 *globalVarBuffer, kernelDescriptor->payloadMappings.implicitArgs.globalVariablesSurfaceAddress,
-                                 *neoDevice, deviceImp->isImplicitScalingCapable());
-        this->residencyContainer.push_back(globalVarBuffer);
+                                 *globalVarBuffer->getGraphicsAllocation(), globalVarBuffer->getGpuAddress(), globalVarBuffer->getSize(),
+                                 kernelDescriptor->payloadMappings.implicitArgs.globalVariablesSurfaceAddress, *neoDevice, deviceImp->isImplicitScalingCapable());
+        this->residencyContainer.push_back(globalVarBuffer->getGraphicsAllocation());
     } else if (nullptr != globalVarBuffer) {
-        this->residencyContainer.push_back(globalVarBuffer);
+        this->residencyContainer.push_back(globalVarBuffer->getGraphicsAllocation());
     }
 
     if (globalVarBuffer && NEO::isValidOffset(kernelDescriptor->payloadMappings.implicitArgs.globalVariablesSurfaceAddress.bindless)) {
-        if (!neoDevice->getMemoryManager()->allocateBindlessSlot(globalVarBuffer)) {
+        UNRECOVERABLE_IF(globalVarBuffer->getGraphicsAllocation()->getUnderlyingBufferSize() != globalVarBuffer->getSize());
+        if (!neoDevice->getMemoryManager()->allocateBindlessSlot(globalVarBuffer->getGraphicsAllocation())) {
             return ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY;
         }
-        auto &ssInHeap = globalVarBuffer->getBindlessInfo();
+        auto &ssInHeap = globalVarBuffer->getGraphicsAllocation()->getBindlessInfo();
 
         patchImplicitArgBindlessOffsetAndSetSurfaceState(crossThreadDataArrayRef, surfaceStateHeapArrayRef,
-                                                         globalVarBuffer, kernelDescriptor->payloadMappings.implicitArgs.globalVariablesSurfaceAddress,
+                                                         globalVarBuffer->getGraphicsAllocation(), kernelDescriptor->payloadMappings.implicitArgs.globalVariablesSurfaceAddress,
                                                          *neoDevice, deviceImp->isImplicitScalingCapable(), ssInHeap, kernelInfo->kernelDescriptor);
     }
 
     return ZE_RESULT_SUCCESS;
 }
 
-void KernelImmutableData::createRelocatedDebugData(NEO::GraphicsAllocation *globalConstBuffer,
-                                                   NEO::GraphicsAllocation *globalVarBuffer) {
+void KernelImmutableData::createRelocatedDebugData(NEO::SharedPoolAllocation *globalConstBuffer,
+                                                   NEO::SharedPoolAllocation *globalVarBuffer) {
     NEO::Linker::SegmentInfo globalData;
     NEO::Linker::SegmentInfo constData;
     if (globalVarBuffer) {
         globalData.gpuAddress = globalVarBuffer->getGpuAddress();
-        globalData.segmentSize = globalVarBuffer->getUnderlyingBufferSize();
+        globalData.segmentSize = globalVarBuffer->getSize();
     }
     if (globalConstBuffer) {
         constData.gpuAddress = globalConstBuffer->getGpuAddress();
-        constData.segmentSize = globalConstBuffer->getUnderlyingBufferSize();
+        constData.segmentSize = globalConstBuffer->getSize();
     }
 
     if (kernelInfo->kernelDescriptor.external.debugData.get()) {
@@ -245,48 +247,70 @@ void KernelImmutableData::setIsaPerKernelAllocation(NEO::GraphicsAllocation *all
 
 KernelMutableState::KernelMutableState() : pImplicitArgs{nullptr}, pExtension{nullptr} {};
 
-KernelMutableState &KernelMutableState::operator=(const KernelMutableState &rhs) {
-    if (this == &rhs) {
-        return *this;
-    }
-    this->Params::operator=(rhs);
-
+KernelMutableState::KernelMutableState(const KernelMutableState &rhs) : Params{rhs} {
     pImplicitArgs = (rhs.pImplicitArgs) ? std::make_unique<NEO::ImplicitArgs>(*rhs.pImplicitArgs) : nullptr;
     pExtension = nullptr;
 
-    crossThreadDataSize = rhs.crossThreadDataSize;
-    if (crossThreadDataSize) {
-        crossThreadData = std::make_unique<uint8_t[]>(crossThreadDataSize);
-        std::memcpy(crossThreadData.get(), rhs.crossThreadData.get(), crossThreadDataSize);
-    }
-
-    surfaceStateHeapDataSize = rhs.surfaceStateHeapDataSize;
-    if (surfaceStateHeapDataSize) {
-        surfaceStateHeapData = std::make_unique<uint8_t[]>(surfaceStateHeapDataSize);
-        std::memcpy(surfaceStateHeapData.get(), rhs.surfaceStateHeapData.get(), surfaceStateHeapDataSize);
-    }
-
-    dynamicStateHeapDataSize = rhs.dynamicStateHeapDataSize;
-    if (dynamicStateHeapDataSize) {
-        dynamicStateHeapData = std::make_unique<uint8_t[]>(dynamicStateHeapDataSize);
-        std::memcpy(dynamicStateHeapData.get(), rhs.dynamicStateHeapData.get(), dynamicStateHeapDataSize);
-    }
+    crossThreadData = rhs.crossThreadData;
+    surfaceStateHeapData = rhs.surfaceStateHeapData;
+    dynamicStateHeapData = rhs.dynamicStateHeapData;
 
     if (rhs.perThreadDataSizeForWholeThreadGroup) {
         reservePerThreadDataForWholeThreadGroup(rhs.perThreadDataSizeForWholeThreadGroup);
         DEBUG_BREAK_IF(perThreadDataSizeForWholeThreadGroupAllocated < perThreadDataSizeForWholeThreadGroup);
         DEBUG_BREAK_IF(nullptr == rhs.perThreadDataForWholeThreadGroup);
+        DEBUG_BREAK_IF(nullptr == perThreadDataForWholeThreadGroup);
         std::memcpy(perThreadDataForWholeThreadGroup, rhs.perThreadDataForWholeThreadGroup, perThreadDataSizeForWholeThreadGroup);
         const size_t tailSize = perThreadDataSizeForWholeThreadGroupAllocated - perThreadDataSizeForWholeThreadGroup;
         std::memset(perThreadDataForWholeThreadGroup + perThreadDataSizeForWholeThreadGroup, 0x0, tailSize);
     }
+};
 
+KernelMutableState &KernelMutableState::operator=(const KernelMutableState &rhs) {
+    if (&rhs != this) {
+        KernelMutableState tmp{rhs};
+        swap(tmp);
+    }
     return *this;
 }
 
-KernelMutableState::KernelMutableState(KernelMutableState &&orig) = default;
+void KernelMutableState::swap(KernelMutableState &rhs) {
+    using std::swap;
+    swap(*static_cast<Params *>(this), static_cast<Params &>(rhs));
+    swap(this->pImplicitArgs, rhs.pImplicitArgs);
+    swap(this->pExtension, rhs.pExtension);
+    swap(this->crossThreadData, rhs.crossThreadData);
+    swap(this->surfaceStateHeapData, rhs.surfaceStateHeapData);
+    swap(this->dynamicStateHeapData, rhs.dynamicStateHeapData);
+    swap(this->perThreadDataForWholeThreadGroup, rhs.perThreadDataForWholeThreadGroup);
+    swap(this->perThreadDataSizeForWholeThreadGroup, rhs.perThreadDataSizeForWholeThreadGroup);
+    swap(this->perThreadDataSizeForWholeThreadGroupAllocated, rhs.perThreadDataSizeForWholeThreadGroupAllocated);
+}
 
-KernelMutableState &KernelMutableState::operator=(KernelMutableState &&rhs) = default;
+KernelMutableState::KernelMutableState(KernelMutableState &&orig) noexcept : Params{std::move(orig)} {
+    this->moveMembersFrom(std::move(orig));
+}
+
+KernelMutableState &KernelMutableState::operator=(KernelMutableState &&rhs) noexcept {
+    if (&rhs != this) {
+        static_cast<Params &>(*this) = static_cast<Params &&>(std::move(rhs));
+        this->moveMembersFrom(std::move(rhs));
+    }
+    return *this;
+}
+
+void KernelMutableState::moveMembersFrom(KernelMutableState &&orig) {
+    pImplicitArgs = std::move(orig.pImplicitArgs);
+    pExtension = std::move(orig.pExtension);
+
+    crossThreadData = std::move(orig.crossThreadData);
+    surfaceStateHeapData = std::move(orig.surfaceStateHeapData);
+    dynamicStateHeapData = std::move(orig.dynamicStateHeapData);
+
+    perThreadDataForWholeThreadGroup = std::exchange(orig.perThreadDataForWholeThreadGroup, nullptr);
+    perThreadDataSizeForWholeThreadGroup = std::exchange(orig.perThreadDataSizeForWholeThreadGroup, 0U);
+    perThreadDataSizeForWholeThreadGroupAllocated = std::exchange(orig.perThreadDataSizeForWholeThreadGroupAllocated, 0U);
+}
 
 void KernelMutableState::reservePerThreadDataForWholeThreadGroup(uint32_t sizeNeeded) {
     if (sizeNeeded > perThreadDataSizeForWholeThreadGroupAllocated) {
@@ -323,6 +347,11 @@ KernelImp::KernelImp(Module *module) : module(module) {
 }
 
 KernelImp::~KernelImp() {
+    /* Only original instance should release resources shared with clones */
+    if (nullptr != cloneOrigin) {
+        return;
+    }
+
     if (nullptr != privateMemoryGraphicsAllocation) {
         module->getDevice()->getNEODevice()->getMemoryManager()->freeGraphicsMemory(privateMemoryGraphicsAllocation);
     }
@@ -639,7 +668,7 @@ ze_result_t KernelImp::setArgImmediate(uint32_t argIndex, size_t argSize, const
             size_t maxBytesToCopy = argSize - element.sourceOffset;
             size_t bytesToCopy = std::min(static_cast<size_t>(element.size), maxBytesToCopy);
 
-            auto pDst = ptrOffset(state.crossThreadData.get(), element.offset);
+            auto pDst = &getCrossThreadDataSpan()[element.offset];
             if (argVal) {
                 auto pSrc = ptrOffset(argVal, element.sourceOffset);
                 memcpy_s(pDst, element.size, pSrc, bytesToCopy);
@@ -692,18 +721,18 @@ ze_result_t KernelImp::setArgRedescribedImage(uint32_t argIndex, ze_image_handle
             state.isBindlessOffsetSet[argIndex] = true;
         } else {
             state.usingSurfaceStateHeap[argIndex] = true;
-            auto ssPtr = ptrOffset(state.surfaceStateHeapData.get(), getSurfaceStateIndexForBindlessOffset(arg.bindless) * surfaceStateSize);
+            auto ssPtr = &getSurfaceStateHeapDataSpan()[getSurfaceStateIndexForBindlessOffset(arg.bindless) * surfaceStateSize];
             image->copySurfaceStateToSSH(ssPtr, 0u, bindlessSlot, false);
         }
     } else {
-        image->copySurfaceStateToSSH(state.surfaceStateHeapData.get(), arg.bindful, bindlessSlot, false);
+        image->copySurfaceStateToSSH(state.surfaceStateHeapData.data(), arg.bindful, bindlessSlot, false);
     }
     state.argumentsResidencyContainer[argIndex] = image->getAllocation();
 
     return ZE_RESULT_SUCCESS;
 }
 
-ze_result_t KernelImp::setArgBufferWithAlloc(uint32_t argIndex, uintptr_t argVal, NEO::GraphicsAllocation *allocation, NEO::SvmAllocationData *peerAllocData) {
+ze_result_t KernelImp::setArgBufferWithAlloc(uint32_t argIndex, uintptr_t argVal, NEO::GraphicsAllocation *allocation, NEO::SvmAllocationData *allocData) {
     const auto &arg = kernelImmData->getDescriptor().payloadMappings.explicitArgs[argIndex].as<NEO::ArgDescPointer>();
     const auto val = argVal;
     const int64_t bufferSize = static_cast<int64_t>(allocation->getUnderlyingBufferSize() - (ptrDiff(argVal, allocation->getGpuAddress())));
@@ -720,10 +749,8 @@ ze_result_t KernelImp::setArgBufferWithAlloc(uint32_t argIndex, uintptr_t argVal
 
         setBufferSurfaceState(argIndex, reinterpret_cast<void *>(val), allocation);
     }
-    NEO::SvmAllocationData *allocData = nullptr;
-    if (peerAllocData) {
-        allocData = peerAllocData;
-    } else {
+
+    if (!allocData) {
         allocData = this->module->getDevice()->getDriverHandle()->getSvmAllocsManager()->getSVMAlloc(reinterpret_cast<void *>(allocation->getGpuAddress()));
     }
     if (allocData) {
@@ -787,7 +814,7 @@ ze_result_t KernelImp::setArgBuffer(uint32_t argIndex, size_t argSize, const voi
         state.slmArgSizes[argIndex] = static_cast<uint32_t>(argSize);
         state.kernelArgInfos[argIndex] = KernelArgInfo{nullptr, 0, 0, false};
         UNRECOVERABLE_IF(NEO::isUndefinedOffset(currArg.as<NEO::ArgDescPointer>().slmOffset));
-        auto slmOffset = *reinterpret_cast<uint32_t *>(state.crossThreadData.get() + currArg.as<NEO::ArgDescPointer>().slmOffset);
+        auto slmOffset = *reinterpret_cast<uint32_t *>(&getCrossThreadDataSpan()[currArg.as<NEO::ArgDescPointer>().slmOffset]);
         state.slmArgOffsetValues[argIndex] = slmOffset;
         slmOffset += static_cast<uint32_t>(argSize);
         ++argIndex;
@@ -818,13 +845,15 @@ ze_result_t KernelImp::setArgBuffer(uint32_t argIndex, size_t argSize, const voi
     }
     const auto requestedAddress = *reinterpret_cast<void *const *>(argVal);
     uintptr_t gpuAddress = 0u;
-    NEO::GraphicsAllocation *alloc = driverHandle->getDriverSystemMemoryAllocation(requestedAddress,
-                                                                                   1u,
-                                                                                   module->getDevice()->getRootDeviceIndex(),
-                                                                                   &gpuAddress);
-    if (allocData == nullptr) {
+    NEO::GraphicsAllocation *alloc = nullptr;
+    if (allocData) {
+        gpuAddress = reinterpret_cast<uintptr_t>(requestedAddress);
+        alloc = allocData->gpuAllocations.getGraphicsAllocation(module->getDevice()->getRootDeviceIndex());
+    } else {
+        alloc = driverHandle->getDriverSystemMemoryAllocation(requestedAddress, 1u, module->getDevice()->getRootDeviceIndex(), &gpuAddress);
         allocData = svmAllocsManager->getSVMAlloc(requestedAddress);
     }
+
     NEO::SvmAllocationData *peerAllocData = nullptr;
     if (allocData && driverHandle->isRemoteResourceNeeded(requestedAddress, alloc, allocData, device)) {
 
@@ -854,7 +883,7 @@ ze_result_t KernelImp::setArgBuffer(uint32_t argIndex, size_t argSize, const voi
     const uint32_t allocId = allocData->getAllocId();
     state.kernelArgInfos[argIndex] = KernelArgInfo{requestedAddress, allocId, allocationsCounter, false};
 
-    return setArgBufferWithAlloc(argIndex, gpuAddress, alloc, peerAllocData);
+    return setArgBufferWithAlloc(argIndex, gpuAddress, alloc, peerAllocData ? peerAllocData : allocData);
 }
 
 ze_result_t KernelImp::setArgImage(uint32_t argIndex, size_t argSize, const void *argVal) {
@@ -896,11 +925,11 @@ ze_result_t KernelImp::setArgImage(uint32_t argIndex, size_t argSize, const void
             state.isBindlessOffsetSet[argIndex] = true;
         } else {
             state.usingSurfaceStateHeap[argIndex] = true;
-            auto ssPtr = ptrOffset(state.surfaceStateHeapData.get(), getSurfaceStateIndexForBindlessOffset(arg.bindless) * surfaceStateSize);
+            auto ssPtr = &getSurfaceStateHeapDataSpan()[getSurfaceStateIndexForBindlessOffset(arg.bindless) * surfaceStateSize];
             image->copySurfaceStateToSSH(ssPtr, 0u, NEO::BindlessImageSlot::image, isMediaBlockImage);
         }
     } else {
-        image->copySurfaceStateToSSH(state.surfaceStateHeapData.get(), arg.bindful, NEO::BindlessImageSlot::image, isMediaBlockImage);
+        image->copySurfaceStateToSSH(state.surfaceStateHeapData.data(), arg.bindful, NEO::BindlessImageSlot::image, isMediaBlockImage);
     }
 
     state.argumentsResidencyContainer[argIndex] = image->getAllocation();
@@ -951,14 +980,14 @@ ze_result_t KernelImp::setArgSampler(uint32_t argIndex, size_t argSize, const vo
     const auto &arg = kernelImmData->getDescriptor().payloadMappings.explicitArgs[argIndex].as<NEO::ArgDescSampler>();
     const auto sampler = Sampler::fromHandle(*static_cast<const ze_sampler_handle_t *>(argVal));
     if (NEO::isValidOffset(arg.bindful)) {
-        sampler->copySamplerStateToDSH(state.dynamicStateHeapData.get(), state.dynamicStateHeapDataSize, arg.bindful);
+        sampler->copySamplerStateToDSH(getDynamicStateHeapDataSpan(), arg.bindful);
     } else if (NEO::isValidOffset(arg.bindless)) {
         const auto offset = kernelImmData->getDescriptor().payloadMappings.samplerTable.tableOffset;
         auto &gfxCoreHelper = this->module->getDevice()->getNEODevice()->getRootDeviceEnvironmentRef().getHelper<NEO::GfxCoreHelper>();
         const auto stateSize = gfxCoreHelper.getSamplerStateSize();
         auto heapOffset = offset + static_cast<uint32_t>(stateSize) * arg.index;
 
-        sampler->copySamplerStateToDSH(state.dynamicStateHeapData.get(), state.dynamicStateHeapDataSize, heapOffset);
+        sampler->copySamplerStateToDSH(getDynamicStateHeapDataSpan(), heapOffset);
     }
     auto samplerDesc = sampler->getSamplerDesc();
 
@@ -1055,9 +1084,7 @@ NEO::GraphicsAllocation *KernelImp::allocatePrivateMemoryGraphicsAllocation() {
 void KernelImp::patchCrossthreadDataWithPrivateAllocation(NEO::GraphicsAllocation *privateAllocation) {
     auto device = module->getDevice();
 
-    ArrayRef<uint8_t> surfaceStateHeapArrayRef = ArrayRef<uint8_t>(this->state.surfaceStateHeapData.get(), this->state.surfaceStateHeapDataSize);
-
-    patchWithImplicitSurface(getCrossThreadDataSpan(), surfaceStateHeapArrayRef,
+    patchWithImplicitSurface(getCrossThreadDataSpan(), getSurfaceStateHeapDataSpan(),
                              static_cast<uintptr_t>(privateAllocation->getGpuAddressToPatch()),
                              *privateAllocation, kernelImmData->getDescriptor().payloadMappings.implicitArgs.privateMemoryAddress,
                              *device->getNEODevice(), device->isImplicitScalingCapable());
@@ -1081,11 +1108,11 @@ void KernelImp::setInlineSamplers() {
             auto samplerStateSize = gfxCoreHelper.getSamplerStateSize();
             uint32_t offset = inlineSampler.borderColorStateSize;
             offset += static_cast<uint32_t>(samplerStateSize) * samplerStateIndex;
-            sampler->copySamplerStateToDSH(state.dynamicStateHeapData.get(), state.dynamicStateHeapDataSize, offset);
+            sampler->copySamplerStateToDSH(getDynamicStateHeapDataSpan(), offset);
 
         } else {
 
-            sampler->copySamplerStateToDSH(state.dynamicStateHeapData.get(), state.dynamicStateHeapDataSize, inlineSampler.getSamplerBindfulOffset());
+            sampler->copySamplerStateToDSH(getDynamicStateHeapDataSpan(), inlineSampler.getSamplerBindfulOffset());
         }
     }
 }
@@ -1175,31 +1202,32 @@ ze_result_t KernelImp::initialize(const ze_kernel_desc_t *desc) {
     state.isBindlessOffsetSet.resize(this->state.kernelArgHandlers.size(), 0);
     state.usingSurfaceStateHeap.resize(this->state.kernelArgHandlers.size(), 0);
 
-    if (kernelImmData->getSurfaceStateHeapSize() > 0) {
-        this->state.surfaceStateHeapData.reset(new uint8_t[kernelImmData->getSurfaceStateHeapSize()]);
-        memcpy_s(this->state.surfaceStateHeapData.get(),
-                 kernelImmData->getSurfaceStateHeapSize(),
+    if (const auto surfaceStateHeapSize = kernelImmData->getSurfaceStateHeapSize();
+        surfaceStateHeapSize > 0U) {
+        this->state.surfaceStateHeapData.resize(surfaceStateHeapSize);
+        memcpy_s(this->state.surfaceStateHeapData.data(),
+                 surfaceStateHeapSize,
                  kernelImmData->getSurfaceStateHeapTemplate(),
-                 kernelImmData->getSurfaceStateHeapSize());
-        this->state.surfaceStateHeapDataSize = kernelImmData->getSurfaceStateHeapSize();
+                 surfaceStateHeapSize);
     }
 
-    if (kernelDescriptor.kernelAttributes.crossThreadDataSize != 0) {
-        this->state.crossThreadData.reset(new uint8_t[kernelDescriptor.kernelAttributes.crossThreadDataSize]);
-        memcpy_s(this->state.crossThreadData.get(),
-                 kernelDescriptor.kernelAttributes.crossThreadDataSize,
+    if (const auto crossThreadDataSize = kernelDescriptor.kernelAttributes.crossThreadDataSize;
+        crossThreadDataSize != 0) {
+        this->state.crossThreadData.resize(crossThreadDataSize);
+        memcpy_s(this->state.crossThreadData.data(),
+                 crossThreadDataSize,
                  kernelImmData->getCrossThreadDataTemplate(),
-                 kernelDescriptor.kernelAttributes.crossThreadDataSize);
-        this->state.crossThreadDataSize = kernelDescriptor.kernelAttributes.crossThreadDataSize;
+                 crossThreadDataSize);
     }
 
-    if (kernelImmData->getDynamicStateHeapDataSize() != 0) {
-        this->state.dynamicStateHeapData.reset(new uint8_t[kernelImmData->getDynamicStateHeapDataSize()]);
-        memcpy_s(this->state.dynamicStateHeapData.get(),
-                 kernelImmData->getDynamicStateHeapDataSize(),
+    if (const auto dynamicStateHeapSize = kernelImmData->getDynamicStateHeapDataSize();
+        dynamicStateHeapSize != 0) {
+        this->state.dynamicStateHeapData.clear();
+        this->state.dynamicStateHeapData.resize(dynamicStateHeapSize);
+        memcpy_s(this->state.dynamicStateHeapData.data(),
+                 dynamicStateHeapSize,
                  kernelImmData->getDynamicStateHeapTemplate(),
-                 kernelImmData->getDynamicStateHeapDataSize());
-        this->state.dynamicStateHeapDataSize = kernelImmData->getDynamicStateHeapDataSize();
+                 dynamicStateHeapSize);
     }
 
     if (kernelDescriptor.kernelAttributes.flags.requiresImplicitArgs) {
@@ -1298,6 +1326,43 @@ ze_result_t KernelImp::initialize(const ze_kernel_desc_t *desc) {
     return ZE_RESULT_SUCCESS;
 }
 
+std::unique_ptr<KernelImp> KernelImp::cloneWithStateOverride(const KernelMutableState *stateOverride) {
+    auto *device{static_cast<DeviceImp *>(this->module->getDevice())};
+    const auto productFamily = device->getNEODevice()->getHardwareInfo().platform.eProductFamily;
+
+    KernelAllocatorFn allocator = kernelFactory[productFamily];
+    auto clone = static_cast<KernelImp *>(allocator(module));
+    DEBUG_BREAK_IF(nullptr == clone);
+
+    clone->cloneOrigin = this;
+
+    // Kernel-specific members dynamically set in `initailize()` but shareable with clones
+    clone->kernelImmData = this->kernelImmData;
+    clone->devicePrintfKernelMutex = this->devicePrintfKernelMutex;
+    clone->privateMemoryGraphicsAllocation = this->privateMemoryGraphicsAllocation;
+
+    clone->printfBuffer = this->printfBuffer;
+    clone->surfaceStateAlignmentMask = this->surfaceStateAlignmentMask;
+    clone->surfaceStateAlignment = this->surfaceStateAlignment;
+
+    clone->implicitArgsVersion = this->implicitArgsVersion;
+    clone->walkerInlineDataSize = this->walkerInlineDataSize;
+
+    clone->maxWgCountPerTileCcs = this->maxWgCountPerTileCcs;
+    clone->maxWgCountPerTileRcs = this->maxWgCountPerTileRcs;
+    clone->maxWgCountPerTileCooperative = this->maxWgCountPerTileCooperative;
+    clone->heaplessEnabled = this->heaplessEnabled;
+    clone->implicitScalingEnabled = this->implicitScalingEnabled;
+    clone->rcsAvailable = this->rcsAvailable;
+    clone->cooperativeSupport = this->cooperativeSupport;
+
+    if (stateOverride) {
+        clone->state = *stateOverride;
+    }
+
+    return std::unique_ptr<KernelImp>{clone};
+}
+
 void KernelImp::createPrintfBuffer() {
     if (this->kernelImmData->getDescriptor().kernelAttributes.flags.usesPrintf || state.pImplicitArgs) {
         this->printfBuffer = PrintfHandler::createPrintfBuffer(this->module->getDevice());
@@ -1336,6 +1401,9 @@ void KernelImp::patchSyncBuffer(NEO::GraphicsAllocation *gfxAllocation, size_t b
     NEO::patchPointer(getCrossThreadDataSpan(),
                       this->getImmutableData()->getDescriptor().payloadMappings.implicitArgs.syncBufferAddress,
                       static_cast<uintptr_t>(ptrOffset(gfxAllocation->getGpuAddressToPatch(), bufferOffset)));
+    if (state.pImplicitArgs) {
+        state.pImplicitArgs->setSyncBufferPtr(static_cast<uintptr_t>(ptrOffset(gfxAllocation->getGpuAddressToPatch(), bufferOffset)));
+    }
 }
 
 void KernelImp::patchRegionGroupBarrier(NEO::GraphicsAllocation *gfxAllocation, size_t bufferOffset) {
@@ -1357,7 +1425,7 @@ uint32_t KernelImp::getSurfaceStateHeapDataSize() const {
             return 0;
         }
     }
-    return state.surfaceStateHeapDataSize;
+    return static_cast<uint32_t>(state.surfaceStateHeapData.size());
 }
 
 void *KernelImp::patchBindlessSurfaceState(NEO::GraphicsAllocation *alloc, uint32_t bindless) {
