@@ -45,6 +45,8 @@ struct KernelImp : Kernel {
         }
     }
 
+    std::unique_ptr<KernelImp> cloneWithStateOverride(const KernelMutableState *stateOverride);
+
     ze_result_t getBaseAddress(uint64_t *baseAddress) override;
     ze_result_t getKernelProgramBinary(size_t *kernelSize, char *pKernelBinary) override;
     ze_result_t setIndirectAccess(ze_kernel_indirect_access_flags_t flags) override;
@@ -79,8 +81,8 @@ struct KernelImp : Kernel {
 
     uint32_t suggestMaxCooperativeGroupCount(NEO::EngineGroupType engineGroupType, uint32_t *groupSize, bool forceSingleTileQuery);
 
-    const uint8_t *getCrossThreadData() const override { return state.crossThreadData.get(); }
-    uint32_t getCrossThreadDataSize() const override { return state.crossThreadDataSize; }
+    const uint8_t *getCrossThreadData() const override { return state.crossThreadData.data(); }
+    uint32_t getCrossThreadDataSize() const override { return static_cast<uint32_t>(state.crossThreadData.size()); }
 
     const std::vector<NEO::GraphicsAllocation *> &getArgumentsResidencyContainer() const override {
         return state.argumentsResidencyContainer;
@@ -98,7 +100,7 @@ struct KernelImp : Kernel {
 
     ze_result_t setArgRedescribedImage(uint32_t argIndex, ze_image_handle_t argVal, bool isPacked) override;
 
-    ze_result_t setArgBufferWithAlloc(uint32_t argIndex, uintptr_t argVal, NEO::GraphicsAllocation *allocation, NEO::SvmAllocationData *peerAllocData) override;
+    ze_result_t setArgBufferWithAlloc(uint32_t argIndex, uintptr_t argVal, NEO::GraphicsAllocation *allocation, NEO::SvmAllocationData *allocData) override;
 
     ze_result_t setArgImage(uint32_t argIndex, size_t argSize, const void *argVal);
 
@@ -126,10 +128,10 @@ struct KernelImp : Kernel {
     void patchSyncBuffer(NEO::GraphicsAllocation *gfxAllocation, size_t bufferOffset) override;
     void patchRegionGroupBarrier(NEO::GraphicsAllocation *gfxAllocation, size_t bufferOffset) override;
 
-    const uint8_t *getSurfaceStateHeapData() const override { return state.surfaceStateHeapData.get(); }
+    const uint8_t *getSurfaceStateHeapData() const override { return state.surfaceStateHeapData.data(); }
     uint32_t getSurfaceStateHeapDataSize() const override;
 
-    const uint8_t *getDynamicStateHeapData() const override { return state.dynamicStateHeapData.get(); }
+    const uint8_t *getDynamicStateHeapData() const override { return state.dynamicStateHeapData.data(); }
 
     const KernelImmutableData *getImmutableData() const override { return kernelImmData; }
 
@@ -249,11 +251,14 @@ struct KernelImp : Kernel {
     void *patchBindlessSurfaceState(NEO::GraphicsAllocation *alloc, uint32_t bindless);
     uint32_t getSurfaceStateIndexForBindlessOffset(NEO::CrossThreadDataOffset bindlessOffset) const;
     ze_result_t validateWorkgroupSize() const;
-    ArrayRef<uint8_t> getCrossThreadDataSpan() { return ArrayRef<uint8_t>(state.crossThreadData.get(), state.crossThreadDataSize); }
+    ArrayRef<uint8_t> getCrossThreadDataSpan() { return ArrayRef<uint8_t>(state.crossThreadData.data(), state.crossThreadData.size()); }
+    ArrayRef<uint8_t> getSurfaceStateHeapDataSpan() { return ArrayRef<uint8_t>(state.surfaceStateHeapData.data(), state.surfaceStateHeapData.size()); }
+    ArrayRef<uint8_t> getDynamicStateHeapDataSpan() { return ArrayRef<uint8_t>(state.dynamicStateHeapData.data(), state.dynamicStateHeapData.size()); }
 
     const KernelImmutableData *kernelImmData = nullptr;
     Module *module = nullptr;
     std::mutex *devicePrintfKernelMutex = nullptr;
+    KernelImp *cloneOrigin = nullptr;
 
     NEO::GraphicsAllocation *privateMemoryGraphicsAllocation = nullptr;
     NEO::GraphicsAllocation *printfBuffer = nullptr;
