@@ -13,22 +13,22 @@
 
 static ze_result_t changeMemoryOperationStatusToL0ResultType(NEO::MemoryOperationsStatus status) {
     switch (status) {
-    case NEO::MemoryOperationsStatus::SUCCESS:
+    case NEO::MemoryOperationsStatus::success:
         return ZE_RESULT_SUCCESS;
 
-    case NEO::MemoryOperationsStatus::MEMORY_NOT_FOUND:
+    case NEO::MemoryOperationsStatus::memoryNotFound:
         return ZE_RESULT_ERROR_INVALID_ARGUMENT;
 
-    case NEO::MemoryOperationsStatus::OUT_OF_MEMORY:
+    case NEO::MemoryOperationsStatus::outOfMemory:
         return ZE_RESULT_ERROR_OUT_OF_DEVICE_MEMORY;
 
-    case NEO::MemoryOperationsStatus::FAILED:
+    case NEO::MemoryOperationsStatus::failed:
         return ZE_RESULT_ERROR_DEVICE_LOST;
 
-    case NEO::MemoryOperationsStatus::DEVICE_UNINITIALIZED:
+    case NEO::MemoryOperationsStatus::deviceUninitialized:
         return ZE_RESULT_ERROR_UNINITIALIZED;
 
-    case NEO::MemoryOperationsStatus::UNSUPPORTED:
+    case NEO::MemoryOperationsStatus::unsupported:
         return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
 
     default:
