@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,6 +8,7 @@
 #pragma once
 
 #include "shared/source/helpers/constants.h"
+#include "shared/source/helpers/non_copyable_or_moveable.h"
 
 #include "level_zero/core/source/kernel/kernel.h"
 
@@ -21,19 +22,19 @@ class GraphicsAllocation;
 namespace L0 {
 struct Device;
 
-struct PrintfHandler {
+struct PrintfHandler : NEO::NonCopyableAndNonMovableClass {
     static NEO::GraphicsAllocation *createPrintfBuffer(Device *device);
     static void printOutput(const KernelImmutableData *kernelData,
                             NEO::GraphicsAllocation *printfBuffer, Device *device, bool useInternalBlitter);
     static size_t getPrintBufferSize();
 
   protected:
-    PrintfHandler(const PrintfHandler &) = delete;
-    PrintfHandler &operator=(PrintfHandler const &) = delete;
     PrintfHandler() = delete;
 
     constexpr static size_t printfBufferSize = 4 * MemoryConstants::megaByte;
     constexpr static uint32_t printfSurfaceInitialDataSize = sizeof(uint32_t);
 };
 
+static_assert(NEO::NonCopyableAndNonMovable<PrintfHandler>);
+
 } // namespace L0
