@@ -20,9 +20,12 @@
 #include "level_zero/core/test/unit_tests/mocks/mock_cmdlist.h"
 #include "level_zero/core/test/unit_tests/sources/helper/ze_object_utils.h"
 
+#include <optional>
+
+extern std::optional<uint32_t> blitterMaskOverride;
+
 namespace L0 {
 namespace ult {
-
 struct SimpleMultiTileFixture : public MulticontextL0AubFixture {
     virtual void setUp() {
         MulticontextL0AubFixture::setUp(2, EnabledCommandStreamers::single, true);
@@ -67,6 +70,9 @@ struct SimpleMultiTileFixture : public MulticontextL0AubFixture {
 struct SynchronizedDispatchMultiTileFixture : public SimpleMultiTileFixture {
     void setUp() override {
         debugManager.flags.ForceSynchronizedDispatchMode.set(1);
+        if (blitterMaskOverride.has_value()) {
+            debugManager.flags.BlitterEnableMaskOverride.set(blitterMaskOverride.value());
+        }
         SimpleMultiTileFixture::setUp();
     }
 };
@@ -117,6 +123,9 @@ struct CopyOffloadMultiTileFixture : public SimpleMultiTileFixture {
     void setUp() override {
         debugManager.flags.ForceCopyOperationOffloadForComputeCmdList.set(1);
         debugManager.flags.ForceInOrderImmediateCmdListExecution.set(1);
+        if (blitterMaskOverride.has_value()) {
+            debugManager.flags.BlitterEnableMaskOverride.set(blitterMaskOverride.value());
+        }
         SimpleMultiTileFixture::setUp();
     }
 };
