@@ -5,91 +5,23 @@
  *
  */
 
+#include "level_zero/core/test/unit_tests/experimental/test_graph.h"
+
+#include "shared/source/command_container/cmdcontainer.h"
+#include "shared/source/command_stream/linear_stream.h"
+#include "shared/test/common/cmd_parse/gen_cmd_parse.h"
 #include "shared/test/common/test_macros/hw_test.h"
 
-#include "level_zero/core/test/unit_tests/mocks/mock_cmdlist.h"
-#include "level_zero/core/test/unit_tests/mocks/mock_context.h"
-#include "level_zero/core/test/unit_tests/mocks/mock_device.h"
-#include "level_zero/core/test/unit_tests/mocks/mock_event.h"
-#include "level_zero/core/test/unit_tests/mocks/mock_image.h"
-#include "level_zero/core/test/unit_tests/mocks/mock_kernel.h"
-#include "level_zero/experimental/source/graph/graph.h"
-#include "level_zero/include/level_zero/driver_experimental/zex_graph.h"
+#include "level_zero/core/source/cmdlist/cmdlist_hw_immediate.h"
+#include "level_zero/core/test/unit_tests/fixtures/device_fixture.h"
+#include "level_zero/core/test/unit_tests/mocks/mock_module.h"
 
 using namespace NEO;
 
 namespace L0 {
-ze_result_t zeCommandListAppendWriteGlobalTimestamp(ze_command_list_handle_t hCommandList, uint64_t *dstptr, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendBarrier(ze_command_list_handle_t hCommandList, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendMemoryRangesBarrier(ze_command_list_handle_t hCommandList, uint32_t numRanges, const size_t *pRangeSizes, const void **pRanges, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendMemoryCopy(ze_command_list_handle_t hCommandList, void *dstptr, const void *srcptr, size_t size, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendMemoryFill(ze_command_list_handle_t hCommandList, void *ptr, const void *pattern, size_t patternSize, size_t size, ze_event_handle_t hEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendMemoryCopyRegion(ze_command_list_handle_t hCommandList, void *dstptr, const ze_copy_region_t *dstRegion, uint32_t dstPitch, uint32_t dstSlicePitch, const void *srcptr, const ze_copy_region_t *srcRegion, uint32_t srcPitch, uint32_t srcSlicePitch, ze_event_handle_t hEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendMemoryCopyFromContext(ze_command_list_handle_t hCommandList, void *dstptr, ze_context_handle_t hContextSrc, const void *srcptr, size_t size, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendImageCopy(ze_command_list_handle_t hCommandList, ze_image_handle_t hDstImage, ze_image_handle_t hSrcImage, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendImageCopyRegion(ze_command_list_handle_t hCommandList, ze_image_handle_t hDstImage, ze_image_handle_t hSrcImage, const ze_image_region_t *pDstRegion, const ze_image_region_t *pSrcRegion, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendImageCopyToMemory(ze_command_list_handle_t hCommandList, void *dstptr, ze_image_handle_t hSrcImage, const ze_image_region_t *pSrcRegion, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendImageCopyFromMemory(ze_command_list_handle_t hCommandList, ze_image_handle_t hDstImage, const void *srcptr, const ze_image_region_t *pDstRegion, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendMemoryPrefetch(ze_command_list_handle_t hCommandList, const void *ptr, size_t size);
-ze_result_t zeCommandListAppendMemAdvise(ze_command_list_handle_t hCommandList, ze_device_handle_t hDevice, const void *ptr, size_t size, ze_memory_advice_t advice);
-ze_result_t zeCommandListAppendSignalEvent(ze_command_list_handle_t hCommandList, ze_event_handle_t hEvent);
-ze_result_t zeCommandListAppendWaitOnEvents(ze_command_list_handle_t hCommandList, uint32_t numEvents, ze_event_handle_t *phEvents);
-ze_result_t zeCommandListAppendEventReset(ze_command_list_handle_t hCommandList, ze_event_handle_t hEvent);
-ze_result_t zeCommandListAppendQueryKernelTimestamps(ze_command_list_handle_t hCommandList, uint32_t numEvents, ze_event_handle_t *phEvents, void *dstptr, const size_t *pOffsets, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendLaunchKernel(ze_command_list_handle_t hCommandList, ze_kernel_handle_t kernelHandle, const ze_group_count_t *launchKernelArgs, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendLaunchCooperativeKernel(ze_command_list_handle_t hCommandList, ze_kernel_handle_t kernelHandle, const ze_group_count_t *launchKernelArgs, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendLaunchKernelIndirect(ze_command_list_handle_t hCommandList, ze_kernel_handle_t kernelHandle, const ze_group_count_t *pLaunchArgumentsBuffer, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendLaunchMultipleKernelsIndirect(ze_command_list_handle_t hCommandList, uint32_t numKernels, ze_kernel_handle_t *kernelHandles, const uint32_t *pCountBuffer, const ze_group_count_t *pLaunchArgumentsBuffer, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendSignalExternalSemaphoreExt(ze_command_list_handle_t hCommandList, uint32_t numSemaphores, ze_external_semaphore_ext_handle_t *phSemaphores, ze_external_semaphore_signal_params_ext_t *signalParams, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendWaitExternalSemaphoreExt(ze_command_list_handle_t hCommandList, uint32_t numSemaphores, ze_external_semaphore_ext_handle_t *phSemaphores, ze_external_semaphore_wait_params_ext_t *waitParams, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendImageCopyToMemoryExt(ze_command_list_handle_t hCommandList, void *dstptr, ze_image_handle_t hSrcImage, const ze_image_region_t *pSrcRegion, uint32_t destRowPitch, uint32_t destSlicePitch, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
-ze_result_t zeCommandListAppendImageCopyFromMemoryExt(ze_command_list_handle_t hCommandList, ze_image_handle_t hDstImage, const void *srcptr, const ze_image_region_t *pDstRegion, uint32_t srcRowPitch, uint32_t srcSlicePitch, ze_event_handle_t hSignalEvent, uint32_t numWaitEvents, ze_event_handle_t *phWaitEvents);
 
 namespace ult {
 
-struct GraphsCleanupGuard {
-    ~GraphsCleanupGuard() {
-        processUsesGraphs.store(false);
-    }
-};
-
-struct MockGraphCmdListWithContext : Mock<CommandList> {
-    MockGraphCmdListWithContext(L0::Context *ctx) : ctx(ctx) {}
-    ze_result_t getContextHandle(ze_context_handle_t *phContext) override {
-        *phContext = ctx;
-        return ZE_RESULT_SUCCESS;
-    }
-
-    L0::Context *ctx = nullptr;
-};
-
-struct MockGraphContextReturningSpecificCmdList : Mock<Context> {
-    Mock<CommandList> *cmdListToReturn = nullptr;
-    ze_result_t createCommandList(ze_device_handle_t hDevice, const ze_command_list_desc_t *desc, ze_command_list_handle_t *commandList) override {
-        *commandList = cmdListToReturn;
-        cmdListToReturn = nullptr;
-        return ZE_RESULT_SUCCESS;
-    }
-
-    MockGraphContextReturningSpecificCmdList() = default;
-    MockGraphContextReturningSpecificCmdList(const MockGraphContextReturningSpecificCmdList &) = delete;
-    MockGraphContextReturningSpecificCmdList &operator=(const MockGraphContextReturningSpecificCmdList &) = delete;
-    MockGraphContextReturningSpecificCmdList(MockGraphContextReturningSpecificCmdList &&) = delete;
-    MockGraphContextReturningSpecificCmdList &operator=(MockGraphContextReturningSpecificCmdList &&) = delete;
-    ~MockGraphContextReturningSpecificCmdList() override {
-        if (cmdListToReturn) {
-            delete static_cast<L0::CommandList *>(cmdListToReturn);
-        }
-    }
-};
-
-struct MockGraphContextReturningNewCmdList : Mock<Context> {
-    ze_result_t createCommandList(ze_device_handle_t hDevice, const ze_command_list_desc_t *desc, ze_command_list_handle_t *commandList) override {
-        *commandList = new Mock<CommandList>;
-        return ZE_RESULT_SUCCESS;
-    }
-};
-
 TEST(GraphTestApiCreate, GivenNonNullPNextThenGraphCreateReturnsError) {
     GraphsCleanupGuard graphCleanup;
     Mock<Context> ctx;
@@ -156,6 +88,7 @@ TEST(GraphTestApiCaptureBeginEnd, GivenValidDestinyGraphThenBeginCaptureReturnsS
     GraphsCleanupGuard graphCleanup;
     Mock<Context> ctx;
     Mock<CommandList> cmdlist;
+    cmdlist.flags = ZE_COMMAND_LIST_FLAG_IN_ORDER;
 
     L0::Graph graph(&ctx, true);
     auto err = ::zeCommandListBeginCaptureIntoGraphExp(&cmdlist, &graph, nullptr);
@@ -165,6 +98,8 @@ TEST(GraphTestApiCaptureBeginEnd, GivenValidDestinyGraphThenBeginCaptureReturnsS
     err = ::zeCommandListEndGraphCaptureExp(&cmdlist, &retGraph, nullptr);
     EXPECT_EQ(ZE_RESULT_SUCCESS, err);
     EXPECT_EQ(retGraph, &graph);
+
+    EXPECT_EQ(static_cast<ze_command_list_flags_t>(ZE_COMMAND_LIST_FLAG_IN_ORDER), graph.getCaptureTargetDesc().desc.flags);
 }
 
 TEST(GraphTestApiCaptureBeginEnd, GivenNonNullPNextThenGraphEndCaptureReturnsError) {
@@ -402,14 +337,6 @@ TEST(GraphTestDebugApis, GivenNonEmptyGraphWhenGraphIsEmptyIsCalledThenErrorIsRe
     EXPECT_EQ(ZE_RESULT_QUERY_FALSE, ::zeGraphIsEmptyExp(&srcGraph));
 }
 
-TEST(GraphTestDebugApis, WhenGraphDumpContentsIsCalledThenReturnUnsupportedFeature) {
-    GraphsCleanupGuard graphCleanup;
-    Mock<Context> ctx;
-    L0::Graph srcGraph(&ctx, true);
-    auto err = ::zeGraphDumpContentsExp(&srcGraph, "dump", nullptr);
-    EXPECT_EQ(ZE_RESULT_ERROR_UNSUPPORTED_FEATURE, err);
-}
-
 TEST(GraphTestApiSubmit, GivenNonNullPNextThenGraphAppendReturnsError) {
     GraphsCleanupGuard graphCleanup;
     Mock<Context> ctx;
@@ -469,15 +396,18 @@ TEST(GraphTestApiCapture, GivenCommandListInRecordStateThenCaptureCommandsInstea
     Mock<CommandList> cmdlist;
     Mock<Event> event;
     Mock<KernelImp> kernel;
+    Mock<KernelImp> kernel2;
     ze_image_handle_t imgA = nullptr;
     ze_image_handle_t imgB = nullptr;
-    zes_device_handle_t device = nullptr;
-    zet_kernel_handle_t kernelHandle = &kernel;
+    ze_device_handle_t device = nullptr;
+    ze_kernel_handle_t kernelHandle = &kernel;
     ze_external_semaphore_ext_handle_t sem = nullptr;
     ze_event_handle_t eventHandle = &event;
     ze_external_semaphore_signal_params_ext_t semSignalParams = {};
     ze_external_semaphore_wait_params_ext_t semWaitParams = {};
-    uint32_t kernelCount = 1;
+    ze_kernel_handle_t pKernelHandles[] = {&kernel, &kernel2};
+    const uint32_t numKernels = 2U;
+    const auto *pCountBuffer = &numKernels;
 
     uint64_t memA[16] = {};
     uint64_t memB[16] = {};
@@ -519,16 +449,14 @@ TEST(GraphTestApiCapture, GivenCommandListInRecordStateThenCaptureCommandsInstea
     EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendImageCopyToMemoryExt(&cmdlist, memA, imgA, &imgRegion, 16, 16, nullptr, 0, nullptr));
     EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendImageCopyFromMemoryExt(&cmdlist, imgA, memA, &imgRegion, 16, 16, nullptr, 0, nullptr));
     EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendLaunchKernel(&cmdlist, kernelHandle, &groupCount, nullptr, 0, nullptr));
-
-    // temporarily unsupported
-    EXPECT_EQ(ZE_RESULT_ERROR_UNSUPPORTED_FEATURE, L0::zeCommandListAppendLaunchCooperativeKernel(&cmdlist, kernelHandle, &groupCount, nullptr, 0, nullptr));
-    EXPECT_EQ(ZE_RESULT_ERROR_UNSUPPORTED_FEATURE, L0::zeCommandListAppendLaunchKernelIndirect(&cmdlist, kernelHandle, &groupCount, nullptr, 0, nullptr));
-    EXPECT_EQ(ZE_RESULT_ERROR_UNSUPPORTED_FEATURE, L0::zeCommandListAppendLaunchMultipleKernelsIndirect(&cmdlist, 1, &kernelHandle, &kernelCount, &groupCount, nullptr, 0, nullptr));
+    EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendLaunchCooperativeKernel(&cmdlist, kernelHandle, &groupCount, nullptr, 0, nullptr));
+    EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendLaunchKernelIndirect(&cmdlist, kernelHandle, &groupCount, nullptr, 0, nullptr));
+    EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendLaunchMultipleKernelsIndirect(&cmdlist, numKernels, pKernelHandles, pCountBuffer, &groupCount, nullptr, 0, nullptr));
 
     ze_graph_handle_t hgraph = &graph;
     EXPECT_EQ(ZE_RESULT_SUCCESS, ::zeCommandListEndGraphCaptureExp(&cmdlist, &hgraph, nullptr));
 
-    ASSERT_EQ(22U, graph.getCapturedCommands().size());
+    ASSERT_EQ(25U, graph.getCapturedCommands().size());
     uint32_t i = 0;
     EXPECT_EQ(CaptureApi::zeCommandListAppendBarrier, static_cast<CaptureApi>(graph.getCapturedCommands()[i++].index()));
     EXPECT_EQ(CaptureApi::zeCommandListAppendMemoryCopy, static_cast<CaptureApi>(graph.getCapturedCommands()[i++].index()));
@@ -552,6 +480,9 @@ TEST(GraphTestApiCapture, GivenCommandListInRecordStateThenCaptureCommandsInstea
     EXPECT_EQ(CaptureApi::zeCommandListAppendImageCopyToMemoryExt, static_cast<CaptureApi>(graph.getCapturedCommands()[i++].index()));
     EXPECT_EQ(CaptureApi::zeCommandListAppendImageCopyFromMemoryExt, static_cast<CaptureApi>(graph.getCapturedCommands()[i++].index()));
     EXPECT_EQ(CaptureApi::zeCommandListAppendLaunchKernel, static_cast<CaptureApi>(graph.getCapturedCommands()[i++].index()));
+    EXPECT_EQ(CaptureApi::zeCommandListAppendLaunchCooperativeKernel, static_cast<CaptureApi>(graph.getCapturedCommands()[i++].index()));
+    EXPECT_EQ(CaptureApi::zeCommandListAppendLaunchKernelIndirect, static_cast<CaptureApi>(graph.getCapturedCommands()[i++].index()));
+    EXPECT_EQ(CaptureApi::zeCommandListAppendLaunchMultipleKernelsIndirect, static_cast<CaptureApi>(graph.getCapturedCommands()[i++].index()));
 }
 
 TEST(GraphForks, GivenUnknownChildCommandlistThenJoinDoesNothing) {
@@ -783,20 +714,29 @@ TEST(GraphInstantiationValidation, WhenSubGraphsAreNotValidForInstantiationThenW
     }
 }
 
-TEST(GraphTestInstantiation, WhenInstantiatingGraphThenBakeCommandsIntoCommandlists) {
+using GraphTestInstantiationTest = Test<DeviceFixture>;
+
+TEST_F(GraphTestInstantiationTest, WhenInstantiatingGraphThenBakeCommandsIntoCommandlists) {
     GraphsCleanupGuard graphCleanup;
 
     MockGraphContextReturningSpecificCmdList ctx;
     MockGraphContextReturningSpecificCmdList otherCtx;
     Mock<CommandList> cmdlist;
     Mock<Event> event;
+    Mock<Module> module(this->device, nullptr);
     Mock<KernelImp> kernel;
+    kernel.module = &module;
+    Mock<KernelImp> kernel2;
+    kernel2.module = &module;
     ze_image_handle_t imgA = nullptr;
     ze_image_handle_t imgB = nullptr;
     zes_device_handle_t device = nullptr;
     ze_external_semaphore_ext_handle_t sem = nullptr;
     ze_event_handle_t eventHandle = &event;
-    zet_kernel_handle_t kernelHandle = &kernel;
+    ze_kernel_handle_t kernelHandle = &kernel;
+    ze_kernel_handle_t pKernelHandles[] = {&kernel, &kernel2};
+    const uint32_t numKernels = 2U;
+    const auto *pCountBuffer = &numKernels;
     ze_external_semaphore_signal_params_ext_t semSignalParams = {};
     ze_external_semaphore_wait_params_ext_t semWaitParams = {};
 
@@ -839,6 +779,9 @@ TEST(GraphTestInstantiation, WhenInstantiatingGraphThenBakeCommandsIntoCommandli
     EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendImageCopyToMemoryExt(&cmdlist, memA, imgA, &imgRegion, 16, 16, nullptr, 0, nullptr));
     EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendImageCopyFromMemoryExt(&cmdlist, imgA, memA, &imgRegion, 16, 16, nullptr, 0, nullptr));
     EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendLaunchKernel(&cmdlist, kernelHandle, &groupCount, nullptr, 0, nullptr));
+    EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendLaunchCooperativeKernel(&cmdlist, kernelHandle, &groupCount, nullptr, 0, nullptr));
+    EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendLaunchKernelIndirect(&cmdlist, kernelHandle, &groupCount, nullptr, 0, nullptr));
+    EXPECT_EQ(ZE_RESULT_SUCCESS, L0::zeCommandListAppendLaunchMultipleKernelsIndirect(&cmdlist, numKernels, pKernelHandles, pCountBuffer, &groupCount, nullptr, 0, nullptr));
 
     ze_graph_handle_t hgraph = &srcGraph;
     EXPECT_EQ(ZE_RESULT_SUCCESS, ::zeCommandListEndGraphCaptureExp(&cmdlist, &hgraph, nullptr));
@@ -869,6 +812,8 @@ TEST(GraphTestInstantiation, WhenInstantiatingGraphThenBakeCommandsIntoCommandli
     EXPECT_EQ(0U, graphHwCommands->appendImageCopyToMemoryExtCalled);
     EXPECT_EQ(0U, graphHwCommands->appendImageCopyFromMemoryExtCalled);
     EXPECT_EQ(0U, graphHwCommands->appendLaunchKernelCalled);
+    EXPECT_EQ(0U, graphHwCommands->appendLaunchKernelIndirectCalled);
+    EXPECT_EQ(0U, graphHwCommands->appendLaunchMultipleKernelsIndirectCalled);
     execGraph.instantiateFrom(srcGraph);
     EXPECT_EQ(1U, graphHwCommands->appendBarrierCalled);
     EXPECT_EQ(1U, graphHwCommands->appendMemoryCopyCalled);
@@ -891,7 +836,69 @@ TEST(GraphTestInstantiation, WhenInstantiatingGraphThenBakeCommandsIntoCommandli
     EXPECT_EQ(1U, graphHwCommands->appendWaitExternalSemaphoresCalled);
     EXPECT_EQ(1U, graphHwCommands->appendImageCopyToMemoryExtCalled);
     EXPECT_EQ(1U, graphHwCommands->appendImageCopyFromMemoryExtCalled);
-    EXPECT_EQ(1U, graphHwCommands->appendLaunchKernelCalled);
+    EXPECT_EQ(2U, graphHwCommands->appendLaunchKernelCalled); // +1 for zeCommandListAppendLaunchCooperativeKernel
+    EXPECT_EQ(1U, graphHwCommands->appendLaunchKernelIndirectCalled);
+    EXPECT_EQ(1U, graphHwCommands->appendLaunchMultipleKernelsIndirectCalled);
+}
+
+HWCMDTEST_F(IGFX_XE_HP_CORE,
+            GraphTestInstantiationTest,
+            GivenExecutableGraphWhenSubmittingItToCommandListThenPatchPreambleIsUsed) {
+    using MI_STORE_DATA_IMM = typename FamilyType::MI_STORE_DATA_IMM;
+    using MI_BATCH_BUFFER_START = typename FamilyType::MI_BATCH_BUFFER_START;
+
+    uint32_t bbStartDwordBuffer[alignUp(sizeof(MI_BATCH_BUFFER_START) / sizeof(uint32_t), 2)] = {0};
+
+    GraphsCleanupGuard graphCleanup;
+
+    ze_command_queue_desc_t cmdQueueDesc = {ZE_STRUCTURE_TYPE_COMMAND_QUEUE_DESC};
+    ze_command_list_handle_t immCmdList;
+    EXPECT_EQ(ZE_RESULT_SUCCESS, zeCommandListCreateImmediate(context, device, &cmdQueueDesc, &immCmdList));
+    auto immCmdListHw = static_cast<CommandListCoreFamilyImmediate<FamilyType::gfxCoreFamily> *>(immCmdList);
+
+    Graph srcGraph(context, true);
+    immCmdListHw->setCaptureTarget(&srcGraph);
+    srcGraph.startCapturingFrom(*immCmdListHw, false);
+    EXPECT_EQ(ZE_RESULT_SUCCESS, ::zeCommandListAppendBarrier(immCmdList, nullptr, 0U, nullptr));
+    srcGraph.stopCapturing();
+    immCmdListHw->setCaptureTarget(nullptr);
+
+    ExecutableGraph execGraph;
+    execGraph.instantiateFrom(srcGraph);
+
+    auto cmdStream = immCmdListHw->getCmdContainer().getCommandStream();
+
+    void *immListCpuBase = cmdStream->getCpuBase();
+    auto usedSpaceBefore = cmdStream->getUsed();
+    auto res = execGraph.execute(immCmdListHw, nullptr, nullptr, 0, nullptr);
+    EXPECT_EQ(ZE_RESULT_SUCCESS, res);
+    auto usedSpaceAfter = cmdStream->getUsed();
+
+    GenCmdList cmdList;
+    ASSERT_TRUE(FamilyType::Parse::parseCommandBuffer(
+        cmdList,
+        ptrOffset(immListCpuBase, usedSpaceBefore),
+        usedSpaceAfter - usedSpaceBefore));
+
+    auto sdiCmds = findAll<MI_STORE_DATA_IMM *>(cmdList.begin(), cmdList.end());
+    ASSERT_LT(1u, sdiCmds.size());
+
+    size_t bbStartIdx = 0;
+    for (auto &sdiCmd : sdiCmds) {
+        auto storeDataImm = reinterpret_cast<MI_STORE_DATA_IMM *>(*sdiCmd);
+
+        bbStartDwordBuffer[bbStartIdx] = storeDataImm->getDataDword0();
+        bbStartIdx++;
+        if (storeDataImm->getStoreQword()) {
+            bbStartDwordBuffer[bbStartIdx] = storeDataImm->getDataDword1();
+            bbStartIdx++;
+        }
+    }
+
+    MI_BATCH_BUFFER_START *chainBackBbStartCmd = genCmdCast<MI_BATCH_BUFFER_START *>(bbStartDwordBuffer);
+    ASSERT_NE(nullptr, chainBackBbStartCmd);
+
+    EXPECT_EQ(ZE_RESULT_SUCCESS, zeCommandListDestroy(immCmdList));
 }
 
 TEST(GraphExecution, GivenEmptyExecutableGraphWhenSubmittingItToCommandListThenTakeCareOnlyOfEvents) {
@@ -1009,5 +1016,106 @@ TEST(GraphExecution, GivenExecutableGraphWithSubGraphsWhenSubmittingItToCommandL
     EXPECT_EQ(0U, subCmdlist.appendSignalEventCalled);
 }
 
+TEST(ClosureExternalStorage, GivenEventWaitListThenRecordsItProperly) {
+    MockEvent events[10];
+    ze_event_handle_t eventHandles[10];
+    std::transform(events, events + 10, eventHandles, [](auto &ev) { return &ev; });
+
+    L0::ClosureExternalStorage storage;
+    EXPECT_EQ(L0::ClosureExternalStorage::invalidEventsListId, storage.registerEventsList(eventHandles, eventHandles));
+
+    auto waitList0Id = storage.registerEventsList(eventHandles, eventHandles + 1);
+    auto waitList1Id = storage.registerEventsList(eventHandles + 3, eventHandles + 5);
+    auto waitList2Id = storage.registerEventsList(eventHandles + 8, eventHandles + 10);
+
+    EXPECT_NE(L0::ClosureExternalStorage::invalidEventsListId, waitList0Id);
+    EXPECT_NE(L0::ClosureExternalStorage::invalidEventsListId, waitList1Id);
+    EXPECT_NE(L0::ClosureExternalStorage::invalidEventsListId, waitList2Id);
+
+    EXPECT_EQ(nullptr, storage.getEventsList(L0::ClosureExternalStorage::invalidEventsListId));
+
+    ASSERT_NE(nullptr, storage.getEventsList(waitList0Id));
+    EXPECT_EQ(eventHandles[0], storage.getEventsList(waitList0Id)[0]);
+
+    ASSERT_NE(nullptr, storage.getEventsList(waitList1Id));
+    EXPECT_EQ(eventHandles[3], storage.getEventsList(waitList1Id)[0]);
+    EXPECT_EQ(eventHandles[4], storage.getEventsList(waitList1Id)[1]);
+
+    ASSERT_NE(nullptr, storage.getEventsList(waitList2Id));
+    EXPECT_EQ(eventHandles[8], storage.getEventsList(waitList2Id)[0]);
+    EXPECT_EQ(eventHandles[9], storage.getEventsList(waitList2Id)[1]);
+}
+
+TEST(ClosureExternalStorage, GivenKernelMutableStateThenRecordsItProperly) {
+    KernelMutableState s1;
+    s1.globalOffsets[0] = 5U;
+    KernelMutableState s2;
+    s2.globalOffsets[0] = 7U;
+
+    L0::ClosureExternalStorage storage;
+
+    auto kernelState1Id = storage.registerKernelState(std::move(s1));
+    auto kernelState2Id = storage.registerKernelState(std::move(s2));
+
+    EXPECT_NE(L0::ClosureExternalStorage::invalidEventsListId, kernelState1Id);
+    EXPECT_NE(L0::ClosureExternalStorage::invalidEventsListId, kernelState2Id);
+
+    EXPECT_EQ(nullptr, storage.getKernelMutableState(L0::ClosureExternalStorage::invalidKernelStateId));
+
+    ASSERT_NE(nullptr, storage.getKernelMutableState(kernelState1Id));
+    EXPECT_EQ(5U, storage.getKernelMutableState(kernelState1Id)->globalOffsets[0]);
+
+    ASSERT_NE(nullptr, storage.getKernelMutableState(kernelState2Id));
+    EXPECT_EQ(7U, storage.getKernelMutableState(kernelState2Id)->globalOffsets[0]);
+}
+
+TEST(ClosureExternalStorage, GivenImageRegionThenRecordsItProperly) {
+    ze_image_region_t r1 = {};
+    r1.width = 5;
+    ze_image_region_t r2 = {};
+    r2.width = 7;
+
+    L0::ClosureExternalStorage storage;
+
+    EXPECT_EQ(L0::ClosureExternalStorage::invalidImageRegionId, storage.registerImageRegion(nullptr));
+    auto iamgeRegion1Id = storage.registerImageRegion(&r1);
+    auto iamgeRegion2Id = storage.registerImageRegion(&r2);
+
+    EXPECT_NE(L0::ClosureExternalStorage::invalidEventsListId, iamgeRegion1Id);
+    EXPECT_NE(L0::ClosureExternalStorage::invalidEventsListId, iamgeRegion2Id);
+
+    EXPECT_EQ(nullptr, storage.getImageRegion(L0::ClosureExternalStorage::invalidImageRegionId));
+
+    ASSERT_NE(nullptr, storage.getImageRegion(iamgeRegion1Id));
+    EXPECT_EQ(5U, storage.getImageRegion(iamgeRegion1Id)->width);
+
+    ASSERT_NE(nullptr, storage.getImageRegion(iamgeRegion2Id));
+    EXPECT_EQ(7U, storage.getImageRegion(iamgeRegion2Id)->width);
+}
+
+TEST(ClosureExternalStorage, GivenCopyRegionThenRecordsItProperly) {
+    ze_copy_region_t r1 = {};
+    r1.width = 5;
+    ze_copy_region_t r2 = {};
+    r2.width = 7;
+
+    L0::ClosureExternalStorage storage;
+
+    EXPECT_EQ(L0::ClosureExternalStorage::invalidCopyRegionId, storage.registerCopyRegion(nullptr));
+    auto copyRegion1Id = storage.registerCopyRegion(&r1);
+    auto copyRegion2Id = storage.registerCopyRegion(&r2);
+
+    EXPECT_NE(L0::ClosureExternalStorage::invalidEventsListId, copyRegion1Id);
+    EXPECT_NE(L0::ClosureExternalStorage::invalidEventsListId, copyRegion2Id);
+
+    EXPECT_EQ(nullptr, storage.getCopyRegion(L0::ClosureExternalStorage::invalidCopyRegionId));
+
+    ASSERT_NE(nullptr, storage.getCopyRegion(copyRegion1Id));
+    EXPECT_EQ(5U, storage.getCopyRegion(copyRegion1Id)->width);
+
+    ASSERT_NE(nullptr, storage.getCopyRegion(copyRegion2Id));
+    EXPECT_EQ(7U, storage.getCopyRegion(copyRegion2Id)->width);
+}
+
 } // namespace ult
 } // namespace L0
