@@ -49,6 +49,7 @@ struct WhiteBox<::L0::CommandListCoreFamily<gfxCoreFamily>>
     using BaseClass::appendMemoryCopyBlitRegion;
     using BaseClass::appendMultiTileBarrier;
     using BaseClass::appendSignalEventPostWalker;
+    using BaseClass::appendVfeStateCmdToPatch;
     using BaseClass::appendWriteKernelTimestamp;
     using BaseClass::applyMemoryRangesBarrier;
     using BaseClass::clearCommandsToPatch;
@@ -109,7 +110,7 @@ struct WhiteBox<::L0::CommandListCoreFamily<gfxCoreFamily>>
     using BaseClass::isTimestampEventForMultiTile;
     using BaseClass::l3FlushAfterPostSyncRequired;
     using BaseClass::latestOperationRequiredNonWalkerInOrderCmdsChaining;
-    using BaseClass::maxFillPaternSizeForCopyEngine;
+    using BaseClass::maxFillPatternSizeForCopyEngine;
     using BaseClass::obtainKernelPreemptionMode;
     using BaseClass::partitionCount;
     using BaseClass::patternAllocations;
@@ -124,6 +125,7 @@ struct WhiteBox<::L0::CommandListCoreFamily<gfxCoreFamily>>
     using BaseClass::signalAllEventPackets;
     using BaseClass::stateBaseAddressTracking;
     using BaseClass::stateComputeModeTracking;
+    using BaseClass::statelessBuiltinsEnabled;
     using BaseClass::syncDispatchQueueId;
     using BaseClass::synchronizedDispatchMode;
     using BaseClass::unifiedMemoryControls;
@@ -212,6 +214,7 @@ struct WhiteBox<L0::CommandListCoreFamilyImmediate<gfxCoreFamily>>
     using BaseClass::disablePatching;
     using BaseClass::dispatchEventRemainingPacketsPostSyncOperation;
     using BaseClass::doubleSbaWa;
+    using BaseClass::dummyBlitWa;
     using BaseClass::duplicatedInOrderCounterStorageEnabled;
     using BaseClass::enablePatching;
     using BaseClass::engineGroupType;
@@ -238,6 +241,7 @@ struct WhiteBox<L0::CommandListCoreFamilyImmediate<gfxCoreFamily>>
     using BaseClass::latestFlushIsHostVisible;
     using BaseClass::latestOperationHasOptimizedCbEvent;
     using BaseClass::latestOperationRequiredNonWalkerInOrderCmdsChaining;
+    using BaseClass::maxFillPatternSizeForCopyEngine;
     using BaseClass::partitionCount;
     using BaseClass::pipeControlMultiKernelEventSync;
     using BaseClass::pipelineSelectStateTracking;
@@ -248,6 +252,7 @@ struct WhiteBox<L0::CommandListCoreFamilyImmediate<gfxCoreFamily>>
     using BaseClass::signalAllEventPackets;
     using BaseClass::stateBaseAddressTracking;
     using BaseClass::stateComputeModeTracking;
+    using BaseClass::statelessBuiltinsEnabled;
     using BaseClass::syncDispatchQueueId;
     using BaseClass::synchronizedDispatchMode;
     using BaseClass::synchronizeInOrderExecution;
@@ -388,11 +393,17 @@ struct Mock<CommandList> : public CommandList {
                      (ze_kernel_handle_t hKernel,
                       const ze_group_count_t groupCounts,
                       const ze_group_size_t groupSizes,
-                      const void **pArguments,
+                      void **pArguments,
                       const void *pNext,
                       ze_event_handle_t hSignalEvent,
                       uint32_t numWaitEvents,
                       ze_event_handle_t *phWaitEvents));
+    ADDMETHOD_NOBASE(appendLaunchKernelWithParameters, ze_result_t, ZE_RESULT_SUCCESS,
+                     (ze_kernel_handle_t hKernel,
+                      const ze_group_count_t *pGroupCounts,
+                      const void *pNext, ze_event_handle_t hSignalEvent,
+                      uint32_t numWaitEvents,
+                      ze_event_handle_t *phWaitEvents));
 
     ADDMETHOD_NOBASE(appendSoftwareTag, ze_result_t, ZE_RESULT_SUCCESS,
                      (const char *data));
@@ -884,5 +895,40 @@ class MockCommandListForExecuteMemAdvise : public WhiteBox<::L0::CommandListCore
     uint32_t executeMemAdviseCallCount = 0;
 };
 
+template <GFXCORE_FAMILY gfxCoreFamily>
+struct MockCommandListImmediateExtSem : public WhiteBox<::L0::CommandListCoreFamilyImmediate<gfxCoreFamily>> {
+    MockCommandListImmediateExtSem() : WhiteBox<::L0::CommandListCoreFamilyImmediate<gfxCoreFamily>>() {}
+
+    ze_result_t appendWaitOnEvents(uint32_t numEvents, ze_event_handle_t *phEvent, CommandToPatchContainer *outWaitCmds,
+                                   bool relaxedOrderingAllowed, bool trackDependencies, bool apiRequest, bool skipAddingWaitEventsToResidency, bool skipFlush, bool copyOffloadOperation) override {
+
+        appendWaitOnEventsCalledTimes++;
+
+        if (failingWaitOnEvents) {
+            return ZE_RESULT_ERROR_UNKNOWN;
+        }
+
+        return ZE_RESULT_SUCCESS;
+    }
+
+    ze_result_t appendSignalEvent(ze_event_handle_t hEvent, bool relaxedOrderingDispatch) override {
+        appendSignalEventCalledTimes++;
+
+        if (failOnSecondSignalEvent && appendSignalEventCalledTimes == 2) {
+            return ZE_RESULT_ERROR_UNKNOWN;
+        }
+        if (failingSignalEvent) {
+            return ZE_RESULT_ERROR_UNKNOWN;
+        }
+        return ZE_RESULT_SUCCESS;
+    }
+
+    uint32_t appendWaitOnEventsCalledTimes = 0;
+    uint32_t appendSignalEventCalledTimes = 0;
+    bool failingWaitOnEvents = false;
+    bool failingSignalEvent = false;
+    bool failOnSecondSignalEvent = false;
+};
+
 } // namespace ult
 } // namespace L0
