@@ -15,7 +15,6 @@
 #include "shared/test/common/mocks/mock_usm_memory_pool.h"
 #include "shared/test/common/mocks/ult_device_factory.h"
 #include "shared/test/common/test_macros/hw_test.h"
-#include "shared/test/common/test_macros/test_checks_shared.h"
 
 #include "level_zero/core/source/context/context_imp.h"
 #include "level_zero/core/source/device/device_imp.h"
@@ -28,10 +27,10 @@ namespace ult {
 template <int hostUsmPoolFlag = -1, int deviceUsmPoolFlag = -1, int poolingVersionFlag = -1>
 struct AllocUsmPoolMemoryTest : public ::testing::Test {
     void SetUp() override {
-        REQUIRE_SVM_OR_SKIP(NEO::defaultHwInfo);
         NEO::debugManager.flags.EnableHostUsmAllocationPool.set(hostUsmPoolFlag);
         NEO::debugManager.flags.EnableDeviceUsmAllocationPool.set(deviceUsmPoolFlag);
         NEO::debugManager.flags.ExperimentalUSMAllocationReuseVersion.set(poolingVersionFlag);
+        NEO::debugManager.flags.EnableShareableWithoutNTHandle.set(false);
 
         executionEnvironment = new NEO::ExecutionEnvironment();
         executionEnvironment->prepareRootDeviceEnvironments(numRootDevices);
@@ -801,4 +800,4 @@ TEST_F(AllocUsmDeviceEnabledMemoryNewVersionTest, givenContextWhenNormalAllocFai
 }
 
 } // namespace ult
-} // namespace L0
\ No newline at end of file
+} // namespace L0
