@@ -87,8 +87,7 @@ HWCMDTEST_F(IGFX_XE_HP_CORE,
     mockKernelImmData2->kernelDescriptor->kernelAttributes.crossThreadDataSize = kernel2CrossThreadInitSize;
     mockKernelImmData2->crossThreadDataSize = kernel2CrossThreadInitSize;
     mockKernelImmData2->crossThreadDataTemplate.reset(new uint8_t[kernel2CrossThreadInitSize]);
-    kernel2->state.crossThreadDataSize = kernel2CrossThreadInitSize;
-    kernel2->state.crossThreadData.reset(new uint8_t[kernel2CrossThreadInitSize]);
+    kernel2->state.crossThreadData.resize(kernel2CrossThreadInitSize, 0x0);
 
     createMutableKernelGroup();
 
@@ -153,7 +152,7 @@ HWCMDTEST_F(IGFX_XE_HP_CORE,
     kernel2->state.perThreadDataSizeForWholeThreadGroup = 0x40;
     kernel2->state.perThreadDataForWholeThreadGroup = static_cast<uint8_t *>(alignedMalloc(kernel2->state.perThreadDataSizeForWholeThreadGroup, 32));
 
-    auto srcPtr = kernel2->state.crossThreadData.get();
+    auto srcPtr = kernel2->state.crossThreadData.data();
     memset(srcPtr, 0xFF, mutableKernels[1]->inlineDataSize);
 
     auto dstPtr = mutableKernels[1]->getMutableComputeWalker()->getHostMemoryInlineDataPointer();
