@@ -7,8 +7,8 @@
 
 #include "level_zero/sysman/source/api/fan/linux/sysman_os_fan_imp.h"
 
-#include "level_zero/sysman/source/linux/pmt/sysman_pmt.h"
-#include "level_zero/sysman/source/linux/zes_os_sysman_imp.h"
+#include "level_zero/sysman/source/shared/linux/pmt/sysman_pmt.h"
+#include "level_zero/sysman/source/shared/linux/zes_os_sysman_imp.h"
 
 namespace L0 {
 namespace Sysman {
