@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2024 Intel Corporation
+ * Copyright (C) 2023-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,6 +8,7 @@
 #include "level_zero/sysman/source/api/firmware/windows/sysman_os_firmware_imp.h"
 
 #include "level_zero/sysman/source/shared/firmware_util/sysman_firmware_util.h"
+#include "level_zero/sysman/source/shared/windows/product_helper/sysman_product_helper.h"
 #include "level_zero/sysman/source/shared/windows/zes_os_sysman_imp.h"
 #include "level_zero/sysman/source/sysman_const.h"
 
@@ -18,6 +19,9 @@ const std::vector<std ::string> deviceSupportedFwTypes = {"GSC", "OptionROM"};
 
 ze_result_t WddmFirmwareImp::getFirmwareVersion(std::string fwType, zes_firmware_properties_t *pProperties) {
     std::string fwVersion;
+    if (std::find(lateBindingFirmwareTypes.begin(), lateBindingFirmwareTypes.end(), fwType) != lateBindingFirmwareTypes.end()) {
+        return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
+    }
     ze_result_t result = pFwInterface->getFwVersion(fwType, fwVersion);
     if (ZE_RESULT_SUCCESS == result) {
         strncpy_s(static_cast<char *>(pProperties->version), ZES_STRING_PROPERTY_SIZE, fwVersion.c_str(), ZES_STRING_PROPERTY_SIZE);
@@ -65,9 +69,13 @@ std::unique_ptr<OsFirmware> OsFirmware::create(OsSysman *pOsSysman, const std::s
 void OsFirmware::getSupportedFwTypes(std::vector<std::string> &supportedFwTypes, OsSysman *pOsSysman) {
     WddmSysmanImp *pWddmSysmanImp = static_cast<WddmSysmanImp *>(pOsSysman);
     FirmwareUtil *pFwInterface = pWddmSysmanImp->getFwUtilInterface();
+    auto pSysmanProductHelper = pWddmSysmanImp->getSysmanProductHelper();
     supportedFwTypes.clear();
     if (pFwInterface != nullptr) {
         supportedFwTypes = deviceSupportedFwTypes;
+        if (pSysmanProductHelper->isLateBindingSupported()) {
+            pFwInterface->getLateBindingSupportedFwTypes(supportedFwTypes);
+        }
     }
 }
 
