@@ -7,7 +7,7 @@
 
 #pragma once
 
-#include "level_zero/sysman/source/windows/sysman_kmd_sys_manager.h"
+#include "level_zero/sysman/source/shared/windows/sysman_kmd_sys_manager.h"
 #include "level_zero/zes_api.h"
 
 namespace L0 {
@@ -24,7 +24,7 @@ struct MockEventHandle {
     bool inited = false;
 };
 
-uint64_t convertTStoMicroSec(uint64_t TS, uint32_t freq);
+uint64_t convertTStoMicroSec(uint64_t ts, uint32_t freq);
 namespace KmdSysman = L0::Sysman::KmdSysman;
 struct MockKmdSysManager : public L0::Sysman::KmdSysManager {
     ze_bool_t allowSetCalls = false;
@@ -54,6 +54,12 @@ struct MockKmdSysManager : public L0::Sysman::KmdSysManager {
         pBuffer += sizeof(KmdSysman::GfxSysmanReqHeaderOut);
 
         if (pRequest->inRequestId == KmdSysman::Requests::Power::CurrentPowerLimit1) {
+
+            if (pRequest->inDataSize != 0) {
+                pResponse->outDataSize = 0;
+                pResponse->outReturnCode = KmdSysman::KmdSysmanFail;
+                return;
+            }
             uint32_t *pPl1 = reinterpret_cast<uint32_t *>(pBuffer);
             *pPl1 = mockPowerLimit1;
             pResponse->outReturnCode = KmdSysman::KmdSysmanSuccess;
@@ -200,7 +206,6 @@ struct MockKmdSysManager : public L0::Sysman::KmdSysManager {
     }
 
     bool validateInputBuffer(KmdSysman::GfxSysmanMainHeaderIn *pHeaderIn) {
-        uint32_t sizeCheck = pHeaderIn->inTotalsize;
         uint8_t *pBufferPtr = pHeaderIn->inBuffer;
 
         for (uint32_t i = 0; i < pHeaderIn->inNumElements; i++) {
@@ -210,7 +215,6 @@ struct MockKmdSysManager : public L0::Sysman::KmdSysManager {
                 pRequest->inCommand == KmdSysman::Command::RegisterEvent) {
                 if (pRequest->inComponent >= KmdSysman::Component::InterfaceProperties && pRequest->inComponent < KmdSysman::Component::MaxComponents) {
                     pBufferPtr += sizeof(KmdSysman::GfxSysmanReqHeaderIn);
-                    sizeCheck -= sizeof(KmdSysman::GfxSysmanReqHeaderIn);
 
                     if (pRequest->inCommand == KmdSysman::Command::Set ||
                         pRequest->inCommand == KmdSysman::Command::RegisterEvent) {
@@ -218,7 +222,6 @@ struct MockKmdSysManager : public L0::Sysman::KmdSysManager {
                             return false;
                         }
                         pBufferPtr += pRequest->inDataSize;
-                        sizeCheck -= pRequest->inDataSize;
                     }
                 } else {
                     return false;
@@ -228,10 +231,6 @@ struct MockKmdSysManager : public L0::Sysman::KmdSysManager {
             }
         }
 
-        if (sizeCheck != 0) {
-            return false;
-        }
-
         return true;
     }
 
@@ -257,8 +256,7 @@ struct MockKmdSysManager : public L0::Sysman::KmdSysManager {
             for (uint32_t i = 0; i < mockKmdMaxHandlesPerEvent; i++) {
                 if (!handles[pRequest->inRequestId][i].inited) {
                     handles[pRequest->inRequestId][i].inited = true;
-                    unsigned long long eventID = *(unsigned long long *)pBuffer;
-                    handles[pRequest->inRequestId][i].eventHandle = reinterpret_cast<HANDLE>(eventID);
+                    memcpy_s(&handles[pRequest->inRequestId][i].eventHandle, sizeof(HANDLE), pBuffer, sizeof(HANDLE));
                     found = true;
                     break;
                 }
