@@ -8,6 +8,7 @@
 #pragma once
 #include "shared/source/helpers/constants.h"
 
+#include "level_zero/core/source/device/device_imp.h"
 #include "level_zero/core/source/event/event.h"
 #include "level_zero/core/source/helpers/api_handle_helper.h"
 #include "level_zero/tools/source/metrics/os_interface_metric.h"
@@ -105,12 +106,15 @@ class MetricSource {
                                                       std::vector<zet_metric_group_handle_t> &metricGroupList) = 0;
     virtual ze_result_t appendMarker(zet_command_list_handle_t hCommandList, zet_metric_group_handle_t hMetricGroup, uint32_t value) = 0;
     virtual ze_result_t calcOperationCreate(MetricDeviceContext &metricDeviceContext,
-                                            zet_intel_metric_calculate_exp_desc_t *pCalculateDesc,
-                                            uint32_t *pCount,
-                                            zet_metric_handle_t *phExcludedMetrics,
-                                            zet_intel_metric_calculate_operation_exp_handle_t *phCalculateOperation) = 0;
+                                            zet_intel_metric_calculation_exp_desc_t *pCalculationDesc,
+                                            const std::vector<MetricScopeImp *> &metricScopes,
+                                            zet_intel_metric_calculation_operation_exp_handle_t *phCalculationOperation) = 0;
     virtual bool canDisable() = 0;
     virtual void initMetricScopes(MetricDeviceContext &metricDeviceContext) = 0;
+    static std::optional<zet_intel_metric_hw_buffer_size_exp_desc_t *> getHwBufferSizeDesc(zet_base_desc_t *baseDesc);
+
+    template <typename T>
+    ze_result_t activatePreferDeferredHierarchical(DeviceImp *deviceImp, const uint32_t count, zet_metric_group_handle_t *phMetricGroups);
 
   protected:
     uint32_t type = MetricSource::metricSourceTypeUndefined;
@@ -176,10 +180,8 @@ class MetricDeviceContext {
                                               uint32_t *pMetricGroupCount,
                                               zet_metric_group_handle_t *phMetricGroups);
     ze_result_t calcOperationCreate(zet_context_handle_t hContext,
-                                    zet_intel_metric_calculate_exp_desc_t *pCalculateDesc,
-                                    uint32_t *pExcludedMetricCount,
-                                    zet_metric_handle_t *phExcludedMetrics,
-                                    zet_intel_metric_calculate_operation_exp_handle_t *phCalculateOperation);
+                                    zet_intel_metric_calculation_exp_desc_t *pCalculationDesc,
+                                    zet_intel_metric_calculation_operation_exp_handle_t *phCalculationOperation);
     ze_result_t metricScopesGet(zet_context_handle_t hContext,
                                 uint32_t *pMetricScopesCount,
                                 zet_intel_metric_scope_exp_handle_t *phMetricScopes);
@@ -188,9 +190,8 @@ class MetricDeviceContext {
     bool isMultiDeviceCapable() const {
         return multiDeviceCapable;
     }
-    void addMetricScope(std::unique_ptr<MetricScopeImp> metricScope) {
-        metricScopes.push_back(std::move(metricScope));
-    }
+
+    uint32_t addMetricScope(std::string_view scopeName, std::string_view scopeDescription);
 
     void setComputeMetricScopeInitialized() {
         computeMetricScopesInitialized = true;
@@ -460,20 +461,17 @@ struct HomogeneousMultiDeviceMetricCreated : public MultiDeviceMetricImp {
     static MetricImp *create(MetricSource &metricSource, std::vector<MetricImp *> &subDeviceMetrics);
 };
 
-struct MetricCalcOp : _zet_intel_metric_calculate_operation_exp_handle_t {
+struct MetricCalcOp : _zet_intel_metric_calculation_operation_exp_handle_t {
     virtual ~MetricCalcOp() = default;
     MetricCalcOp() {}
-    static MetricCalcOp *fromHandle(zet_intel_metric_calculate_operation_exp_handle_t handle) {
+    static MetricCalcOp *fromHandle(zet_intel_metric_calculation_operation_exp_handle_t handle) {
         return static_cast<MetricCalcOp *>(handle);
     }
-    inline zet_intel_metric_calculate_operation_exp_handle_t toHandle() { return this; }
+    inline zet_intel_metric_calculation_operation_exp_handle_t toHandle() { return this; }
 
     virtual ze_result_t destroy() = 0;
     virtual ze_result_t getReportFormat(uint32_t *pCount, zet_metric_handle_t *phMetrics) = 0;
-    virtual ze_result_t metricCalculateMultipleValues(const size_t rawDataSize, size_t *offset, const uint8_t *pRawData,
-                                                      uint32_t *pSetCount, uint32_t *pMetricsReportCountPerSet,
-                                                      uint32_t *pTotalMetricReportCount,
-                                                      zet_intel_metric_result_exp_t *pMetricResults) = 0;
+    virtual ze_result_t getExcludedMetrics(uint32_t *pCount, zet_metric_handle_t *phMetrics) = 0;
     virtual ze_result_t metricCalculateValues(const size_t rawDataSize, size_t *pOffset, const uint8_t *pRawData,
                                               uint32_t *pTotalMetricReportCount,
                                               zet_intel_metric_result_exp_t *pMetricResults) = 0;
@@ -481,13 +479,33 @@ struct MetricCalcOp : _zet_intel_metric_calculate_operation_exp_handle_t {
 
 struct MetricCalcOpImp : public MetricCalcOp {
     ~MetricCalcOpImp() override = default;
-    MetricCalcOpImp(bool multiDevice) : isMultiDevice(multiDevice) {}
+    MetricCalcOpImp(bool multiDevice,
+                    const std::vector<MetricScopeImp *> &metricScopes,
+                    const std::vector<MetricImp *> &metricsInReport,
+                    const std::vector<MetricImp *> &excludedMetrics = std::vector<MetricImp *>())
+        : isMultiDevice(multiDevice),
+          metricScopes(metricScopes),
+          metricsInReport(metricsInReport),
+          excludedMetrics(excludedMetrics) {}
+
     bool isRootDevice() { return isMultiDevice; }
+    ze_result_t getReportFormat(uint32_t *pCount, zet_metric_handle_t *phMetrics) override;
+    ze_result_t getExcludedMetrics(uint32_t *pCount, zet_metric_handle_t *phMetrics) override;
+    uint32_t getMetricsInReportCount() { return static_cast<uint32_t>(metricsInReport.size()); };
+    uint32_t getExcludedMetricsCount() { return static_cast<uint32_t>(excludedMetrics.size()); };
 
   protected:
+    ze_result_t getMetricsFromCalcOp(uint32_t *pCount, zet_metric_handle_t *phMetrics, bool isExcludedMetrics = false);
     bool isMultiDevice = false;
+    std::vector<MetricScopeImp *> metricScopes{};
+    std::vector<MetricImp *> metricsInReport{};
+    std::vector<MetricImp *> excludedMetrics{};
 };
 
+static constexpr std::string_view computeScopeNamePrefix = "COMPUTE_TILE_";
+static constexpr std::string_view computeScopeDescriptionPrefix = "Metrics results for tile ";
+static constexpr std::string_view aggregatedScopeName = "DEVICE_AGGREGATED";
+static constexpr std::string_view aggregatedScopeDescription = "Metrics results aggregated at device level";
 struct MetricScope : _zet_intel_metric_scope_exp_handle_t {
     virtual ~MetricScope() = default;
     MetricScope() {}
@@ -500,13 +518,23 @@ struct MetricScope : _zet_intel_metric_scope_exp_handle_t {
 
 struct MetricScopeImp : public MetricScope {
     ~MetricScopeImp() override = default;
-    MetricScopeImp(zet_intel_metric_scope_properties_exp_t &properties) : properties(properties){};
+    MetricScopeImp(zet_intel_metric_scope_properties_exp_t &properties, bool aggregated) : properties(properties), aggregated(aggregated) {}
 
     virtual ze_result_t getProperties(zet_intel_metric_scope_properties_exp_t *pProperties);
-    static std::unique_ptr<MetricScopeImp> create(zet_intel_metric_scope_properties_exp_t &scopeProperties);
+    static std::unique_ptr<MetricScopeImp> create(zet_intel_metric_scope_properties_exp_t &scopeProperties, bool aggregated);
+    bool isAggregated() const { return aggregated; }
+
+    uint32_t getId() const {
+        return properties.iD;
+    }
+
+    bool isName(std::string_view name) const {
+        return strcmp(properties.name, name.data()) == 0;
+    }
 
   private:
     zet_intel_metric_scope_properties_exp_t properties;
+    bool aggregated = false;
 };
 
 // MetricGroup.
@@ -561,26 +589,29 @@ ze_result_t metricTracerDecode(zet_metric_decoder_exp_handle_t hMetricDecoder, s
                                uint32_t metricsCount, zet_metric_handle_t *phMetrics, uint32_t *pSetCount, uint32_t *pMetricEntriesCountPerSet,
                                uint32_t *pMetricEntriesCount, zet_metric_entry_exp_t *pMetricEntries);
 
-ze_result_t metricCalculateOperationCreate(zet_context_handle_t hContext, zet_device_handle_t hDevice, zet_intel_metric_calculate_exp_desc_t *pCalculateDesc,
-                                           uint32_t *pCount, zet_metric_handle_t *phExcludedMetrics, zet_intel_metric_calculate_operation_exp_handle_t *phCalculateOperation);
+ze_result_t metricCalculationOperationCreate(zet_context_handle_t hContext, zet_device_handle_t hDevice, zet_intel_metric_calculation_exp_desc_t *pCalculationDesc,
+                                             zet_intel_metric_calculation_operation_exp_handle_t *phCalculationOperation);
 
-ze_result_t metricCalculateOperationDestroy(zet_intel_metric_calculate_operation_exp_handle_t hCalculateOperation);
+ze_result_t metricCalculationOperationDestroy(zet_intel_metric_calculation_operation_exp_handle_t hCalculationOperation);
 
-ze_result_t metricCalculateGetReportFormat(zet_intel_metric_calculate_operation_exp_handle_t hCalculateOperation,
-                                           uint32_t *pCount, zet_metric_handle_t *phMetrics);
+ze_result_t metricCalculationGetReportFormat(zet_intel_metric_calculation_operation_exp_handle_t hCalculationOperation,
+                                             uint32_t *pCount, zet_metric_handle_t *phMetrics);
+
+ze_result_t metricCalculationGetExcludedMetrics(zet_intel_metric_calculation_operation_exp_handle_t hCalculationOperation,
+                                                uint32_t *pCount, zet_metric_handle_t *phMetrics);
 
 ze_result_t metricCalculateValues(const size_t rawDataSize, size_t *pOffset, const uint8_t *pRawData,
-                                  zet_intel_metric_calculate_operation_exp_handle_t hCalculateOperation,
+                                  zet_intel_metric_calculation_operation_exp_handle_t hCalculationOperation,
                                   uint32_t *pTotalMetricReportsCount, zet_intel_metric_result_exp_t *pMetricResults);
 
 ze_result_t metricCalculateMultipleValues(const size_t rawDataSize, size_t *offset, const uint8_t *pRawData,
-                                          zet_intel_metric_calculate_operation_exp_handle_t hCalculateOperation,
+                                          zet_intel_metric_calculation_operation_exp_handle_t hCalculationOperation,
                                           uint32_t *pSetCount, uint32_t *pMetricsReportCountPerSet,
                                           uint32_t *pTotalMetricReportCount, zet_intel_metric_result_exp_t *pMetricResults);
 
 ze_result_t metricDecodeCalculateMultipleValues(zet_intel_metric_decoder_exp_handle_t hMetricDecoder,
                                                 const size_t rawDataSize, size_t *offset, const uint8_t *pRawData,
-                                                zet_intel_metric_calculate_operation_exp_handle_t hCalculateOperation,
+                                                zet_intel_metric_calculation_operation_exp_handle_t hCalculationOperation,
                                                 uint32_t *pSetCount, uint32_t *pMetricReportCountPerSet,
                                                 uint32_t *pTotalMetricReportCount, zet_intel_metric_result_exp_t *pMetricResults);
 
