@@ -58,10 +58,9 @@ class IpSamplingMetricSourceImp : public MetricSource {
         activationTracker.reset(inputActivationTracker);
     }
     ze_result_t calcOperationCreate(MetricDeviceContext &metricDeviceContext,
-                                    zet_intel_metric_calculate_exp_desc_t *pCalculateDesc,
-                                    uint32_t *pExcludedMetricCount,
-                                    zet_metric_handle_t *phExcludedMetrics,
-                                    zet_intel_metric_calculate_operation_exp_handle_t *phCalculateOperation) override;
+                                    zet_intel_metric_calculation_exp_desc_t *pCalculationDesc,
+                                    const std::vector<MetricScopeImp *> &metricScopes,
+                                    zet_intel_metric_calculation_operation_exp_handle_t *phCalculationOperation) override;
 
     uint32_t metricSourceCount = 0;
     bool canDisable() override;
