@@ -65,10 +65,9 @@ class OaMetricSourceImp : public MetricSource {
                            zet_metric_group_sampling_type_flag_t samplingType,
                            zet_metric_group_handle_t *pMetricGroupHandle);
     ze_result_t calcOperationCreate(MetricDeviceContext &metricDeviceContext,
-                                    zet_intel_metric_calculate_exp_desc_t *pCalculateDesc,
-                                    uint32_t *pExcludedMetricCount,
-                                    zet_metric_handle_t *phExcludedMetrics,
-                                    zet_intel_metric_calculate_operation_exp_handle_t *phCalculateOperation) override {
+                                    zet_intel_metric_calculation_exp_desc_t *pCalculationDesc,
+                                    const std::vector<MetricScopeImp *> &metricScopes,
+                                    zet_intel_metric_calculation_operation_exp_handle_t *phCalculationOperation) override {
         return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
     }
     bool canDisable() override;
