@@ -1,29 +1,26 @@
 /*
- * Copyright (C) 2021-2022 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
-#include "level_zero/core/source/device/device.h"
+#include "level_zero/api/sysman/zes_handles_struct.h"
 #include <level_zero/zes_api.h>
 
+#include <memory>
 #include <mutex>
 #include <string>
 #include <vector>
 
-struct _zes_diag_handle_t {
-    virtual ~_zes_diag_handle_t() = default;
-};
-
 namespace L0 {
 
 struct OsSysman;
 
 class Diagnostics : _zes_diag_handle_t {
   public:
-    ~Diagnostics() override {}
+    virtual ~Diagnostics() = default;
     virtual ze_result_t diagnosticsGetProperties(zes_diag_properties_t *pProperties) = 0;
     virtual ze_result_t diagnosticsGetTests(uint32_t *pCount, zes_diag_test_t *pTests) = 0;
     virtual ze_result_t diagnosticsRunTests(uint32_t start, uint32_t end, zes_diag_result_t *pResult) = 0;
@@ -44,7 +41,7 @@ struct DiagnosticsHandleContext {
     ze_result_t diagnosticsGet(uint32_t *pCount, zes_diag_handle_t *phDiagnostics);
     std::vector<std::string> supportedDiagTests = {};
     OsSysman *pOsSysman = nullptr;
-    std::vector<Diagnostics *> handleList = {};
+    std::vector<std::unique_ptr<Diagnostics>> handleList = {};
     bool isDiagnosticsInitDone() {
         return diagnosticsInitDone;
     }
