@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2021 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -14,16 +14,17 @@
 #include <level_zero/zes_api.h>
 namespace L0 {
 
-class EngineImp : public Engine, NEO::NonCopyableOrMovableClass {
+class EngineImp : public Engine, NEO::NonCopyableAndNonMovableClass {
   public:
     ze_result_t engineGetProperties(zes_engine_properties_t *pProperties) override;
     ze_result_t engineGetActivity(zes_engine_stats_t *pStats) override;
+    ze_result_t engineGetActivityExt(uint32_t *pCount, zes_engine_stats_t *pStats) override;
 
     EngineImp() = default;
-    EngineImp(OsSysman *pOsSysman, zes_engine_group_t engineType, uint32_t engineInstance, uint32_t subDeviceId);
+    EngineImp(OsSysman *pOsSysman, zes_engine_group_t engineType, uint32_t engineInstance, uint32_t subDeviceId, ze_bool_t onSubdevice);
     ~EngineImp() override;
 
-    OsEngine *pOsEngine = nullptr;
+    std::unique_ptr<OsEngine> pOsEngine = nullptr;
     void init();
 
   private:
