@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -17,7 +17,7 @@ namespace L0 {
 
 struct OsSysman;
 
-class FabricDeviceAccess : NEO::NonCopyableOrMovableClass {
+class FabricDeviceAccess : NEO::NonCopyableAndNonMovableClass {
   public:
     virtual ze_result_t getState(const zes_fabric_port_id_t portId, zes_fabric_port_state_t &state) = 0;
     virtual ze_result_t getThroughput(const zes_fabric_port_id_t portId, zes_fabric_port_throughput_t &througput) = 0;
@@ -36,6 +36,7 @@ class FabricDeviceAccess : NEO::NonCopyableOrMovableClass {
     virtual ze_result_t getPorts(std::vector<zes_fabric_port_id_t> &ports) = 0;
     virtual void getProperties(const zes_fabric_port_id_t portId, std::string &model, bool &onSubdevice,
                                uint32_t &subdeviceId, zes_fabric_port_speed_t &maxRxSpeed, zes_fabric_port_speed_t &maxTxSpeed) = 0;
+    virtual ze_result_t getMultiPortThroughput(std::vector<zes_fabric_port_id_t> &portIdList, zes_fabric_port_throughput_t **pThroughput) = 0;
 
     virtual ~FabricDeviceAccess() = default;
 
