@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020 Intel Corporation
+ * Copyright (C) 2020-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -9,6 +9,8 @@
 
 #include <level_zero/zes_api.h>
 
+#include <memory>
+
 namespace L0 {
 
 struct OsSysman;
@@ -21,7 +23,7 @@ class OsFan {
     virtual ze_result_t setSpeedTableMode(const zes_fan_speed_table_t *pSpeedTable) = 0;
     virtual ze_result_t getState(zes_fan_speed_units_t units, int32_t *pSpeed) = 0;
     virtual bool isFanModuleSupported() = 0;
-    static OsFan *create(OsSysman *pOsSysman);
+    static std::unique_ptr<OsFan> create(OsSysman *pOsSysman);
     virtual ~OsFan() = default;
 };
 
