@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -65,13 +65,14 @@ int FdCache::getFd(std::string file) {
 
 FdCache::~FdCache() {
     for (auto it = fdMap.begin(); it != fdMap.end(); ++it) {
-        NEO::SysCalls::close(it->second.second);
+        NEO::SysCalls::close(it->second.first);
     }
     fdMap.clear();
 }
 
 template <typename T>
 ze_result_t FsAccess::readValue(const std::string file, T &val) {
+    auto lock = this->obtainMutex();
 
     std::string readVal(64, '\0');
     int fd = pFdCache->getFd(file);
@@ -251,7 +252,7 @@ ze_result_t FsAccess::getRealPath(const std::string path, std::string &val) {
 
 ze_result_t FsAccess::listDirectory(const std::string path, std::vector<std::string> &list) {
     list.clear();
-    ::DIR *procDir = ::opendir(path.c_str());
+    ::DIR *procDir = NEO::SysCalls::opendir(path.c_str());
     if (!procDir) {
         return getResult(errno);
     }
@@ -259,7 +260,7 @@ ze_result_t FsAccess::listDirectory(const std::string path, std::vector<std::str
     int err = 0;
     // readdir doesn't clear errno, so make sure it is clear
     errno = 0;
-    while (NULL != (ent = ::readdir(procDir))) {
+    while (NULL != (ent = NEO::SysCalls::readdir(procDir))) {
         // Ignore . and ..
         std::string name = std::string(ent->d_name);
         if (!name.compare(".") || !name.compare("..")) {
@@ -270,7 +271,7 @@ ze_result_t FsAccess::listDirectory(const std::string path, std::vector<std::str
         errno = 0;
     }
     err = errno;
-    ::closedir(procDir);
+    NEO::SysCalls::closedir(procDir);
     // Check if in above while loop, readdir encountered any error.
     if ((err != 0) && (err != ENOENT)) {
         list.clear();
@@ -307,6 +308,10 @@ bool FsAccess::directoryExists(const std::string path) {
     return true;
 }
 
+std::unique_lock<std::mutex> FsAccess::obtainMutex() {
+    return std::unique_lock<std::mutex>(this->fsMutex);
+}
+
 // Procfs Access
 const std::string ProcfsAccess::procDir = "/proc/";
 const std::string ProcfsAccess::fdDir = "/fd/";
