@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -9,10 +9,11 @@
 
 #include "level_zero/tools/source/sysman/linux/nl_api/nl_api.h"
 
-#include "iaf/iaf_netlink.h"
+#include "iaf_netlink.h"
 
 #include <linux/types.h>
 #include <list>
+#include <mutex>
 #include <netlink/genl/genl.h>
 #include <netlink/genl/mngt.h>
 #include <vector>
@@ -145,6 +146,7 @@ class IafNlApi {
     struct nla_policy policy[_IAF_ATTR_COUNT] = {};
     struct genl_cmd cmds[_IAF_CMD_OP_COUNT] = {};
     struct genl_ops ops = {};
+    std::mutex iafMutex{};
 };
 
 } // namespace L0
