@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -40,7 +40,7 @@ class ExecutionEnvironmentRefCountRestore {
     NEO::ExecutionEnvironment *executionEnvironment = nullptr;
 };
 
-class LinuxSysmanImp : public OsSysman, NEO::NonCopyableOrMovableClass {
+class LinuxSysmanImp : public OsSysman, NEO::NonCopyableAndNonMovableClass {
   public:
     LinuxSysmanImp(SysmanDeviceImp *pParentSysmanDeviceImp);
     ~LinuxSysmanImp() override;
@@ -57,6 +57,7 @@ class LinuxSysmanImp : public OsSysman, NEO::NonCopyableOrMovableClass {
     Device *getDeviceHandle();
     std::vector<ze_device_handle_t> &getDeviceHandles() override;
     ze_device_handle_t getCoreDeviceHandle() override;
+    ze_bool_t isDriverModelSupported() override;
     SysmanDeviceImp *getSysmanDeviceImp();
     std::string getPciCardBusDirectoryPath(std::string realPciPath);
     uint32_t getMemoryType();
@@ -73,7 +74,7 @@ class LinuxSysmanImp : public OsSysman, NEO::NonCopyableOrMovableClass {
     MOCKABLE_VIRTUAL void getPidFdsForOpenDevice(ProcfsAccess *, SysfsAccess *, const ::pid_t, std::vector<int> &);
     MOCKABLE_VIRTUAL ze_result_t osWarmReset();
     MOCKABLE_VIRTUAL ze_result_t osColdReset();
-    ze_result_t gpuProcessCleanup();
+    MOCKABLE_VIRTUAL ze_result_t gpuProcessCleanup(ze_bool_t force);
     std::string getAddressFromPath(std::string &rootPortPath);
     decltype(&NEO::SysCalls::pread) preadFunction = NEO::SysCalls::pread;
     decltype(&NEO::SysCalls::pwrite) pwriteFunction = NEO::SysCalls::pwrite;
@@ -84,6 +85,7 @@ class LinuxSysmanImp : public OsSysman, NEO::NonCopyableOrMovableClass {
     bool isMemoryDiagnostics = false;
     Device *pDevice = nullptr;
     std::string gtDevicePath;
+    bool isUsingPrelimEnabledKmd = false;
 
   protected:
     FsAccess *pFsAccess = nullptr;
