@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -12,7 +12,7 @@
 
 namespace L0 {
 class KmdSysManager;
-class WddmPciImp : public OsPci, NEO::NonCopyableOrMovableClass {
+class WddmPciImp : public OsPci, NEO::NonCopyableAndNonMovableClass {
   public:
     ze_result_t getPciBdf(zes_pci_properties_t &pciProperties) override;
     void getMaxLinkCaps(double &maxLinkSpeed, int32_t &maxLinkWidth) override;
