@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2021 Intel Corporation
+ * Copyright (C) 2020-2022 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,6 +7,7 @@
 
 #include "shared/source/helpers/basic_math.h"
 
+#include "level_zero/tools/source/sysman/os_sysman.h"
 #include "level_zero/tools/source/sysman/ras/ras_imp.h"
 
 namespace L0 {
@@ -38,6 +39,10 @@ void RasHandleContext::init(std::vector<ze_device_handle_t> &deviceHandles) {
 }
 ze_result_t RasHandleContext::rasGet(uint32_t *pCount,
                                      zes_ras_handle_t *phRas) {
+    std::call_once(initRasOnce, [this]() {
+        this->init(pOsSysman->getDeviceHandles());
+        this->rasInitDone = true;
+    });
     uint32_t handleListSize = static_cast<uint32_t>(handleList.size());
     uint32_t numToCopy = std::min(*pCount, handleListSize);
     if (0 == *pCount || *pCount > handleListSize) {
