@@ -1,16 +1,15 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
-#include "shared/source/helpers/basic_math.h"
-#include "shared/source/helpers/debug_helpers.h"
-
 #include "level_zero/tools/source/sysman/os_sysman.h"
 #include "level_zero/tools/source/sysman/scheduler/scheduler_imp.h"
 
+#include <algorithm>
+
 class OsScheduler;
 namespace L0 {
 
@@ -19,14 +18,11 @@ SchedulerHandleContext::SchedulerHandleContext(OsSysman *pOsSysman) {
 }
 
 SchedulerHandleContext::~SchedulerHandleContext() {
-    for (Scheduler *pScheduler : handleList) {
-        delete pScheduler;
-    }
     handleList.clear();
 }
 void SchedulerHandleContext::createHandle(zes_engine_type_flag_t engineType, std::vector<std::string> &listOfEngines, ze_device_handle_t deviceHandle) {
-    Scheduler *pScheduler = new SchedulerImp(pOsSysman, engineType, listOfEngines, deviceHandle);
-    handleList.push_back(pScheduler);
+    std::unique_ptr<Scheduler> pScheduler = std::make_unique<SchedulerImp>(pOsSysman, engineType, listOfEngines, deviceHandle);
+    handleList.push_back(std::move(pScheduler));
 }
 
 void SchedulerHandleContext::init(std::vector<ze_device_handle_t> &deviceHandles) {
