@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,17 +8,17 @@
 #pragma once
 #include "shared/source/helpers/non_copyable_or_moveable.h"
 
-#include "sysman/temperature/os_temperature.h"
-#include "sysman/windows/os_sysman_imp.h"
+#include "level_zero/tools/source/sysman/temperature/os_temperature.h"
+#include "level_zero/tools/source/sysman/windows/os_sysman_imp.h"
 
 namespace L0 {
 class KmdSysManager;
-class WddmTemperatureImp : public OsTemperature, NEO::NonCopyableOrMovableClass {
+class WddmTemperatureImp : public OsTemperature, NEO::NonCopyableAndNonMovableClass {
   public:
     ze_result_t getProperties(zes_temp_properties_t *pProperties) override;
     ze_result_t getSensorTemperature(double *pTemperature) override;
     bool isTempModuleSupported() override;
-
+    uint32_t getNumTempDomainsSupported();
     void setSensorType(zes_temp_sensors_t sensorType);
     WddmTemperatureImp(OsSysman *pOsSysman);
     WddmTemperatureImp() = default;
