@@ -6,6 +6,8 @@
  */
 
 #pragma once
+#include "shared/source/helpers/non_copyable_or_moveable.h"
+
 #include "level_zero/api/sysman/zes_handles_struct.h"
 #include <level_zero/zes_api.h>
 
@@ -19,6 +21,7 @@ struct OsSysman;
 
 class VfManagement : _zes_vf_handle_t {
   public:
+    virtual ~VfManagement() = default;
     virtual ze_result_t vfGetCapabilities(zes_vf_exp2_capabilities_t *pCapability) = 0;
     virtual ze_result_t vfGetMemoryUtilization(uint32_t *pCount, zes_vf_util_mem_exp2_t *pMemUtil) = 0;
     virtual ze_result_t vfGetEngineUtilization(uint32_t *pCount, zes_vf_util_engine_exp2_t *pEngineUtil) = 0;
@@ -30,13 +33,9 @@ class VfManagement : _zes_vf_handle_t {
     }
 };
 
-struct VfManagementHandleContext {
+struct VfManagementHandleContext : NEO::NonCopyableAndNonMovableClass {
     VfManagementHandleContext(OsSysman *pOsSysman) : pOsSysman(pOsSysman){};
     ~VfManagementHandleContext();
-    VfManagementHandleContext(VfManagementHandleContext &&other) noexcept = delete;
-    VfManagementHandleContext(const VfManagementHandleContext &other) = delete;
-    VfManagementHandleContext &operator=(VfManagementHandleContext &&other) noexcept = delete;
-    VfManagementHandleContext &operator=(const VfManagementHandleContext &other) = delete;
 
     ze_result_t init();
 
@@ -50,4 +49,6 @@ struct VfManagementHandleContext {
     std::once_flag initVfManagementOnce;
 };
 
+static_assert(NEO::NonCopyableAndNonMovable<VfManagementHandleContext>);
+
 } // namespace L0
