@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,16 +7,17 @@
 
 #pragma once
 
-#include "shared/source/os_interface/os_interface.h"
-#include "shared/source/os_interface/windows/wddm/wddm.h"
+#include "shared/source/gmm_helper/gmm_lib.h"
 
 #include "level_zero/tools/source/sysman/windows/kmd_sys.h"
 #include "level_zero/ze_api.h"
-#include "level_zero/zet_api.h"
 
-#include <string>
 #include <vector>
 
+namespace NEO {
+class Wddm;
+}
+
 namespace L0 {
 class KmdSysManager {
   public:
@@ -29,7 +30,7 @@ class KmdSysManager {
     NEO::Wddm *GetWddmAccess() { return pWddmAccess; }
 
   private:
-    virtual bool escape(uint32_t escapeOp, uint64_t pDataIn, uint32_t dataInSize, uint64_t pDataOut, uint32_t dataOutSize);
+    virtual NTSTATUS escape(uint32_t escapeOp, uint64_t pDataIn, uint32_t dataInSize, uint64_t pDataOut, uint32_t dataOutSize);
 
     bool parseBufferIn(KmdSysman::GfxSysmanMainHeaderIn *pIn, std::vector<KmdSysman::RequestProperty> &vIn);
     bool parseBufferOut(KmdSysman::GfxSysmanMainHeaderOut *pOut, std::vector<KmdSysman::ResponseProperty> &vOut);
