@@ -70,6 +70,19 @@ bool getTestMachineConfiguration(TestMachineConfiguration &machineConfig) {
     deviceProperties.pNext = nullptr;
     VALIDATECALL(zeDeviceGetProperties(devices[0], &deviceProperties));
     machineConfig.deviceId = deviceProperties.deviceId;
+
+    uint32_t extensionsCount = 0;
+    VALIDATECALL(zeDriverGetExtensionProperties(driverHandle, &extensionsCount, nullptr));
+    if (extensionsCount != 0) {
+        machineConfig.driverExtensionsProperties.resize(extensionsCount);
+        VALIDATECALL(zeDriverGetExtensionProperties(driverHandle, &extensionsCount, machineConfig.driverExtensionsProperties.data()));
+
+        for (uint32_t i = 0; i < extensionsCount; i++) {
+            uint32_t supportedVersion = machineConfig.driverExtensionsProperties[i].version;
+            LOG(LogLevel::DEBUG) << "Extension #" << i << " name: " << machineConfig.driverExtensionsProperties[i].name << " version: " << ZE_MAJOR_VERSION(supportedVersion) << "." << ZE_MINOR_VERSION(supportedVersion) << std::endl;
+        }
+    }
+
     return true;
 }
 
