@@ -76,5 +76,58 @@ void MetricIpSamplingFixture::TearDown() {
     globalDriverHandles->clear();
 }
 
+void MetricIpSamplingCalculateBaseFixture::initCalcDescriptor() {
+    zet_intel_metric_scope_properties_exp_t scopeProperties{};
+    scopeProperties.stype = ZET_STRUCTURE_TYPE_INTEL_METRIC_SCOPE_PROPERTIES_EXP;
+    scopeProperties.pNext = nullptr;
+
+    mockMetricScope = new MockMetricScope(scopeProperties, false);
+    hMockScope = mockMetricScope->toHandle();
+
+    calculationDesc.stype = ZET_INTEL_STRUCTURE_TYPE_METRIC_CALCULATION_DESC_EXP;
+    calculationDesc.pNext = nullptr;                   // pNext
+    calculationDesc.metricGroupCount = 0;              // metricGroupCount
+    calculationDesc.phMetricGroups = nullptr;          // phMetricGroups
+    calculationDesc.metricCount = 0;                   // metricCount
+    calculationDesc.phMetrics = nullptr;               // phMetrics
+    calculationDesc.timeWindowsCount = 0;              // timeWindowsCount
+    calculationDesc.pCalculationTimeWindows = nullptr; // pCalculationTimeWindows
+    calculationDesc.timeAggregationWindow = 0;         // timeAggregationWindow
+    calculationDesc.metricScopesCount = 1;             // metricScopesCount
+    calculationDesc.phMetricScopes = &hMockScope;      // phMetricScopes
+}
+
+void MetricIpSamplingCalculateBaseFixture::cleanupCalcDescriptor() {
+    delete mockMetricScope;
+    hMockScope = nullptr;
+}
+
+void MetricIpSamplingCalculateMultiDevFixture::SetUp() {
+    MetricIpSamplingMultiDevFixture::SetUp();
+    initCalcDescriptor();
+}
+
+void MetricIpSamplingCalculateMultiDevFixture::TearDown() {
+    MetricIpSamplingMultiDevFixture::TearDown();
+    cleanupCalcDescriptor();
+}
+
+void MetricIpSamplingCalculateSingleDevFixture::SetUp() {
+    MetricIpSamplingFixture::SetUp();
+    initCalcDescriptor();
+
+    device->getMetricDeviceContext().enableMetricApi();
+    uint32_t metricGroupCount = 1;
+    zetMetricGroupGet(device->toHandle(), &metricGroupCount, &metricGroupHandle);
+
+    calculationDesc.metricGroupCount = 1;
+    calculationDesc.phMetricGroups = &metricGroupHandle;
+}
+
+void MetricIpSamplingCalculateSingleDevFixture::TearDown() {
+    MetricIpSamplingFixture::TearDown();
+    cleanupCalcDescriptor();
+}
+
 } // namespace ult
 } // namespace L0
