@@ -17,6 +17,11 @@ class MockMetricSource : public L0::MetricSource {
   public:
     uint32_t enableCallCount = 0;
     bool isAvailableReturn = false;
+    std::vector<std::pair<std::string, std::string>> testMetricScopeNames = {
+        {std::string(aggregatedScopeName), std::string(aggregatedScopeDescription)},
+        {std::string(computeScopeNamePrefix) + std::to_string(1), std::string(computeScopeDescriptionPrefix) + std::to_string(1)},
+        {std::string(computeScopeNamePrefix) + std::to_string(0), std::string(computeScopeDescriptionPrefix) + std::to_string(0)},
+        {std::string(computeScopeNamePrefix) + std::to_string(1), std::string(computeScopeDescriptionPrefix) + std::to_string(1)}};
     void enable() override { enableCallCount++; }
     bool isAvailable() override { return isAvailableReturn; }
     ze_result_t appendMetricMemoryBarrier(L0::CommandList &commandList) override { return ZE_RESULT_ERROR_UNKNOWN; }
@@ -50,18 +55,18 @@ class MockMetricSource : public L0::MetricSource {
     }
 
     ze_result_t calcOperationCreate(MetricDeviceContext &metricDeviceContext,
-                                    zet_intel_metric_calculate_exp_desc_t *pCalculateDesc,
-                                    uint32_t *pCount,
-                                    zet_metric_handle_t *phExcludedMetrics,
-                                    zet_intel_metric_calculate_operation_exp_handle_t *phCalculateOperation) override {
+                                    zet_intel_metric_calculation_exp_desc_t *pCalculationDesc,
+                                    const std::vector<MetricScopeImp *> &metricScopes,
+                                    zet_intel_metric_calculation_operation_exp_handle_t *phCalculationOperation) override {
         return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
     }
     bool canDisable() override { return false; }
     void initMetricScopes(MetricDeviceContext &metricDeviceContext) override {
-        if (!metricDeviceContext.isComputeMetricScopesInitialized()) {
-            initComputeMetricScopes(metricDeviceContext);
+        for (auto index = 0u; index < static_cast<uint32_t>(testMetricScopeNames.size()); index++) {
+            metricDeviceContext.addMetricScope(testMetricScopeNames[index].first, testMetricScopeNames[index].second);
         }
-    };
+        initComputeMetricScopes(metricDeviceContext);
+    }
 
     ~MockMetricSource() override = default;
 };
@@ -163,19 +168,15 @@ class MockMetric : public L0::MetricImp {
 class MockMetricCalcOp : public MetricCalcOpImp {
   public:
     ~MockMetricCalcOp() override = default;
-    MockMetricCalcOp() : MetricCalcOpImp(false){};
+    MockMetricCalcOp(bool multiDevice, const std::vector<MetricScopeImp *> &metricScopes,
+                     const std::vector<MetricImp *> &metricsInReport,
+                     const std::vector<MetricImp *> &excludedMetrics)
+        : MetricCalcOpImp(multiDevice, metricScopes, metricsInReport, excludedMetrics) {}
+
     ze_result_t destroy() override {
         return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
     };
-    ze_result_t getReportFormat(uint32_t *pCount, zet_metric_handle_t *phMetrics) override {
-        return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
-    };
-    ze_result_t metricCalculateMultipleValues(const size_t rawDataSize, size_t *offset, const uint8_t *pRawData,
-                                              uint32_t *pSetCount, uint32_t *pMetricReportCountPerSet,
-                                              uint32_t *pTotalMetricReportCount,
-                                              zet_intel_metric_result_exp_t *pMetricResults) override {
-        return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
-    };
+
     ze_result_t metricCalculateValues(const size_t rawDataSize, size_t *pOffset, const uint8_t *pRawData,
                                       uint32_t *pTotalMetricReportCount,
                                       zet_intel_metric_result_exp_t *pMetricResults) override {
@@ -206,8 +207,8 @@ class MockMetricDeviceContext : public MetricDeviceContext {
 class MockMetricScope : public MetricScopeImp {
   public:
     ~MockMetricScope() override = default;
-    MockMetricScope(zet_intel_metric_scope_properties_exp_t &properties)
-        : MetricScopeImp(properties) {}
+    MockMetricScope(zet_intel_metric_scope_properties_exp_t &properties, bool aggregated)
+        : MetricScopeImp(properties, aggregated) {}
     ze_result_t getProperties(zet_intel_metric_scope_properties_exp_t *pProperties) override {
         return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
     }
