@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2022 Intel Corporation
+ * Copyright (C) 2021-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -10,25 +10,19 @@
 #include "shared/test/common/test_macros/hw_test.h"
 
 #include "level_zero/core/test/unit_tests/fixtures/device_fixture.h"
+#include "level_zero/tools/source/sysman/linux/os_sysman_imp.h"
 #include "level_zero/tools/source/sysman/sysman.h"
 
-#include "sysman/linux/os_sysman_imp.h"
-
-using ::testing::_;
-using ::testing::NiceMock;
 using namespace NEO;
 
 namespace L0 {
 namespace ult {
 const std::string mockedDeviceName("/MOCK_DEVICE_NAME");
 
-class LinuxProcfsAccess : public ProcfsAccess {};
-
-template <>
-struct Mock<LinuxProcfsAccess> : public LinuxProcfsAccess {
+struct MockLinuxProcfsAccess : public ProcfsAccess {
     ::pid_t ourDevicePid = 0;
     int ourDeviceFd = 0;
-    ze_result_t getMockFileName(const ::pid_t pid, const int fd, std::string &val) {
+    ze_result_t getFileName(const ::pid_t pid, const int fd, std::string &val) override {
         if (pid == ourDevicePid && fd == ourDeviceFd) {
             val = mockedDeviceName;
         } else {
@@ -38,9 +32,7 @@ struct Mock<LinuxProcfsAccess> : public LinuxProcfsAccess {
         return ZE_RESULT_SUCCESS;
     }
 
-    Mock<LinuxProcfsAccess>() = default;
-
-    MOCK_METHOD(ze_result_t, getFileName, (const ::pid_t pid, const int fd, std::string &val), (override));
+    MockLinuxProcfsAccess() = default;
 };
 
 } // namespace ult
