@@ -36,7 +36,7 @@ struct Mock<PowerKmdSysManager> : public PowerKmdSysManager {
     uint64_t mockEnergyCounter64Bit = 32323232323232;
     uint32_t mockFrequencyTimeStamp = 38400000;
 
-    void getActivityProperty(KmdSysman::GfxSysmanReqHeaderIn *pRequest, KmdSysman::GfxSysmanReqHeaderOut *pResponse) {
+    void getActivityProperty(KmdSysman::GfxSysmanReqHeaderIn *pRequest, KmdSysman::GfxSysmanReqHeaderOut *pResponse) override {
         uint8_t *pBuffer = reinterpret_cast<uint8_t *>(pResponse);
         pBuffer += sizeof(KmdSysman::GfxSysmanReqHeaderOut);
 
@@ -148,8 +148,8 @@ struct Mock<PowerKmdSysManager> : public PowerKmdSysManager {
         case KmdSysman::Requests::Power::CurrentEnergyCounter64Bit: {
             uint64_t *pValueCounter = reinterpret_cast<uint64_t *>(pBuffer);
             uint64_t *pValueTS = reinterpret_cast<uint64_t *>(pBuffer + sizeof(uint64_t));
-            *pValueCounter = mockEnergyCounter64Bit;
-            *pValueTS = mockTimeStamp;
+            memcpy_s(pValueCounter, sizeof(uint64_t), &mockEnergyCounter64Bit, sizeof(mockEnergyCounter64Bit));
+            memcpy_s(pValueTS, sizeof(uint64_t), &mockTimeStamp, sizeof(mockEnergyCounter64Bit));
             pResponse->outReturnCode = KmdSysman::KmdSysmanSuccess;
             pResponse->outDataSize = sizeof(uint64_t) + sizeof(uint64_t);
         } break;
