@@ -348,40 +348,47 @@ CommandStreamReceiver &CommandQueue::selectCsrForBuiltinOperation(const CsrSelec
 }
 
 void CommandQueue::constructBcsEngine(bool internalUsage) {
-    if (bcsAllowed && !bcsInitialized) {
-        auto &gfxCoreHelper = device->getGfxCoreHelper();
-        auto &neoDevice = device->getNearestGenericSubDevice(0)->getDevice();
-        auto &selectorCopyEngine = neoDevice.getSelectorCopyEngine();
-        auto bcsEngineType = EngineHelpers::getBcsEngineType(device->getRootDeviceEnvironment(), device->getDeviceBitfield(), selectorCopyEngine, internalUsage);
-        auto bcsIndex = EngineHelpers::getBcsIndex(bcsEngineType);
-        auto engineUsage = (internalUsage && gfxCoreHelper.preferInternalBcsEngine()) ? EngineUsage::internal : EngineUsage::regular;
+    if (!bcsAllowed) {
+        return;
+    }
+    if (!bcsInitialized) {
+        const std::lock_guard lock{bcsInitMutex};
 
-        if (priority == QueuePriority::high) {
-            auto hpBcs = neoDevice.getHpCopyEngine();
+        if (!bcsInitialized) {
+            auto &gfxCoreHelper = device->getGfxCoreHelper();
+            auto &neoDevice = device->getNearestGenericSubDevice(0)->getDevice();
+            auto &selectorCopyEngine = neoDevice.getSelectorCopyEngine();
+            auto bcsEngineType = EngineHelpers::getBcsEngineType(device->getRootDeviceEnvironment(), device->getDeviceBitfield(), selectorCopyEngine, internalUsage);
+            auto bcsIndex = EngineHelpers::getBcsIndex(bcsEngineType);
+            auto engineUsage = (internalUsage && gfxCoreHelper.preferInternalBcsEngine()) ? EngineUsage::internal : EngineUsage::regular;
 
-            if (hpBcs) {
-                bcsEngineType = hpBcs->getEngineType();
-                engineUsage = EngineUsage::highPriority;
-                bcsIndex = EngineHelpers::getBcsIndex(bcsEngineType);
-                bcsEngines[bcsIndex] = hpBcs;
-            }
-        }
+            if (priority == QueuePriority::high) {
+                auto hpBcs = neoDevice.getHpCopyEngine();
 
-        if (bcsEngines[bcsIndex] == nullptr) {
-            bcsEngines[bcsIndex] = neoDevice.tryGetEngine(bcsEngineType, engineUsage);
-        }
-
-        if (bcsEngines[bcsIndex]) {
-            bcsQueueEngineType = bcsEngineType;
-
-            if (gfxCoreHelper.areSecondaryContextsSupported() && !internalUsage) {
-                tryAssignSecondaryEngine(device->getDevice(), bcsEngines[bcsIndex], {bcsEngineType, engineUsage});
+                if (hpBcs) {
+                    bcsEngineType = hpBcs->getEngineType();
+                    engineUsage = EngineUsage::highPriority;
+                    bcsIndex = EngineHelpers::getBcsIndex(bcsEngineType);
+                    bcsEngines[bcsIndex] = hpBcs;
+                }
             }
 
-            bcsEngines[bcsIndex]->osContext->ensureContextInitialized(false);
-            bcsEngines[bcsIndex]->commandStreamReceiver->initDirectSubmission();
+            if (bcsEngines[bcsIndex] == nullptr) {
+                bcsEngines[bcsIndex] = neoDevice.tryGetEngine(bcsEngineType, engineUsage);
+            }
+
+            if (bcsEngines[bcsIndex]) {
+                bcsQueueEngineType = bcsEngineType;
+
+                if (gfxCoreHelper.areSecondaryContextsSupported() && !internalUsage) {
+                    tryAssignSecondaryEngine(device->getDevice(), bcsEngines[bcsIndex], {bcsEngineType, engineUsage});
+                }
+
+                bcsEngines[bcsIndex]->osContext->ensureContextInitialized(false);
+                bcsEngines[bcsIndex]->commandStreamReceiver->initDirectSubmission();
+            }
+            bcsInitialized = true;
         }
-        bcsInitialized = true;
     }
 }
 
@@ -449,6 +456,10 @@ void CommandQueue::releaseMainCopyEngine() {
     }
 }
 
+bool CommandQueue::waitOnDestructionNeeded() const {
+    return (device && (getRefApiCount() == 1) && (taskCount < CompletionStamp::notReady));
+}
+
 Device &CommandQueue::getDevice() const noexcept {
     return device->getDevice();
 }
@@ -639,6 +650,11 @@ cl_int CommandQueue::enqueueReleaseSharedObjects(cl_uint numObjects, const cl_me
         return CL_INVALID_VALUE;
     }
 
+    Event::waitForEvents(numEventsInWaitList, eventWaitList);
+    if (!this->isOOQEnabled()) {
+        this->finish();
+    }
+
     bool isImageReleased = false;
     bool isDisplayableReleased = false;
     for (unsigned int object = 0; object < numObjects; object++) {
@@ -1022,7 +1038,7 @@ void CommandQueue::obtainNewTimestampPacketNodes(size_t numberOfNodes, Timestamp
     for (size_t i = 0; i < numberOfNodes; i++) {
         auto newTag = allocator->getTag();
 
-        if (csr.getType() != CommandStreamReceiverType::hardware) {
+        if (!csr.isHardwareMode()) {
             auto tagAlloc = newTag->getBaseGraphicsAllocation()->getGraphicsAllocation(csr.getRootDeviceIndex());
 
             // initialize full page tables for the first time
