@@ -23,6 +23,7 @@
 #include "opencl/source/helpers/properties_helper.h"
 
 #include <cstdint>
+#include <mutex>
 #include <optional>
 #include <span>
 
@@ -433,6 +434,20 @@ class CommandQueue : public BaseObject<_cl_command_queue> {
         return retVal;
     }
 
+    bool waitOnDestructionNeeded() const;
+
+    bool getL3FlushDeferredIfNeeded() const {
+        return l3FlushDeferredIfNeeded;
+    }
+
+    void setL3FlushDeferredIfNeeded(bool newValue) {
+        l3FlushDeferredIfNeeded = newValue;
+    }
+
+    void setCheckIfDeferredL3FlushIsNeeded(bool newValue) {
+        checkIfDeferredL3FlushIsNeeded = newValue;
+    }
+
   protected:
     void *enqueueReadMemObjForMap(TransferProperties &transferProperties, EventsRequest &eventsRequest, cl_int &errcodeRet);
     cl_int enqueueWriteMemObjForUnmap(MemObj *memObj, void *mappedPtr, EventsRequest &eventsRequest);
@@ -495,6 +510,7 @@ class CommandQueue : public BaseObject<_cl_command_queue> {
     mutable EngineControl *gpgpuEngine = nullptr;
     std::array<EngineControl *, bcsInfoMaskSize> bcsEngines = {};
     std::optional<aub_stream::EngineType> bcsQueueEngineType{};
+    std::mutex bcsInitMutex;
     size_t bcsEngineCount = bcsInfoMaskSize;
 
     cl_command_queue_properties commandQueueProperties = 0;
@@ -545,10 +561,11 @@ class CommandQueue : public BaseObject<_cl_command_queue> {
     bool heaplessModeEnabled = false;
     bool heaplessStateInitEnabled = false;
     bool isForceStateless = false;
-    bool l3FlushedAfterCpuRead = true;
     bool l3FlushAfterPostSyncEnabled = false;
     bool isWalkerWithProfilingEnqueued = false;
     bool shouldRegisterEnqueuedWalkerWithProfiling = false;
+    bool l3FlushDeferredIfNeeded = false;
+    bool checkIfDeferredL3FlushIsNeeded = false;
 };
 
 static_assert(NEO::NonCopyableAndNonMovable<CommandQueue>);
