@@ -6,14 +6,10 @@
  */
 
 #pragma once
-#include "shared/source/command_stream/command_stream_receiver.h"
-#include "shared/source/device/device.h"
+
 #include "shared/source/memory_manager/surface.h"
 
 #include "opencl/source/command_queue/command_queue_hw.h"
-#include "opencl/source/event/event.h"
-
-#include <new>
 
 namespace NEO {
 
