@@ -6,15 +6,8 @@
  */
 
 #pragma once
-#include "shared/source/command_stream/command_stream_receiver.h"
-#include "shared/source/device/device.h"
 
 #include "opencl/source/command_queue/command_queue_hw.h"
-#include "opencl/source/command_queue/gpgpu_walker.h"
-#include "opencl/source/event/event.h"
-#include "opencl/source/memory_manager/mem_obj_surface.h"
-
-#include <new>
 
 namespace NEO {
 
