@@ -25,17 +25,17 @@ cl_int CommandQueueHw<GfxFamily>::finish() {
 
     bool waitForTaskCountRequired = false;
 
-    if (!l3FlushedAfterCpuRead && l3FlushAfterPostSyncEnabled) {
+    if (l3FlushAfterPostSyncEnabled && this->checkIfDeferredL3FlushIsNeeded && this->l3FlushDeferredIfNeeded) {
         csr.flushTagUpdate();
 
         CompletionStamp completionStamp = {
             csr.peekTaskCount(),
-            csr.peekTaskLevel(),
+            std::max(this->taskLevel, csr.peekTaskLevel()),
             csr.obtainCurrentFlushStamp()};
 
         this->updateFromCompletionStamp(completionStamp, nullptr);
 
-        this->l3FlushedAfterCpuRead = true;
+        this->l3FlushDeferredIfNeeded = false;
         waitForTaskCountRequired = true;
     }
 
@@ -47,4 +47,5 @@ cl_int CommandQueueHw<GfxFamily>::finish() {
 
     return CL_SUCCESS;
 }
+
 } // namespace NEO
