@@ -148,6 +148,10 @@ class Context : public BaseObject<_cl_context> {
         return memoryManager;
     }
 
+    StagingBufferManager *getStagingBufferManager() const {
+        return stagingBufferManager;
+    }
+
     SVMAllocsManager *getSVMAllocsManager() const {
         return svmAllocsManager;
     }
@@ -251,14 +255,10 @@ class Context : public BaseObject<_cl_context> {
     TagAllocatorBase *getMultiRootDeviceTimestampPacketAllocator();
     std::unique_lock<std::mutex> obtainOwnershipForMultiRootDeviceAllocator();
     void setMultiRootDeviceTimestampPacketAllocator(std::unique_ptr<TagAllocatorBase> &allocator);
-    void setContextAsNonZebin();
-    bool checkIfContextIsNonZebin() const;
 
     void initializeUsmAllocationPools();
     void cleanupUsmAllocationPools();
 
-    StagingBufferManager *getStagingBufferManager() const;
-
   protected:
     struct BuiltInKernel {
         const char *pSource = nullptr;
@@ -287,6 +287,8 @@ class Context : public BaseObject<_cl_context> {
 
     void setupContextType();
 
+    virtual void initializeManagers();
+
     RootDeviceIndicesContainer rootDeviceIndices;
     std::map<uint32_t, DeviceBitfield> deviceBitfields;
     std::vector<std::unique_ptr<SharingFunctions>> sharingFunctions;
@@ -312,12 +314,12 @@ class Context : public BaseObject<_cl_context> {
     std::unique_ptr<TagAllocatorBase> multiRootDeviceTimestampPacketAllocator;
     std::mutex multiRootDeviceAllocatorMtx;
 
-    std::unique_ptr<StagingBufferManager> stagingBufferManager;
+    StagingBufferManager *stagingBufferManager = nullptr;
 
     bool interopUserSync = false;
     bool resolvesRequiredInKernels = false;
-    bool nonZebinContext = false;
     bool usmPoolInitialized = false;
+    bool platformManagersInitialized = false;
 };
 
 static_assert(NEO::NonCopyableAndNonMovable<Context>);
