@@ -142,9 +142,6 @@ class Image : public MemObj {
                         size_t *paramValueSizeRet);
 
     virtual void setImageArg(void *memory, bool isMediaBlockImage, uint32_t mipLevel, uint32_t rootDeviceIndex) = 0;
-    virtual void setMediaImageArg(void *memory, uint32_t rootDeviceIndex) = 0;
-    virtual void setMediaSurfaceRotation(void *memory) = 0;
-    virtual void setSurfaceMemoryObjectControlState(void *memory, uint32_t value) = 0;
 
     const cl_image_desc &getImageDesc() const;
     const cl_image_format &getImageFormat() const;
@@ -343,9 +340,6 @@ class ImageHw : public Image {
 
     void setImageArg(void *memory, bool setAsMediaBlockImage, uint32_t mipLevel, uint32_t rootDeviceIndex) override;
     void setAuxParamsForMultisamples(RENDER_SURFACE_STATE *surfaceState, uint32_t rootDeviceIndex);
-    void setMediaImageArg(void *memory, uint32_t rootDeviceIndex) override;
-    void setMediaSurfaceRotation(void *memory) override;
-    void setSurfaceMemoryObjectControlState(void *memory, uint32_t value) override;
     void appendSurfaceStateParams(RENDER_SURFACE_STATE *surfaceState, uint32_t rootDeviceIndex);
     void appendSurfaceStateDepthParams(RENDER_SURFACE_STATE *surfaceState, Gmm *gmm);
     void appendSurfaceStateExt(void *memory);
