@@ -1,11 +1,12 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
+
 #include "shared/source/helpers/bit_helpers.h"
 #include "shared/source/memory_manager/memory_manager.h"
 #include "shared/source/memory_manager/unified_memory_manager.h"
@@ -18,6 +19,9 @@
 namespace NEO {
 
 class Context;
+struct HardwareInfo;
+struct ImageInfo;
+struct MemoryProperties;
 
 class MemObjHelper {
   public:
