@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,15 +7,12 @@
 
 #include "shared/source/helpers/get_info.h"
 
-#include "shared/source/compiler_interface/external_functions.h"
-#include "shared/source/device/device.h"
 #include "shared/source/device_binary_format/device_binary_formats.h"
 #include "shared/source/program/kernel_info.h"
 
 #include "opencl/source/cl_device/cl_device.h"
 #include "opencl/source/context/context.h"
 #include "opencl/source/helpers/base_object.h"
-#include "opencl/source/helpers/cl_validators.h"
 #include "opencl/source/helpers/get_info_status_mapper.h"
 
 #include "program.h"
@@ -64,7 +61,7 @@ cl_int Program::getInfo(cl_program_info paramName, size_t paramValueSize,
             auto binarySize = buildInfos[rootDeviceIndex].packedDeviceBinarySize;
             memcpy_s(outputBinaries[i], binarySize, buildInfos[rootDeviceIndex].packedDeviceBinary.get(), binarySize);
         }
-        GetInfo::setParamValueReturnSize(paramValueSizeRet, requiredSize, GetInfoStatus::SUCCESS);
+        GetInfo::setParamValueReturnSize(paramValueSizeRet, requiredSize, GetInfoStatus::success);
         return CL_SUCCESS;
     } break;
 
@@ -117,7 +114,7 @@ cl_int Program::getInfo(cl_program_info paramName, size_t paramValueSize,
         break;
 
     case CL_PROGRAM_SOURCE:
-        if (createdFrom == CreatedFrom::SOURCE) {
+        if (createdFrom == CreatedFrom::source) {
             pSrc = sourceCode.c_str();
             retSize = srcSize = strlen(sourceCode.c_str()) + 1;
         } else {
@@ -129,7 +126,7 @@ cl_int Program::getInfo(cl_program_info paramName, size_t paramValueSize,
         break;
 
     case CL_PROGRAM_IL:
-        if (createdFrom != CreatedFrom::IL) {
+        if (createdFrom != CreatedFrom::il) {
             if (paramValueSizeRet) {
                 *paramValueSizeRet = 0;
             }
@@ -144,7 +141,7 @@ cl_int Program::getInfo(cl_program_info paramName, size_t paramValueSize,
             auto rootDeviceIndex = clDevices[i]->getRootDeviceIndex();
             if (nullptr == buildInfos[rootDeviceIndex].debugData) {
                 auto refBin = ArrayRef<const uint8_t>(reinterpret_cast<const uint8_t *>(buildInfos[rootDeviceIndex].unpackedDeviceBinary.get()), buildInfos[rootDeviceIndex].unpackedDeviceBinarySize);
-                if (isDeviceBinaryFormat<DeviceBinaryFormat::Zebin>(refBin)) {
+                if (isDeviceBinaryFormat<DeviceBinaryFormat::zebin>(refBin)) {
                     createDebugZebin(rootDeviceIndex);
                 } else
                     continue;
@@ -171,7 +168,7 @@ cl_int Program::getInfo(cl_program_info paramName, size_t paramValueSize,
             auto rootDeviceIndex = clDevices[i]->getRootDeviceIndex();
             if (nullptr == buildInfos[rootDeviceIndex].debugData) {
                 auto refBin = ArrayRef<const uint8_t>(reinterpret_cast<const uint8_t *>(buildInfos[rootDeviceIndex].unpackedDeviceBinary.get()), buildInfos[rootDeviceIndex].unpackedDeviceBinarySize);
-                if (isDeviceBinaryFormat<DeviceBinaryFormat::Zebin>(refBin)) {
+                if (isDeviceBinaryFormat<DeviceBinaryFormat::zebin>(refBin)) {
                     createDebugZebin(rootDeviceIndex);
                 } else
                     continue;
@@ -179,7 +176,7 @@ cl_int Program::getInfo(cl_program_info paramName, size_t paramValueSize,
             auto dbgDataSize = buildInfos[rootDeviceIndex].debugDataSize;
             memcpy_s(outputDebugData[i], dbgDataSize, buildInfos[rootDeviceIndex].debugData.get(), dbgDataSize);
         }
-        GetInfo::setParamValueReturnSize(paramValueSizeRet, requiredSize, GetInfoStatus::SUCCESS);
+        GetInfo::setParamValueReturnSize(paramValueSizeRet, requiredSize, GetInfoStatus::success);
         return CL_SUCCESS;
     } break;
 
@@ -194,7 +191,7 @@ cl_int Program::getInfo(cl_program_info paramName, size_t paramValueSize,
         break;
     }
 
-    auto getInfoStatus = GetInfoStatus::INVALID_VALUE;
+    auto getInfoStatus = GetInfoStatus::invalidValue;
     if (retVal == CL_SUCCESS) {
         getInfoStatus = GetInfo::getInfo(paramValue, paramValueSize, pSrc, srcSize);
         retVal = changeGetInfoStatusToCLResultType(getInfoStatus);
@@ -246,7 +243,7 @@ cl_int Program::getBuildInfo(cl_device_id device, cl_program_build_info paramNam
         break;
     }
 
-    auto getInfoStatus = GetInfoStatus::INVALID_VALUE;
+    auto getInfoStatus = GetInfoStatus::invalidValue;
     if (retVal == CL_SUCCESS) {
         getInfoStatus = GetInfo::getInfo(paramValue, paramValueSize, pSrc, srcSize);
         retVal = changeGetInfoStatusToCLResultType(getInfoStatus);
