@@ -1,11 +1,11 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
-#include "shared/test/common/test_macros/test.h"
+#include "shared/test/common/test_macros/hw_test.h"
 
 #include "opencl/test/unit_test/aub_tests/fixtures/aub_fixture.h"
 #include "opencl/test/unit_test/fixtures/hello_world_kernel_fixture.h"
@@ -33,7 +33,7 @@ class AUBPrintfKernelFixture : public AUBFixture,
         HelloWorldKernelFixture::tearDown();
         AUBFixture::tearDown();
     }
-    const char *programFile = "printf";
+    const char *programFile = "simple_kernels";
     const char *kernelName = "test_printf_number";
 };
 
@@ -57,4 +57,4 @@ HWTEST_F(AUBPrintfKernelFixture, GivenPrintfKernelThenEnqueuingSucceeds) {
 
     pCmdQ->enqueueKernel(pKernel, 1, offset, gws, lws, 0, 0, 0);
     pCmdQ->finish();
-}
\ No newline at end of file
+}
