@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -271,12 +271,12 @@ static cl_mem_flags copyHostPtrFlags[] = {
 using UseHostPtrTest = AUBCreateImageHostPtr;
 using CopyHostPtrTest = AUBCreateImageHostPtr;
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreateImgTest_UseHostPtr,
     UseHostPtrTest,
     testing::ValuesIn(useHostPtrFlags));
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreateImgTest_CopyHostPtr,
     CopyHostPtrTest,
     testing::ValuesIn(copyHostPtrFlags));
