@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -16,10 +16,6 @@
 
 using XeHpcCoreAubMemDumpTests = Test<NEO::ClDeviceFixture>;
 
-XE_HPC_CORETEST_F(XeHpcCoreAubMemDumpTests, GivenCcsThenExpectationsAreMet) {
-    setupAUB<FamilyType>(pDevice, aub_stream::ENGINE_CCS);
-}
-
 XE_HPC_CORETEST_F(XeHpcCoreAubMemDumpTests, whenAubCsrIsCreatedThenCreateHardwareContext) {
     DebugManagerStateRestore restore;
     VariableBackup<UltHwConfig> backup(&ultHwConfig);
