@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -13,7 +13,7 @@
 
 #include "opencl/source/api/api.h"
 #include "opencl/test/unit_test/aub_tests/fixtures/aub_fixture.h"
-#include "opencl/test/unit_test/aub_tests/fixtures/multicontext_aub_fixture.h"
+#include "opencl/test/unit_test/aub_tests/fixtures/multicontext_ocl_aub_fixture.h"
 #include "opencl/test/unit_test/fixtures/program_fixture.h"
 #include "opencl/test/unit_test/mocks/mock_kernel.h"
 
@@ -23,9 +23,9 @@ class SystemMemFenceViaMiMemFence : public AUBFixture,
                                     public ::testing::Test {
   public:
     void SetUp() override {
-        DebugManager.flags.ProgramGlobalFenceAsMiMemFenceCommandInCommandStream.set(1);
-        DebugManager.flags.ProgramGlobalFenceAsPostSyncOperationInComputeWalker.set(0);
-        DebugManager.flags.ProgramGlobalFenceAsKernelInstructionInEUKernel.set(0);
+        debugManager.flags.ProgramGlobalFenceAsMiMemFenceCommandInCommandStream.set(1);
+        debugManager.flags.ProgramGlobalFenceAsPostSyncOperationInComputeWalker.set(0);
+        debugManager.flags.ProgramGlobalFenceAsKernelInstructionInEUKernel.set(0);
         AUBFixture::setUp(defaultHwInfo.get());
     }
     void TearDown() override {
@@ -69,9 +69,9 @@ class SystemMemFenceViaComputeWalker : public AUBFixture,
                                        public ::testing::Test {
   public:
     void SetUp() override {
-        DebugManager.flags.ProgramGlobalFenceAsMiMemFenceCommandInCommandStream.set(0);
-        DebugManager.flags.ProgramGlobalFenceAsPostSyncOperationInComputeWalker.set(1);
-        DebugManager.flags.ProgramGlobalFenceAsKernelInstructionInEUKernel.set(0);
+        debugManager.flags.ProgramGlobalFenceAsMiMemFenceCommandInCommandStream.set(0);
+        debugManager.flags.ProgramGlobalFenceAsPostSyncOperationInComputeWalker.set(1);
+        debugManager.flags.ProgramGlobalFenceAsKernelInstructionInEUKernel.set(0);
         AUBFixture::setUp(defaultHwInfo.get());
     }
     void TearDown() override {
@@ -111,21 +111,21 @@ XE_HPC_CORETEST_F(SystemMemFenceViaComputeWalker, givenSystemMemFenceWhenPostSyn
     EXPECT_EQ(CL_SUCCESS, retVal);
 }
 
-class SystemMemFenceWithBlitter : public MulticontextAubFixture,
+class SystemMemFenceWithBlitter : public MulticontextOclAubFixture,
                                   public ::testing::Test {
   public:
     void SetUp() override {
-        DebugManager.flags.ProgramGlobalFenceAsMiMemFenceCommandInCommandStream.set(1);
-        DebugManager.flags.ProgramGlobalFenceAsPostSyncOperationInComputeWalker.set(0);
-        DebugManager.flags.ProgramGlobalFenceAsKernelInstructionInEUKernel.set(0);
+        debugManager.flags.ProgramGlobalFenceAsMiMemFenceCommandInCommandStream.set(1);
+        debugManager.flags.ProgramGlobalFenceAsPostSyncOperationInComputeWalker.set(0);
+        debugManager.flags.ProgramGlobalFenceAsKernelInstructionInEUKernel.set(0);
 
-        DebugManager.flags.EnableBlitterOperationsSupport.set(1);
-        DebugManager.flags.EnableBlitterForEnqueueOperations.set(1);
+        debugManager.flags.EnableBlitterOperationsSupport.set(1);
+        debugManager.flags.EnableBlitterForEnqueueOperations.set(1);
 
-        MulticontextAubFixture::setUp(1, EnabledCommandStreamers::Single, true);
+        MulticontextOclAubFixture::setUp(1, EnabledCommandStreamers::single, true);
     }
     void TearDown() override {
-        MulticontextAubFixture::tearDown();
+        MulticontextOclAubFixture::tearDown();
     }
 
     DebugManagerStateRestore debugRestorer;
@@ -162,19 +162,19 @@ XE_HPC_CORETEST_F(SystemMemFenceWithBlitter, givenSystemMemFenceWhenGeneratedAsM
 }
 
 class SystemMemFenceViaKernel : public ProgramFixture,
-                                public MulticontextAubFixture,
+                                public MulticontextOclAubFixture,
                                 public ::testing::Test {
   public:
     void SetUp() override {
-        DebugManager.flags.ProgramGlobalFenceAsMiMemFenceCommandInCommandStream.set(0);
-        DebugManager.flags.ProgramGlobalFenceAsPostSyncOperationInComputeWalker.set(0);
-        DebugManager.flags.ProgramGlobalFenceAsKernelInstructionInEUKernel.set(1);
+        debugManager.flags.ProgramGlobalFenceAsMiMemFenceCommandInCommandStream.set(0);
+        debugManager.flags.ProgramGlobalFenceAsPostSyncOperationInComputeWalker.set(0);
+        debugManager.flags.ProgramGlobalFenceAsKernelInstructionInEUKernel.set(1);
 
         ProgramFixture::setUp();
-        MulticontextAubFixture::setUp(1, EnabledCommandStreamers::Single, true);
+        MulticontextOclAubFixture::setUp(1, EnabledCommandStreamers::single, true);
     }
     void TearDown() override {
-        MulticontextAubFixture::tearDown();
+        MulticontextOclAubFixture::tearDown();
         ProgramFixture::tearDown();
     }
 
@@ -217,7 +217,7 @@ XE_HPC_CORETEST_F(SystemMemFenceViaKernel, givenSystemMemFenceWhenKernelInstruct
     retVal = clSetKernelArgSVMPointer(pMultiDeviceKernel.get(), 1, hostMemAlloc);
     ASSERT_EQ(CL_SUCCESS, retVal);
 
-    size_t globalWorkSize[3] = {bufferSize, 1, 1};
+    size_t globalWorkSize[3] = {bufferSize / sizeof(cl_int), 1, 1};
     retVal = commandQueues[0][0]->enqueueKernel(pMultiDeviceKernel->getKernel(rootDeviceIndex), 1, nullptr, globalWorkSize, nullptr, 0, nullptr, nullptr);
     ASSERT_EQ(CL_SUCCESS, retVal);
 
