@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -25,6 +25,7 @@ std::vector<std::string> imageBuiltInFileNames = {
     "copy_image_to_image2d.builtin_kernel",
     "copy_image_to_image3d.builtin_kernel",
     "copy_buffer_to_image3d.builtin_kernel",
-    "copy_image3d_to_buffer.builtin_kernel"};
+    "copy_image3d_to_buffer.builtin_kernel",
+    "fill_image1d_buffer.builtin_kernel"};
 
 } // namespace NEO
