@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -38,7 +38,7 @@ struct BlitEnqueueTests : public ::testing::Test {
     class BcsMockContext : public MockContext {
       public:
         BcsMockContext(ClDevice *device) : MockContext(device) {
-            bcsOsContext.reset(OsContext::create(nullptr, device->getRootDeviceIndex(), 0, EngineDescriptorHelper::getDefaultDescriptor({aub_stream::ENGINE_BCS, EngineUsage::Regular})));
+            bcsOsContext.reset(OsContext::create(nullptr, device->getRootDeviceIndex(), 0, EngineDescriptorHelper::getDefaultDescriptor({aub_stream::ENGINE_BCS, EngineUsage::regular})));
             bcsCsr.reset(createCommandStream(*device->getExecutionEnvironment(), device->getRootDeviceIndex(), device->getDeviceBitfield()));
             bcsCsr->setupContext(*bcsOsContext);
             bcsCsr->initializeTagAllocation();
@@ -46,10 +46,10 @@ struct BlitEnqueueTests : public ::testing::Test {
             auto mockBlitMemoryToAllocation = [this](const Device &device, GraphicsAllocation *memory, size_t offset, const void *hostPtr,
                                                      Vec3<size_t> size) -> BlitOperationResult {
                 if (!device.getRootDeviceEnvironment().getMutableHardwareInfo()->capabilityTable.blitterOperationsSupported) {
-                    return BlitOperationResult::Unsupported;
+                    return BlitOperationResult::unsupported;
                 }
 
-                auto blitProperties = BlitProperties::constructPropertiesForReadWrite(BlitterConstants::BlitDirection::HostPtrToBuffer,
+                auto blitProperties = BlitProperties::constructPropertiesForReadWrite(BlitterConstants::BlitDirection::hostPtrToBuffer,
                                                                                       *bcsCsr, memory, nullptr,
                                                                                       hostPtr,
                                                                                       memory->getGpuAddress(), 0,
@@ -57,9 +57,9 @@ struct BlitEnqueueTests : public ::testing::Test {
 
                 BlitPropertiesContainer container;
                 container.push_back(blitProperties);
-                bcsCsr->flushBcsTask(container, true, false, const_cast<Device &>(device));
+                bcsCsr->flushBcsTask(container, true, const_cast<Device &>(device));
 
-                return BlitOperationResult::Success;
+                return BlitOperationResult::success;
             };
             blitMemoryToAllocationFuncBackup = mockBlitMemoryToAllocation;
         }
@@ -76,13 +76,13 @@ struct BlitEnqueueTests : public ::testing::Test {
             GTEST_SKIP();
         }
 
-        DebugManager.flags.EnableTimestampPacket.set(timestampPacketEnabled);
-        DebugManager.flags.EnableBlitterForEnqueueOperations.set(1);
-        DebugManager.flags.ForceAuxTranslationMode.set(static_cast<int32_t>(AuxTranslationMode::Blit));
-        DebugManager.flags.RenderCompressedBuffersEnabled.set(1);
-        DebugManager.flags.ForceGpgpuSubmissionForBcsEnqueue.set(1);
-        DebugManager.flags.CsrDispatchMode.set(static_cast<int32_t>(DispatchMode::ImmediateDispatch));
-        DebugManager.flags.EnableLocalMemory.set(1);
+        debugManager.flags.EnableTimestampPacket.set(timestampPacketEnabled);
+        debugManager.flags.EnableBlitterForEnqueueOperations.set(1);
+        debugManager.flags.ForceAuxTranslationMode.set(static_cast<int32_t>(AuxTranslationMode::blit));
+        debugManager.flags.RenderCompressedBuffersEnabled.set(1);
+        debugManager.flags.ForceGpgpuSubmissionForBcsEnqueue.set(1);
+        debugManager.flags.CsrDispatchMode.set(static_cast<int32_t>(DispatchMode::immediateDispatch));
+        debugManager.flags.EnableLocalMemory.set(1);
 
         device = std::make_unique<MockClDevice>(MockClDevice::createWithNewExecutionEnvironment<MockDevice>(nullptr));
 
@@ -97,9 +97,9 @@ struct BlitEnqueueTests : public ::testing::Test {
             GTEST_SKIP();
         }
         if (createBcsEngine) {
-            auto &engine = device->getEngine(getChosenEngineType(device->getHardwareInfo()), EngineUsage::LowPriority);
+            auto &engine = device->getEngine(getChosenEngineType(device->getHardwareInfo()), EngineUsage::lowPriority);
             bcsOsContext.reset(OsContext::create(nullptr, device->getRootDeviceIndex(), 1,
-                                                 EngineDescriptorHelper::getDefaultDescriptor({aub_stream::ENGINE_BCS, EngineUsage::Regular}, device->getDeviceBitfield())));
+                                                 EngineDescriptorHelper::getDefaultDescriptor({aub_stream::ENGINE_BCS, EngineUsage::regular}, device->getDeviceBitfield())));
             engine.osContext = bcsOsContext.get();
             engine.commandStreamReceiver->setupContext(*bcsOsContext);
         }
@@ -117,8 +117,8 @@ struct BlitEnqueueTests : public ::testing::Test {
     template <typename FamilyType>
     void tearDownT() {}
 
-    template <size_t N>
-    void setMockKernelArgs(std::array<Buffer *, N> buffers) {
+    template <size_t n>
+    void setMockKernelArgs(std::array<Buffer *, n> buffers) {
         for (uint32_t i = 0; i < buffers.size(); i++) {
             mockKernel->kernelInfo.addArgBuffer(i, 0);
         }
@@ -132,8 +132,8 @@ struct BlitEnqueueTests : public ::testing::Test {
         }
     }
 
-    template <size_t N>
-    void setMockKernelArgs(std::array<GraphicsAllocation *, N> allocs) {
+    template <size_t n>
+    void setMockKernelArgs(std::array<GraphicsAllocation *, n> allocs) {
         for (uint32_t i = 0; i < allocs.size(); i++) {
             mockKernel->kernelInfo.addArgBuffer(i, 0);
         }
@@ -164,16 +164,18 @@ struct BlitEnqueueTests : public ::testing::Test {
     }
 
     void setAllocationType(GraphicsAllocation *graphicsAllocation, bool compressed) {
-        graphicsAllocation->setAllocationType(AllocationType::BUFFER);
+        graphicsAllocation->setAllocationType(AllocationType::buffer);
 
         if (compressed && !graphicsAllocation->getDefaultGmm()) {
             auto gmmHelper = device->getRootDeviceEnvironment().getGmmHelper();
-
-            graphicsAllocation->setDefaultGmm(new Gmm(gmmHelper, nullptr, 0, 0, GMM_RESOURCE_USAGE_OCL_BUFFER, false, {}, true));
+            GmmRequirements gmmRequirements{};
+            gmmRequirements.allowLargePages = true;
+            gmmRequirements.preferCompressed = false;
+            graphicsAllocation->setDefaultGmm(new Gmm(gmmHelper, nullptr, 0, 0, GMM_RESOURCE_USAGE_OCL_BUFFER, {}, gmmRequirements));
         }
 
         if (graphicsAllocation->getDefaultGmm()) {
-            graphicsAllocation->getDefaultGmm()->isCompressionEnabled = compressed;
+            graphicsAllocation->getDefaultGmm()->setCompressionEnabled(compressed);
         }
     }
 
