@@ -23,55 +23,55 @@ TEST(CsrSelectionArgsTests, givenBuffersWhenCreatingCsrSelectionArgsThenSetupArg
     MockBuffer buffer2{allocation2};
 
     {
-        allocation1.memoryPool = MemoryPool::System4KBPages;
+        allocation1.memoryPool = MemoryPool::system4KBPages;
         CsrSelectionArgs args{CL_COMMAND_WRITE_BUFFER, {}, &buffer1, rootDeviceIndex, size};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_WRITE_BUFFER), args.cmdType);
-        EXPECT_EQ(TransferDirection::HostToHost, args.direction);
+        EXPECT_EQ(TransferDirection::hostToHost, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&allocation1, args.dstResource.allocation);
     }
     {
-        allocation1.memoryPool = MemoryPool::LocalMemory;
+        allocation1.memoryPool = MemoryPool::localMemory;
         CsrSelectionArgs args{CL_COMMAND_WRITE_BUFFER, {}, &buffer1, rootDeviceIndex, size};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_WRITE_BUFFER), args.cmdType);
-        EXPECT_EQ(TransferDirection::HostToLocal, args.direction);
+        EXPECT_EQ(TransferDirection::hostToLocal, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&allocation1, args.dstResource.allocation);
     }
 
     {
-        allocation1.memoryPool = MemoryPool::LocalMemory;
+        allocation1.memoryPool = MemoryPool::localMemory;
         CsrSelectionArgs args{CL_COMMAND_READ_BUFFER, &buffer1, {}, rootDeviceIndex, size};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_READ_BUFFER), args.cmdType);
-        EXPECT_EQ(TransferDirection::LocalToHost, args.direction);
+        EXPECT_EQ(TransferDirection::localToHost, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
     }
     {
-        allocation1.memoryPool = MemoryPool::System4KBPages;
+        allocation1.memoryPool = MemoryPool::system4KBPages;
         CsrSelectionArgs args{CL_COMMAND_READ_BUFFER, &buffer1, {}, rootDeviceIndex, size};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_READ_BUFFER), args.cmdType);
-        EXPECT_EQ(TransferDirection::HostToHost, args.direction);
+        EXPECT_EQ(TransferDirection::hostToHost, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
     }
 
     {
-        allocation1.memoryPool = MemoryPool::LocalMemory;
-        allocation2.memoryPool = MemoryPool::System4KBPages;
+        allocation1.memoryPool = MemoryPool::localMemory;
+        allocation2.memoryPool = MemoryPool::system4KBPages;
         CsrSelectionArgs args{CL_COMMAND_COPY_BUFFER, &buffer1, &buffer2, rootDeviceIndex, size};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_COPY_BUFFER), args.cmdType);
-        EXPECT_EQ(TransferDirection::LocalToHost, args.direction);
+        EXPECT_EQ(TransferDirection::localToHost, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
         EXPECT_EQ(&allocation2, args.dstResource.allocation);
     }
     {
-        allocation1.memoryPool = MemoryPool::System4KBPages;
-        allocation2.memoryPool = MemoryPool::LocalMemory;
+        allocation1.memoryPool = MemoryPool::system4KBPages;
+        allocation2.memoryPool = MemoryPool::localMemory;
         CsrSelectionArgs args{CL_COMMAND_COPY_BUFFER, &buffer1, &buffer2, rootDeviceIndex, size};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_COPY_BUFFER), args.cmdType);
-        EXPECT_EQ(TransferDirection::HostToLocal, args.direction);
+        EXPECT_EQ(TransferDirection::hostToLocal, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
         EXPECT_EQ(&allocation2, args.dstResource.allocation);
@@ -90,20 +90,20 @@ TEST(CsrSelectionArgsTests, givenImagesWhenCreatingCsrSelectionArgsThenSetupArgs
     MockGraphicsAllocation &allocation2 = *image2.graphicsAllocation;
 
     {
-        allocation1.memoryPool = MemoryPool::System4KBPages;
+        allocation1.memoryPool = MemoryPool::system4KBPages;
         CsrSelectionArgs args{CL_COMMAND_WRITE_IMAGE, {}, &image1, rootDeviceIndex, size, nullptr, origin1};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_WRITE_IMAGE), args.cmdType);
-        EXPECT_EQ(TransferDirection::HostToHost, args.direction);
+        EXPECT_EQ(TransferDirection::hostToHost, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&image1, args.dstResource.image);
         EXPECT_EQ(&allocation1, args.dstResource.allocation);
         EXPECT_EQ(origin1, args.dstResource.imageOrigin);
     }
     {
-        allocation1.memoryPool = MemoryPool::LocalMemory;
+        allocation1.memoryPool = MemoryPool::localMemory;
         CsrSelectionArgs args{CL_COMMAND_WRITE_IMAGE, {}, &image1, rootDeviceIndex, size, nullptr, origin1};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_WRITE_IMAGE), args.cmdType);
-        EXPECT_EQ(TransferDirection::HostToLocal, args.direction);
+        EXPECT_EQ(TransferDirection::hostToLocal, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&image1, args.dstResource.image);
         EXPECT_EQ(&allocation1, args.dstResource.allocation);
@@ -111,20 +111,20 @@ TEST(CsrSelectionArgsTests, givenImagesWhenCreatingCsrSelectionArgsThenSetupArgs
     }
 
     {
-        allocation1.memoryPool = MemoryPool::System4KBPages;
+        allocation1.memoryPool = MemoryPool::system4KBPages;
         CsrSelectionArgs args{CL_COMMAND_READ_IMAGE, &image1, nullptr, rootDeviceIndex, size, origin1, nullptr};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_READ_IMAGE), args.cmdType);
-        EXPECT_EQ(TransferDirection::HostToHost, args.direction);
+        EXPECT_EQ(TransferDirection::hostToHost, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&image1, args.srcResource.image);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
         EXPECT_EQ(origin1, args.srcResource.imageOrigin);
     }
     {
-        allocation1.memoryPool = MemoryPool::LocalMemory;
+        allocation1.memoryPool = MemoryPool::localMemory;
         CsrSelectionArgs args{CL_COMMAND_READ_IMAGE, &image1, nullptr, rootDeviceIndex, size, origin1, nullptr};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_READ_IMAGE), args.cmdType);
-        EXPECT_EQ(TransferDirection::LocalToHost, args.direction);
+        EXPECT_EQ(TransferDirection::localToHost, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&image1, args.srcResource.image);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
@@ -132,11 +132,11 @@ TEST(CsrSelectionArgsTests, givenImagesWhenCreatingCsrSelectionArgsThenSetupArgs
     }
 
     {
-        allocation1.memoryPool = MemoryPool::System4KBPages;
-        allocation2.memoryPool = MemoryPool::LocalMemory;
+        allocation1.memoryPool = MemoryPool::system4KBPages;
+        allocation2.memoryPool = MemoryPool::localMemory;
         CsrSelectionArgs args{CL_COMMAND_COPY_IMAGE, &image1, &image2, rootDeviceIndex, size, origin1, origin2};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_COPY_IMAGE), args.cmdType);
-        EXPECT_EQ(TransferDirection::HostToLocal, args.direction);
+        EXPECT_EQ(TransferDirection::hostToLocal, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&image1, args.srcResource.image);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
@@ -146,11 +146,11 @@ TEST(CsrSelectionArgsTests, givenImagesWhenCreatingCsrSelectionArgsThenSetupArgs
         EXPECT_EQ(origin2, args.dstResource.imageOrigin);
     }
     {
-        allocation1.memoryPool = MemoryPool::LocalMemory;
-        allocation2.memoryPool = MemoryPool::System4KBPages;
+        allocation1.memoryPool = MemoryPool::localMemory;
+        allocation2.memoryPool = MemoryPool::system4KBPages;
         CsrSelectionArgs args{CL_COMMAND_COPY_IMAGE, &image1, &image2, rootDeviceIndex, size, origin1, origin2};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_COPY_IMAGE), args.cmdType);
-        EXPECT_EQ(TransferDirection::LocalToHost, args.direction);
+        EXPECT_EQ(TransferDirection::localToHost, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&image1, args.srcResource.image);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
@@ -171,41 +171,41 @@ TEST(CsrSelectionArgsTests, givenGraphicsAllocationsWhenCreatingCsrSelectionArgs
     MultiGraphicsAllocation multiAlloc2 = GraphicsAllocationHelper::toMultiGraphicsAllocation(&allocation2);
 
     {
-        allocation1.memoryPool = MemoryPool::System4KBPages;
-        allocation2.memoryPool = MemoryPool::System4KBPages;
+        allocation1.memoryPool = MemoryPool::system4KBPages;
+        allocation2.memoryPool = MemoryPool::system4KBPages;
         CsrSelectionArgs args{CL_COMMAND_SVM_MEMCPY, &multiAlloc1, &multiAlloc2, rootDeviceIndex, size};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_SVM_MEMCPY), args.cmdType);
-        EXPECT_EQ(TransferDirection::HostToHost, args.direction);
+        EXPECT_EQ(TransferDirection::hostToHost, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
         EXPECT_EQ(&allocation2, args.dstResource.allocation);
     }
     {
-        allocation1.memoryPool = MemoryPool::System4KBPages;
-        allocation2.memoryPool = MemoryPool::LocalMemory;
+        allocation1.memoryPool = MemoryPool::system4KBPages;
+        allocation2.memoryPool = MemoryPool::localMemory;
         CsrSelectionArgs args{CL_COMMAND_SVM_MEMCPY, &multiAlloc1, &multiAlloc2, rootDeviceIndex, size};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_SVM_MEMCPY), args.cmdType);
-        EXPECT_EQ(TransferDirection::HostToLocal, args.direction);
+        EXPECT_EQ(TransferDirection::hostToLocal, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
         EXPECT_EQ(&allocation2, args.dstResource.allocation);
     }
     {
-        allocation1.memoryPool = MemoryPool::LocalMemory;
-        allocation2.memoryPool = MemoryPool::System4KBPages;
+        allocation1.memoryPool = MemoryPool::localMemory;
+        allocation2.memoryPool = MemoryPool::system4KBPages;
         CsrSelectionArgs args{CL_COMMAND_SVM_MEMCPY, &multiAlloc1, &multiAlloc2, rootDeviceIndex, size};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_SVM_MEMCPY), args.cmdType);
-        EXPECT_EQ(TransferDirection::LocalToHost, args.direction);
+        EXPECT_EQ(TransferDirection::localToHost, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
         EXPECT_EQ(&allocation2, args.dstResource.allocation);
     }
     {
-        allocation1.memoryPool = MemoryPool::LocalMemory;
-        allocation2.memoryPool = MemoryPool::LocalMemory;
+        allocation1.memoryPool = MemoryPool::localMemory;
+        allocation2.memoryPool = MemoryPool::localMemory;
         CsrSelectionArgs args{CL_COMMAND_SVM_MEMCPY, &multiAlloc1, &multiAlloc2, rootDeviceIndex, size};
         EXPECT_EQ(static_cast<cl_command_type>(CL_COMMAND_SVM_MEMCPY), args.cmdType);
-        EXPECT_EQ(TransferDirection::LocalToLocal, args.direction);
+        EXPECT_EQ(TransferDirection::localToLocal, args.direction);
         EXPECT_EQ(size, args.size);
         EXPECT_EQ(&allocation1, args.srcResource.allocation);
         EXPECT_EQ(&allocation2, args.dstResource.allocation);
