@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2024 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -9,6 +9,10 @@
 
 #include "shared/source/helpers/ptr_math.h"
 
+namespace NEO {
+class GraphicsAllocation;
+} // namespace NEO
+
 // clang-format off
 // EnqueueTraits
 using namespace NEO;
