@@ -912,7 +912,7 @@ HWTEST_F(CommandStreamReceiverFlushTaskTests, GivenEnoughMemoryOnlyForPreambleWh
     csrCS.getSpace(csrCS.getAvailableSpace() - sizeNeededForPreamble);
 
     commandStreamReceiver.streamProperties.stateComputeMode.setPropertiesAll(false, flushTaskFlags.numGrfRequired,
-                                                                             flushTaskFlags.threadArbitrationPolicy, PreemptionMode::Disabled);
+                                                                             flushTaskFlags.threadArbitrationPolicy, PreemptionMode::Disabled, false);
     flushTask(commandStreamReceiver);
 
     EXPECT_GE(sizeNeeded, csrCS.getUsed());
@@ -952,7 +952,7 @@ HWTEST_F(CommandStreamReceiverFlushTaskTests, GivenEnoughMemoryOnlyForPreambleAn
     csrCS.getSpace(csrCS.getAvailableSpace() - sizeNeededForPreamble - sizeNeededForStateBaseAddress);
 
     commandStreamReceiver.streamProperties.stateComputeMode.setPropertiesAll(false, flushTaskFlags.numGrfRequired,
-                                                                             flushTaskFlags.threadArbitrationPolicy, PreemptionMode::Disabled);
+                                                                             flushTaskFlags.threadArbitrationPolicy, PreemptionMode::Disabled, false);
     flushTask(commandStreamReceiver);
 
     EXPECT_GE(sizeNeeded, csrCS.getUsed());
@@ -992,7 +992,7 @@ HWTEST_F(CommandStreamReceiverFlushTaskTests, GivenEnoughMemoryOnlyForPreambleAn
     flushTaskFlags.preemptionMode = PreemptionHelper::getDefaultPreemptionMode(mockDevice->getHardwareInfo());
 
     commandStreamReceiver.streamProperties.stateComputeMode.setPropertiesAll(false, flushTaskFlags.numGrfRequired,
-                                                                             flushTaskFlags.threadArbitrationPolicy, PreemptionMode::Disabled);
+                                                                             flushTaskFlags.threadArbitrationPolicy, PreemptionMode::Disabled, false);
     commandStreamReceiver.flushTask(
         commandStream,
         0,
