@@ -7,10 +7,12 @@
 
 #pragma once
 #include "shared/source/device/device.h"
+#include "shared/source/helpers/compiler_product_helper.h"
 #include "shared/source/helpers/constants.h"
 #include "shared/source/helpers/file_io.h"
 #include "shared/test/common/helpers/test_files.h"
 #include "shared/test/common/mocks/mock_modules_zebin.h"
+#include "shared/test/common/mocks/mock_zebin_wrapper.h"
 
 #include "opencl/source/kernel/kernel.h"
 #include "opencl/source/platform/platform.h"
@@ -83,19 +85,12 @@ struct HelloWorldKernelFixture : public ProgramFixture {
         EXPECT_EQ(CL_SUCCESS, retVal);
     }
 
-    void setUp(ClDevice *pDevice, const char *kernelNameStr) {
+    void setUp(ClDevice *pDevice, MockZebinWrapper<>::Descriptor desc) {
         ProgramFixture::setUp();
-        pKernelName = new std::string(kernelNameStr);
+        pKernelName = new std::string("CopyBuffer");
 
         constexpr auto numBits = is32bit ? Elf::EI_CLASS_32 : Elf::EI_CLASS_64;
-        auto zebinData = std::make_unique<ZebinTestData::ZebinCopyBufferSimdModule<numBits>>(pDevice->getHardwareInfo(), 32);
-        const auto &src = zebinData->storage;
-
-        ASSERT_NE(nullptr, src.data());
-        ASSERT_NE(0u, src.size());
-
-        const unsigned char *binaries[1] = {reinterpret_cast<const unsigned char *>(src.data())};
-        const size_t binarySize = src.size();
+        MockZebinWrapper<1u, numBits> zebin{pDevice->getHardwareInfo(), desc};
 
         auto deviceVector = toClDeviceVector(*pDevice);
         pContext = Context::create<MockContext>(nullptr, deviceVector, nullptr, nullptr, retVal);
@@ -105,8 +100,8 @@ struct HelloWorldKernelFixture : public ProgramFixture {
         createProgramFromBinary(
             pContext,
             deviceVector,
-            binaries,
-            &binarySize);
+            zebin.binaries.data(),
+            zebin.binarySizes.data());
 
         ASSERT_NE(nullptr, pProgram);
 
@@ -124,6 +119,14 @@ struct HelloWorldKernelFixture : public ProgramFixture {
         EXPECT_EQ(CL_SUCCESS, retVal);
     }
 
+    void setUp(ClDevice *pDevice) {
+        auto productHelper = NEO::CompilerProductHelper::create(defaultHwInfo->platform.eProductFamily);
+        MockZebinWrapper<>::Descriptor desc{};
+        desc.isStateless = productHelper->isForceToStatelessRequired();
+
+        setUp(pDevice, desc);
+    }
+
     void tearDown() {
         delete pKernelName;
         delete pTestFilename;
