@@ -281,9 +281,9 @@ class MockCommandQueueHw : public CommandQueueHw<GfxFamily> {
     using BaseClass::isBlitAuxTranslationRequired;
     using BaseClass::isCacheFlushOnNextBcsWriteRequired;
     using BaseClass::isCompleted;
+    using BaseClass::isForceStateless;
     using BaseClass::isGpgpuSubmissionForBcsRequired;
     using BaseClass::l3FlushAfterPostSyncEnabled;
-    using BaseClass::l3FlushedAfterCpuRead;
     using BaseClass::latestSentEnqueueType;
     using BaseClass::minimalSizeForBcsSplit;
     using BaseClass::obtainCommandStream;
@@ -298,18 +298,6 @@ class MockCommandQueueHw : public CommandQueueHw<GfxFamily> {
     using BaseClass::throttle;
     using BaseClass::timestampPacketContainer;
 
-    void clearBcsStates() {
-        CopyEngineState unusedState{};
-        std::fill(bcsStates.begin(), bcsStates.end(), unusedState);
-    }
-
-    void insertBcsEngine(aub_stream::EngineType bcsEngineType) {
-        const auto index = NEO::EngineHelpers::getBcsIndex(bcsEngineType);
-        const auto engine = &getDevice().getEngine(bcsEngineType, EngineUsage::regular);
-        bcsEngines[index] = engine;
-        bcsQueueEngineType = bcsEngineType;
-    }
-
     MockCommandQueueHw(Context *context,
                        ClDevice *device,
                        cl_queue_properties *properties) : MockCommandQueueHw(context, device, properties, false) {}
@@ -320,10 +308,22 @@ class MockCommandQueueHw : public CommandQueueHw<GfxFamily> {
         this->constructBcsEngine(false);
     }
 
+    void clearBcsStates() {
+        CopyEngineState unusedState{};
+        std::fill(bcsStates.begin(), bcsStates.end(), unusedState);
+    }
+
     void clearBcsEngines() {
         std::fill(bcsEngines.begin(), bcsEngines.end(), nullptr);
     }
 
+    void insertBcsEngine(aub_stream::EngineType bcsEngineType) {
+        const auto index = NEO::EngineHelpers::getBcsIndex(bcsEngineType);
+        const auto engine = &getDevice().getEngine(bcsEngineType, EngineUsage::regular);
+        bcsEngines[index] = engine;
+        bcsQueueEngineType = bcsEngineType;
+    }
+
     cl_int flush() override {
         flushCalled = true;
         return BaseClass::flush();
@@ -526,18 +526,37 @@ class MockCommandQueueHw : public CommandQueueHw<GfxFamily> {
         return BaseClass::finish();
     }
 
-    unsigned int lastCommandType;
+    LinearStream *peekCommandStream() {
+        return this->commandStream;
+    }
+
     std::vector<Kernel *> lastEnqueuedKernels;
     MultiDispatchInfo storedMultiDispatchInfo;
+    BuiltinOpParams kernelParams;
     size_t enqueueWriteImageCounter = 0;
-    bool enqueueWriteImageCallBase = true;
     size_t enqueueReadImageCounter = 0;
-    bool enqueueReadImageCallBase = true;
     size_t enqueueWriteBufferCounter = 0;
-    bool enqueueWriteBufferCallBase = true;
     size_t enqueueReadBufferCounter = 0;
-    bool enqueueReadBufferCallBase = true;
     size_t requestedCmdStreamSize = 0;
+    size_t enqueueSVMMemcpyCalledCount = 0;
+    size_t finishCalledCount = 0;
+    std::atomic<TaskCountType> latestTaskCountWaited{std::numeric_limits<uint32_t>::max()};
+    std::atomic<uint32_t> isCompletedCalled = 0;
+    unsigned int lastCommandType;
+    int setQueueBlocked = -1;
+    int forceGpgpuSubmissionForBcsRequired = -1;
+    int waitForAllEnginesCalledCount = 0;
+    int enqueueMarkerWithWaitListCalledCount = 0;
+    std::optional<WaitStatus> waitForAllEnginesReturnValue{};
+    std::optional<WaitStatus> waitUntilCompleteReturnValue{};
+    struct OverrideReturnValue {
+        bool enabled = false;
+        bool returnValue = false;
+    } overrideIsCacheFlushForBcsRequired;
+    bool enqueueWriteImageCallBase = true;
+    bool enqueueReadImageCallBase = true;
+    bool enqueueWriteBufferCallBase = true;
+    bool enqueueReadBufferCallBase = true;
     bool blockingWriteBuffer = false;
     bool blockingReadBuffer = false;
     bool storeMultiDispatchInfo = false;
@@ -549,25 +568,7 @@ class MockCommandQueueHw : public CommandQueueHw<GfxFamily> {
     bool waitForTimestampsCalled = false;
     bool latestWaitForTimestampsStatus = false;
     bool recordedSkipWait = false;
-    int setQueueBlocked = -1;
-    int forceGpgpuSubmissionForBcsRequired = -1;
-    mutable bool isBlitEnqueueImageAllowed = false;
-    struct OverrideReturnValue {
-        bool enabled = false;
-        bool returnValue = false;
-    } overrideIsCacheFlushForBcsRequired;
-    BuiltinOpParams kernelParams;
-    std::atomic<TaskCountType> latestTaskCountWaited{std::numeric_limits<uint32_t>::max()};
-    std::atomic<uint32_t> isCompletedCalled = 0;
     bool flushCalled = false;
-    std::optional<WaitStatus> waitForAllEnginesReturnValue{};
-    std::optional<WaitStatus> waitUntilCompleteReturnValue{};
-    int waitForAllEnginesCalledCount{0};
-    int enqueueMarkerWithWaitListCalledCount{0};
-    size_t enqueueSVMMemcpyCalledCount{0};
-    size_t finishCalledCount{0};
-    LinearStream *peekCommandStream() {
-        return this->commandStream;
-    }
+    mutable bool isBlitEnqueueImageAllowed = false;
 };
 } // namespace NEO
