@@ -201,12 +201,7 @@ int main(int argc, char **argv) {
 
     gEnvironment = reinterpret_cast<Environment *>(::testing::AddGlobalTestEnvironment(new Environment(devicePrefix, productConfig)));
 
-    int sigOut = setAlarm(enableAlarm);
-    if (sigOut != 0) {
-        return sigOut;
-    }
-
-    sigOut = setSegv(enableSegv);
+    int sigOut = setSegv(enableSegv);
     if (sigOut != 0) {
         return sigOut;
     }
@@ -216,7 +211,13 @@ int main(int argc, char **argv) {
         return sigOut;
     }
 
+    sigOut = setAlarm(enableAlarm);
+    if (sigOut != 0) {
+        return sigOut;
+    }
+
     retVal = RUN_ALL_TESTS();
+    cleanupSignals();
 
     if (showTestStats) {
         std::cout << getTestStats() << std::endl;
