@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2021 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,14 +8,10 @@
 #pragma once
 #include "shared/source/os_interface/linux/performance_counters_linux.h"
 
-#include "opencl/test/unit_test/os_interface/mock_performance_counters.h"
-
 namespace NEO {
 
-using MetricsLibraryApi::LinuxAdapterType;
-
 class MockPerformanceCountersLinux : public PerformanceCountersLinux {
   public:
-    MockPerformanceCountersLinux(Device *device);
+    MockPerformanceCountersLinux();
 };
 } // namespace NEO
