@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -46,13 +46,13 @@ void ClWddmMemoryManagerFixture::setUp() {
         auto csr = std::unique_ptr<CommandStreamReceiver>(createCommandStream(executionEnvironment, 1u, 1));
         auto hwInfo = *defaultHwInfo;
         EngineInstancesContainer regularEngines = {
-            {aub_stream::ENGINE_CCS, EngineUsage::Regular}};
+            {aub_stream::ENGINE_CCS, EngineUsage::regular}};
 
         memoryManager->createAndRegisterOsContext(csr.get(), EngineDescriptorHelper::getDefaultDescriptor(regularEngines[0],
                                                                                                           PreemptionHelper::getDefaultPreemptionMode(hwInfo)));
 
         for (auto engine : memoryManager->getRegisteredEngines(rootDeviceIndex)) {
-            if (engine.getEngineUsage() == EngineUsage::Regular) {
+            if (engine.getEngineUsage() == EngineUsage::regular) {
                 engine.commandStreamReceiver->pageTableManager.reset(GmmPageTableMngr::create(nullptr, 0, &dummyTTCallbacks));
             }
         }
@@ -319,7 +319,10 @@ TEST_F(BufferWithWddmMemory, givenFragmentsThatAreNotInOrderWhenGraphicsAllocati
     handleStorage.fragmentStorageData[0].residency = new ResidencyData(maxOsContextCount);
     handleStorage.fragmentStorageData[0].freeTheFragment = true;
     auto rootDeviceEnvironment = executionEnvironment.rootDeviceEnvironments[0].get();
-    osHandle->gmm = new Gmm(rootDeviceEnvironment->getGmmHelper(), ptr, size, 0, GMM_RESOURCE_USAGE_OCL_BUFFER, false, {}, true);
+    GmmRequirements gmmRequirements{};
+    gmmRequirements.allowLargePages = true;
+    gmmRequirements.preferCompressed = false;
+    osHandle->gmm = new Gmm(rootDeviceEnvironment->getGmmHelper(), ptr, size, 0, GMM_RESOURCE_USAGE_OCL_BUFFER, {}, gmmRequirements);
     handleStorage.fragmentCount = 1;
 
     FragmentStorage fragment = {};
@@ -357,7 +360,10 @@ TEST_F(BufferWithWddmMemory, givenFragmentsThatAreNotInOrderWhenGraphicsAllocati
     handleStorage.fragmentStorageData[0].residency = new ResidencyData(maxOsContextCount);
     handleStorage.fragmentStorageData[0].freeTheFragment = true;
     auto rootDeviceEnvironment = executionEnvironment.rootDeviceEnvironments[0].get();
-    osHandle->gmm = new Gmm(rootDeviceEnvironment->getGmmHelper(), ptr, size, 0, GMM_RESOURCE_USAGE_OCL_BUFFER, false, {}, true);
+    GmmRequirements gmmRequirements{};
+    gmmRequirements.allowLargePages = true;
+    gmmRequirements.preferCompressed = false;
+    osHandle->gmm = new Gmm(rootDeviceEnvironment->getGmmHelper(), ptr, size, 0, GMM_RESOURCE_USAGE_OCL_BUFFER, {}, gmmRequirements);
     handleStorage.fragmentCount = 1;
 
     FragmentStorage fragment = {};
@@ -409,7 +415,7 @@ struct ClWddmMemoryManagerWithAsyncDeleterTest : public ::testing::Test {
 TEST_F(ClWddmMemoryManagerWithAsyncDeleterTest, givenMemoryManagerWithAsyncDeleterWhenCannotAllocateMemoryForTiledImageThenDrainIsCalledAndCreateAllocationIsCalledTwice) {
     UltDeviceFactory deviceFactory{1, 0};
     ImageDescriptor imgDesc = {};
-    imgDesc.imageType = ImageType::Image3D;
+    imgDesc.imageType = ImageType::image3D;
     ImageInfo imgInfo = MockGmm::initImgInfo(imgDesc, 0, nullptr);
 
     wddm->createAllocationStatus = STATUS_GRAPHICS_NO_VIDEO_MEMORY;
@@ -427,7 +433,7 @@ TEST_F(ClWddmMemoryManagerWithAsyncDeleterTest, givenMemoryManagerWithAsyncDelet
 TEST_F(ClWddmMemoryManagerWithAsyncDeleterTest, givenMemoryManagerWithAsyncDeleterWhenCanAllocateMemoryForTiledImageThenDrainIsNotCalledAndCreateAllocationIsCalledOnce) {
     UltDeviceFactory deviceFactory{1, 0};
     ImageDescriptor imgDesc;
-    imgDesc.imageType = ImageType::Image3D;
+    imgDesc.imageType = ImageType::image3D;
     ImageInfo imgInfo = MockGmm::initImgInfo(imgDesc, 0, nullptr);
 
     wddm->createAllocationStatus = STATUS_SUCCESS;
@@ -451,7 +457,7 @@ TEST_F(ClWddmMemoryManagerWithAsyncDeleterTest, givenMemoryManagerWithoutAsyncDe
     UltDeviceFactory deviceFactory{1, 0};
     memoryManager->setDeferredDeleter(nullptr);
     ImageDescriptor imgDesc;
-    imgDesc.imageType = ImageType::Image3D;
+    imgDesc.imageType = ImageType::image3D;
     ImageInfo imgInfo = MockGmm::initImgInfo(imgDesc, 0, nullptr);
 
     wddm->createAllocationStatus = STATUS_GRAPHICS_NO_VIDEO_MEMORY;
@@ -469,7 +475,7 @@ struct PlatformWithFourDevicesTest : public ::testing::Test {
         ultHwConfig.useMockedPrepareDeviceEnvironmentsFunc = false;
     }
     void SetUp() override {
-        DebugManager.flags.CreateMultipleSubDevices.set(4);
+        debugManager.flags.CreateMultipleSubDevices.set(4);
         initPlatform();
     }
 
@@ -482,7 +488,7 @@ TEST_F(PlatformWithFourDevicesTest, whenCreateColoredAllocationAndWddmReturnsCan
     struct CanonizeAddressMockWddm : public WddmMock {
         using WddmMock::WddmMock;
 
-        bool mapGpuVirtualAddress(Gmm *gmm, D3DKMT_HANDLE handle, D3DGPU_VIRTUAL_ADDRESS minimumAddress, D3DGPU_VIRTUAL_ADDRESS maximumAddress, D3DGPU_VIRTUAL_ADDRESS preferredAddress, D3DGPU_VIRTUAL_ADDRESS &gpuPtr) override {
+        bool mapGpuVirtualAddress(Gmm *gmm, D3DKMT_HANDLE handle, D3DGPU_VIRTUAL_ADDRESS minimumAddress, D3DGPU_VIRTUAL_ADDRESS maximumAddress, D3DGPU_VIRTUAL_ADDRESS preferredAddress, D3DGPU_VIRTUAL_ADDRESS &gpuPtr, AllocationType type) override {
             auto gmmHelper = rootDeviceEnvironment.getGmmHelper();
             gpuPtr = gmmHelper->canonize(preferredAddress);
             return mapGpuVaStatus;
@@ -506,7 +512,7 @@ TEST_F(PlatformWithFourDevicesTest, whenCreateColoredAllocationAndWddmReturnsCan
     platform()->peekExecutionEnvironment()->rootDeviceEnvironments[0]->getMutableHardwareInfo()->featureTable.flags.ftrMultiTileArch = true;
 
     GraphicsAllocation *allocation = nullptr;
-    EXPECT_NO_THROW(allocation = memoryManager.allocateGraphicsMemoryWithProperties({mockRootDeviceIndex, true, 4 * MemoryConstants::pageSize64k, AllocationType::BUFFER, true, mockDeviceBitfield}));
+    EXPECT_NO_THROW(allocation = memoryManager.allocateGraphicsMemoryWithProperties({mockRootDeviceIndex, true, 4 * MemoryConstants::pageSize64k, AllocationType::buffer, true, mockDeviceBitfield}));
     EXPECT_NE(nullptr, allocation);
 
     memoryManager.freeGraphicsMemory(allocation);
@@ -527,7 +533,7 @@ TEST_F(PlatformWithFourDevicesTest, givenDifferentAllocationSizesWhenColourAlloc
 
     // We are allocating memory from 4 to 12 pages and want to check if remainders (1, 2 or 3 pages in case of 4 devices) are spread equally.
     for (int additionalSize = 0; additionalSize <= 8; additionalSize++) {
-        auto allocation = static_cast<WddmAllocation *>(memoryManager.allocateGraphicsMemoryWithProperties({mockRootDeviceIndex, true, (4 + additionalSize) * MemoryConstants::pageSize64k, AllocationType::BUFFER, true, 0b1111}));
+        auto allocation = static_cast<WddmAllocation *>(memoryManager.allocateGraphicsMemoryWithProperties({mockRootDeviceIndex, true, (4 + additionalSize) * MemoryConstants::pageSize64k, AllocationType::buffer, true, 0b1111}));
         auto handles = allocation->getNumGmms();
 
         EXPECT_EQ(4u, handles);
@@ -566,7 +572,7 @@ TEST_F(PlatformWithFourDevicesTest, givenDifferentAllocationSizesWhenColourAlloc
 TEST_F(PlatformWithFourDevicesTest, whenCreateScratchSpaceInSingleTileQueueThenTheAllocationHasOneHandle) {
     MemoryManagerCreate<WddmMemoryManager> memoryManager(true, true, *platform()->peekExecutionEnvironment());
 
-    AllocationProperties properties{mockRootDeviceIndex, true, 1u, AllocationType::SCRATCH_SURFACE, false, false, mockDeviceBitfield};
+    AllocationProperties properties{mockRootDeviceIndex, true, 1u, AllocationType::scratchSurface, false, false, mockDeviceBitfield};
     auto allocation = static_cast<WddmAllocation *>(memoryManager.allocateGraphicsMemoryWithProperties(properties));
     EXPECT_EQ(1u, allocation->getNumGmms());
     memoryManager.freeGraphicsMemory(allocation);
