@@ -40,8 +40,8 @@ TEST_F(ProgramWithZebinFixture, givenZebinSegmentsThenSegmentsArePopulated) {
         EXPECT_EQ(static_cast<uintptr_t>(alloc->getGpuAddress()), segment.address);
         EXPECT_EQ(static_cast<size_t>(alloc->getUnderlyingBufferSize()), segment.size);
     };
-    checkGPUSeg(program->buildInfos[rootDeviceIndex].constantSurface, segments.constData);
-    checkGPUSeg(program->buildInfos[rootDeviceIndex].globalSurface, segments.varData);
+    checkGPUSeg(program->buildInfos[rootDeviceIndex].constantSurface->getGraphicsAllocation(), segments.constData);
+    checkGPUSeg(program->buildInfos[rootDeviceIndex].globalSurface->getGraphicsAllocation(), segments.varData);
     checkGPUSeg(program->getKernelInfoArray(rootDeviceIndex)[0]->getGraphicsAllocation(), segments.nameToSegMap[ZebinTestData::ValidEmptyProgram<>::kernelName]);
 
     EXPECT_EQ(reinterpret_cast<uintptr_t>(program->buildInfos[rootDeviceIndex].constStringSectionData.initData), segments.stringData.address);
@@ -49,6 +49,22 @@ TEST_F(ProgramWithZebinFixture, givenZebinSegmentsThenSegmentsArePopulated) {
     EXPECT_EQ(program->buildInfos[rootDeviceIndex].constStringSectionData.size, sizeof(strings));
 }
 
+TEST_F(ProgramWithZebinFixture, givenZebinSegmentsWithSharedGlobalAndConstSurfacesThenSegmentsArePopulated) {
+    const bool createWithSharedGlobalConstSurfaces = true;
+    populateProgramWithSegments(program.get(), createWithSharedGlobalConstSurfaces);
+    auto segments = program->getZebinSegments(rootDeviceIndex);
+
+    auto checkGPUSeg = [](NEO::SharedPoolAllocation *surface, NEO::Zebin::Debug::Segments::Segment segment) {
+        EXPECT_EQ(static_cast<uintptr_t>(surface->getGpuAddress()), segment.address);
+        EXPECT_EQ(static_cast<size_t>(surface->getSize()), segment.size);
+
+        EXPECT_NE(surface->getGraphicsAllocation()->getGpuAddress(), surface->getGpuAddress());
+        EXPECT_NE(surface->getGraphicsAllocation()->getUnderlyingBufferSize(), surface->getSize());
+    };
+    checkGPUSeg(program->buildInfos[rootDeviceIndex].constantSurface.get(), segments.constData);
+    checkGPUSeg(program->buildInfos[rootDeviceIndex].globalSurface.get(), segments.varData);
+}
+
 TEST_F(ProgramWithZebinFixture, givenNonEmptyDebugDataThenDebugZebinIsNotCreated) {
     addEmptyZebin(program.get());
     populateProgramWithSegments(program.get());
