@@ -27,7 +27,7 @@ using namespace NEO;
 
 struct EnqueueFixtureXeHpcCore : public ::testing::Test {
     void SetUp() override {
-        DebugManager.flags.EnableMemoryPrefetch.set(1);
+        debugManager.flags.EnableMemoryPrefetch.set(1);
 
         clDevice = std::make_unique<MockClDevice>(MockDevice::createWithNewExecutionEnvironment<MockDevice>(defaultHwInfo.get(), mockRootDeviceIndex));
         context = std::make_unique<MockContext>(clDevice.get());
@@ -63,15 +63,15 @@ XE_HPC_CORETEST_F(MemoryPrefetchTestsXeHpcCore, givenKernelWhenWalkerIsProgramme
     auto commandQueue = createCommandQueue<FamilyType>();
     auto &commandStream = commandQueue->getCS(1024);
 
-    auto &heap = commandQueue->getIndirectHeap(IndirectHeap::Type::DYNAMIC_STATE, 1);
+    auto &heap = commandQueue->getIndirectHeap(IndirectHeap::Type::dynamicState, 1);
     size_t workSize[] = {1, 1, 1};
     Vec3<size_t> wgInfo = {1, 1, 1};
 
     HardwareInterfaceWalkerArgs walkerArgs = createHardwareInterfaceWalkerArgs(workSize, wgInfo, PreemptionMode::Disabled);
 
     mockKernel->kernelInfo.heapInfo.kernelHeapSize = 1;
-    HardwareInterface<FamilyType>::programWalker(commandStream, *mockKernel->mockKernel, *commandQueue,
-                                                 heap, heap, heap, dispatchInfo, walkerArgs);
+    HardwareInterface<FamilyType>::template programWalker<COMPUTE_WALKER>(commandStream, *mockKernel->mockKernel, *commandQueue,
+                                                                          heap, heap, heap, dispatchInfo, walkerArgs);
 
     HardwareParse hwParse;
     hwParse.parseCommands<FamilyType>(commandStream, 0);
@@ -109,7 +109,7 @@ XE_HPC_CORETEST_F(ProgramWalkerTestsXeHpcCore, givenProperThreadGroupSizesWhenWa
     auto commandQueue = createCommandQueue<FamilyType>();
     auto &commandStream = commandQueue->getCS(1024);
 
-    auto &heap = commandQueue->getIndirectHeap(IndirectHeap::Type::DYNAMIC_STATE, 1);
+    auto &heap = commandQueue->getIndirectHeap(IndirectHeap::Type::dynamicState, 1);
     size_t workSize[] = {1, 1, 1};
     Vec3<size_t> wgInfo = {1024, 1, 1};
 
@@ -121,8 +121,8 @@ XE_HPC_CORETEST_F(ProgramWalkerTestsXeHpcCore, givenProperThreadGroupSizesWhenWa
     hwInfo->platform.usRevId = productHelper.getHwRevIdFromStepping(REVISION_A0, *hwInfo);
 
     {
-        HardwareInterface<FamilyType>::programWalker(commandStream, *mockKernel->mockKernel, *commandQueue,
-                                                     heap, heap, heap, dispatchInfo, walkerArgs);
+        HardwareInterface<FamilyType>::template programWalker<COMPUTE_WALKER>(commandStream, *mockKernel->mockKernel, *commandQueue,
+                                                                              heap, heap, heap, dispatchInfo, walkerArgs);
         HardwareParse hwParse;
         hwParse.parseCommands<FamilyType>(commandStream, 0);
         auto itorWalker = find<COMPUTE_WALKER *>(hwParse.cmdList.begin(), hwParse.cmdList.end());
@@ -141,7 +141,7 @@ XE_HPC_CORETEST_F(ProgramWalkerTestsXeHpcCore, givenDebugVariableSetWhenProgramm
     auto commandQueue = createCommandQueue<FamilyType>();
     auto &commandStream = commandQueue->getCS(1024);
 
-    auto &heap = commandQueue->getIndirectHeap(IndirectHeap::Type::DYNAMIC_STATE, 1);
+    auto &heap = commandQueue->getIndirectHeap(IndirectHeap::Type::dynamicState, 1);
     size_t workSize[] = {1, 1, 1};
     Vec3<size_t> wgInfo = {1, 1, 1};
 
@@ -152,8 +152,8 @@ XE_HPC_CORETEST_F(ProgramWalkerTestsXeHpcCore, givenDebugVariableSetWhenProgramm
     {
         // default
 
-        HardwareInterface<FamilyType>::programWalker(commandStream, *mockKernel->mockKernel, *commandQueue,
-                                                     heap, heap, heap, dispatchInfo, walkerArgs);
+        HardwareInterface<FamilyType>::template programWalker<COMPUTE_WALKER>(commandStream, *mockKernel->mockKernel, *commandQueue,
+                                                                              heap, heap, heap, dispatchInfo, walkerArgs);
 
         HardwareParse hwParse;
         hwParse.parseCommands<FamilyType>(commandStream, 0);
@@ -169,10 +169,10 @@ XE_HPC_CORETEST_F(ProgramWalkerTestsXeHpcCore, givenDebugVariableSetWhenProgramm
         // debug flag == 1
 
         commandsOffset = commandStream.getUsed();
-        DebugManager.flags.ForceL3PrefetchForComputeWalker.set(1);
+        debugManager.flags.ForceL3PrefetchForComputeWalker.set(1);
 
-        HardwareInterface<FamilyType>::programWalker(commandStream, *mockKernel->mockKernel, *commandQueue,
-                                                     heap, heap, heap, dispatchInfo, walkerArgs);
+        HardwareInterface<FamilyType>::template programWalker<COMPUTE_WALKER>(commandStream, *mockKernel->mockKernel, *commandQueue,
+                                                                              heap, heap, heap, dispatchInfo, walkerArgs);
 
         HardwareParse hwParse;
         hwParse.parseCommands<FamilyType>(commandStream, commandsOffset);
@@ -188,10 +188,10 @@ XE_HPC_CORETEST_F(ProgramWalkerTestsXeHpcCore, givenDebugVariableSetWhenProgramm
         // debug flag == 0
 
         commandsOffset = commandStream.getUsed();
-        DebugManager.flags.ForceL3PrefetchForComputeWalker.set(0);
+        debugManager.flags.ForceL3PrefetchForComputeWalker.set(0);
 
-        HardwareInterface<FamilyType>::programWalker(commandStream, *mockKernel->mockKernel, *commandQueue,
-                                                     heap, heap, heap, dispatchInfo, walkerArgs);
+        HardwareInterface<FamilyType>::template programWalker<COMPUTE_WALKER>(commandStream, *mockKernel->mockKernel, *commandQueue,
+                                                                              heap, heap, heap, dispatchInfo, walkerArgs);
 
         HardwareParse hwParse;
         hwParse.parseCommands<FamilyType>(commandStream, commandsOffset);
