@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -105,7 +105,7 @@ int BinaryEncoder::createElf(std::stringstream &deviceBinary) {
 }
 
 void BinaryEncoder::printHelp() {
-    argHelper->printf(R"===(Assembles Intel Compute GPU device binary from input files.
+    argHelper->printf(R"OCLOC_HELP(Assembles Intel Compute GPU device binary from input files.
 It's expected that input files were previously generated by 'ocloc disasm'
 command or are compatible with 'ocloc disasm' output (especially in terms of
 file naming scheme). See 'ocloc disasm --help' for additional info.
@@ -128,12 +128,14 @@ Usage: ocloc asm -out <out_file> [-dump <dump_dir>] [-device <device_type>] [-ig
   -ignore_isa_padding       Ignores Kernel Heap padding - padding will not
                             be added to Kernel Heap binary.
 
+  -v                        Verbose mode.
+
   --help                    Print this usage message.
 
 Examples:
   Assemble to Intel Compute GPU device binary
     ocloc asm -out reassembled.bin
-)===",
+)OCLOC_HELP",
                       argHelper->createStringForArgs(argHelper->productConfigHelper->getDeviceAcronyms()).c_str());
 }
 
@@ -165,7 +167,7 @@ int BinaryEncoder::processBinary(const std::vector<std::string> &ptmFileLines, s
             std::stringstream ss(ptmFileLines[deviceMarker]);
             ss.ignore(32, ' ');
             ss.ignore(32, ' ');
-            uint32_t gfxCore = 0;
+            int32_t gfxCore = 0;
             ss >> gfxCore;
             iga->setGfxCore(static_cast<GFXCORE_FAMILY>(gfxCore));
         }
@@ -326,6 +328,8 @@ int BinaryEncoder::validateInput(const std::vector<std::string> &args) {
         } else if ("-q" == currArg) {
             argHelper->getPrinterRef().setSuppressMessages(true);
             iga->setMessagePrinter(argHelper->getPrinterRef());
+        } else if ("-v" == currArg) {
+            argHelper->setVerbose(true);
         } else {
             argHelper->printf("Unknown argument %s\n", currArg.c_str());
             return -1;
