@@ -15,6 +15,7 @@
 #include "shared/offline_compiler/source/ocloc_supported_devices_helper.h"
 #include "shared/offline_compiler/source/queries.h"
 #include "shared/offline_compiler/source/utilities/get_git_version_info.h"
+#include "shared/source/compiler_interface/compiler_cache.h"
 #include "shared/source/compiler_interface/compiler_options.h"
 #include "shared/source/compiler_interface/compiler_options_extra.h"
 #include "shared/source/compiler_interface/default_cache_config.h"
@@ -28,6 +29,8 @@
 #include "shared/source/helpers/compiler_options_parser.h"
 #include "shared/source/helpers/compiler_product_helper.h"
 #include "shared/source/helpers/debug_helpers.h"
+#include "shared/source/helpers/file_io.h"
+#include "shared/source/helpers/hash.h"
 #include "shared/source/helpers/string.h"
 #include "shared/source/helpers/validators.h"
 #include "shared/source/os_interface/debug_env_reader.h"
@@ -37,6 +40,7 @@
 #include "neo_aot_platforms.h"
 #include "offline_compiler_ext.h"
 
+#include <filesystem>
 #include <iomanip>
 #include <iterator>
 #include <list>
@@ -729,6 +733,10 @@ int OfflineCompiler::build() {
         return igcInitializationResult;
     }
 
+    if (!inputFileSpirV()) {
+        createTempSourceFileForDebug();
+    }
+
     int retVal = OCLOC_SUCCESS;
     if (isOnlySpirV()) {
         retVal = buildToIrBinary();
@@ -1440,7 +1448,6 @@ Usage: ocloc [compile] -file <filename> -device <device_type> [-output <filename
 
   --format                                  Enforce given binary format. The possible values are:
                                             --format zebin - Enforce generating zebin binary
-                                            --format patchtokens - Enforce generating patchtokens (legacy) binary.
 
   -stateful_address_mode                    Enforce given addressing mode. The possible values are:
                                             -stateful_address_mode bindful - enforce generating in bindful mode
@@ -1475,10 +1482,11 @@ void OfflineCompiler::storeBinary(
     DEBUG_BREAK_IF(!(pSrc && srcSize > 0));
 
     delete[] pDst;
-    pDst = new char[srcSize];
+    pDst = new char[srcSize + 1];
 
     dstSize = static_cast<uint32_t>(srcSize);
     memcpy_s(pDst, dstSize, pSrc, srcSize);
+    pDst[srcSize] = 0;
 }
 
 bool OfflineCompiler::generateElfBinary() {
@@ -1546,6 +1554,31 @@ bool OfflineCompiler::generateElfBinary() {
     return true;
 }
 
+void OfflineCompiler::createTempSourceFileForDebug() {
+    if (!CompilerOptions::contains(options, CompilerOptions::generateDebugInfo) || CompilerOptions::contains(options, CompilerOptions::useCMCompiler)) {
+        return;
+    }
+
+    std::string sourcePathOption = CompilerOptions::generateSourcePath.str();
+    size_t sourcePosInOpts = options.find(sourcePathOption);
+
+    if (sourcePosInOpts != std::string::npos) {
+        return;
+    }
+
+    uint64_t sourceHash = NEO::Hash::hash(sourceCode.c_str(), sourceCode.size());
+    std::string tempFilePath = "main_" + std::to_string(sourceHash) + ".cl";
+    std::filesystem::path absTempFilePath = std::filesystem::absolute(tempFilePath);
+
+    writeDataToFile(absTempFilePath.string().c_str(), std::string_view(sourceCode.c_str(), sourceCode.size()));
+
+    if (argHelper && !isQuiet()) {
+        argHelper->printf("Temporary source file for debug info created: %s\n", absTempFilePath.string().c_str());
+    }
+    std::string sourcePathWithFile = sourcePathOption + " " + CompilerOptions::wrapInQuotes(absTempFilePath.string());
+    options = CompilerOptions::concatenate(options, sourcePathWithFile);
+}
+
 void OfflineCompiler::writeOutAllFiles() {
     std::string fileBase;
     std::string fileTrunk = getFileNameTrunk(inputFile);
@@ -1694,7 +1727,7 @@ void OfflineCompiler::enforceFormat(std::string &format) {
     if (format == "zebin") {
         // zebin is enabled by default
     } else if (format == "patchtokens") {
-        CompilerOptions::concatenateAppend(internalOptions, CompilerOptions::disableZebin);
+        argHelper->printf("WARNING: Ignoring deprecated '--format patchtokens' option.\n");
     } else {
         argHelper->printf("Invalid format passed: %s. Ignoring.\n", format.c_str());
     }
