@@ -41,9 +41,10 @@ enum class AILEnumeration : uint32_t {
     disableHostPtrTracking,
     enableLegacyPlatformName,
     disableDirectSubmission,
-    disableDirectSubmissionAllEngines,
+    disableDirectSubmissionBcs,
     handleDivergentBarriers,
     disableBindlessAddressing,
+    disableZeroContract
 };
 
 class AILConfiguration;
