@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2022 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -18,6 +18,7 @@ struct EncodeSurfaceStateArgsBase {
     size_t size = 0u;
 
     void *outMemory = nullptr;
+    void *inTemplateMemory = nullptr;
 
     GraphicsAllocation *allocation = nullptr;
     GmmHelper *gmmHelper = nullptr;
@@ -28,7 +29,6 @@ struct EncodeSurfaceStateArgsBase {
     bool cpuCoherent = false;
     bool forceNonAuxMode = false;
     bool isReadOnly = false;
-    bool useGlobalAtomics = false;
     bool areMultipleSubDevicesInContext = false;
     bool implicitScaling = false;
     bool isDebuggerActive = false;
