@@ -1026,6 +1026,12 @@ bool CommandStreamReceiver::checkImplicitFlushForGpuIdle() {
     return false;
 }
 
+bool CommandStreamReceiver::getAndClearIsWalkerWithProfilingEnqueued() {
+    bool retVal = this->isWalkerWithProfilingEnqueued;
+    this->isWalkerWithProfilingEnqueued = false;
+    return retVal;
+}
+
 void CommandStreamReceiver::downloadTagAllocation(TaskCountType taskCountToWait) {
     if (this->getTagAllocation()) {
         if (taskCountToWait && taskCountToWait <= this->peekLatestFlushedTaskCount()) {
@@ -1120,6 +1126,10 @@ bool CommandStreamReceiver::isAubMode() const {
     return (getType() == NEO::CommandStreamReceiverType::aub || getType() == NEO::CommandStreamReceiverType::tbxWithAub || getType() == NEO::CommandStreamReceiverType::hardwareWithAub || getType() == NEO::CommandStreamReceiverType::nullAub);
 }
 
+bool CommandStreamReceiver::isHardwareMode() const {
+    return (getType() == NEO::CommandStreamReceiverType::hardware);
+}
+
 TaskCountType CompletionStamp::getTaskCountFromSubmissionStatusError(SubmissionStatus status) {
     switch (status) {
     case SubmissionStatus::outOfHostMemory:
