@@ -501,6 +501,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
 
     bool isTbxMode() const;
     bool isAubMode() const;
+    bool isHardwareMode() const;
     bool ensureTagAllocationForRootDeviceIndex(uint32_t rootDeviceIndex);
 
     L1CachePolicy *getStoredL1CachePolicy() {
@@ -576,6 +577,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     void printDeviceIndex();
     void checkForNewResources(TaskCountType submittedTaskCount, TaskCountType allocationTaskCount, GraphicsAllocation &gfxAllocation);
     bool checkImplicitFlushForGpuIdle();
+    MOCKABLE_VIRTUAL bool getAndClearIsWalkerWithProfilingEnqueued();
     void downloadTagAllocation(TaskCountType taskCountToWait);
     void printTagAddressContent(TaskCountType taskCountToWait, int64_t waitTimeout, bool start);
     virtual void addToEvictionContainer(GraphicsAllocation &gfxAllocation);
