@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -15,6 +15,9 @@ void CsrDependencies::makeResident(CommandStreamReceiver &commandStreamReceiver)
     for (auto &timestampPacketContainer : timestampPacketContainer) {
         timestampPacketContainer->makeResident(commandStreamReceiver);
     }
+    for (auto &timestampPacketContainer : multiRootTimeStampSyncContainer) {
+        timestampPacketContainer->makeResident(commandStreamReceiver);
+    }
 }
 
 void CsrDependencies::copyNodesToNewContainer(TimestampPacketContainer &newTimestampPacketContainer) {
@@ -22,4 +25,10 @@ void CsrDependencies::copyNodesToNewContainer(TimestampPacketContainer &newTimes
         newTimestampPacketContainer.assignAndIncrementNodesRefCounts(*timestampPacketContainer);
     }
 }
+void CsrDependencies::copyRootDeviceSyncNodesToNewContainer(TimestampPacketContainer &newTimestampPacketContainer) {
+    for (auto &timestampPacketContainer : multiRootTimeStampSyncContainer) {
+        newTimestampPacketContainer.assignAndIncrementNodesRefCounts(*timestampPacketContainer);
+    }
+}
+
 } // namespace NEO
