@@ -1347,4 +1347,58 @@ std::vector<DeviceVector> Device::groupDevices(DeviceVector devices) {
     return outDevices;
 }
 
+bool Device::canAccessPeer(QueryPeerAccessFunc queryPeerAccess, Device *peerDevice, bool &canAccess) {
+    bool retVal = true;
+
+    if (NEO::debugManager.flags.ForceZeDeviceCanAccessPerReturnValue.get() != -1) {
+        canAccess = !!NEO::debugManager.flags.ForceZeDeviceCanAccessPerReturnValue.get();
+        return retVal;
+    }
+
+    const uint32_t rootDeviceIndex = this->getRootDeviceIndex();
+    const uint32_t peerRootDeviceIndex = peerDevice->getRootDeviceIndex();
+
+    if (rootDeviceIndex == peerRootDeviceIndex) {
+        canAccess = true;
+        return retVal;
+    }
+
+    auto lock = executionEnvironment->obtainPeerAccessQueryLock();
+    if (this->crossAccessEnabledDevices.find(peerRootDeviceIndex) == this->crossAccessEnabledDevices.end()) {
+        retVal = queryPeerAccess(*this, *peerDevice, canAccess);
+        this->updatePeerAccessCache(peerDevice, canAccess);
+    }
+    canAccess = this->crossAccessEnabledDevices[peerRootDeviceIndex];
+
+    return retVal;
+}
+
+void Device::initializePeerAccessForDevices(QueryPeerAccessFunc queryPeerAccess, const std::vector<NEO::Device *> &devices) {
+    for (auto &device : devices) {
+        if (device->getReleaseHelper() && device->getReleaseHelper()->shouldQueryPeerAccess()) {
+            device->hasPeerAccess = false;
+            auto rootDeviceIndex = device->getRootDeviceIndex();
+
+            for (auto &peerDevice : devices) {
+                auto peerRootDeviceIndex = peerDevice->getRootDeviceIndex();
+                if (rootDeviceIndex == peerRootDeviceIndex) {
+                    continue;
+                }
+
+                bool canAccess = false;
+                if (device->crossAccessEnabledDevices.find(peerRootDeviceIndex) == device->crossAccessEnabledDevices.end()) {
+                    auto lock = device->getExecutionEnvironment()->obtainPeerAccessQueryLock();
+                    queryPeerAccess(*device, *peerDevice, canAccess);
+                    device->updatePeerAccessCache(peerDevice, canAccess);
+                } else {
+                    canAccess = device->crossAccessEnabledDevices[peerRootDeviceIndex];
+                }
+
+                if (canAccess) {
+                    device->hasPeerAccess = true;
+                }
+            }
+        }
+    }
+}
 } // namespace NEO
