@@ -91,6 +91,8 @@ struct RTDispatchGlobalsInfo {
     std::vector<GraphicsAllocation *> rtStacks; // per tile
 };
 
+using QueryPeerAccessFunc = std::function<bool(Device &, Device &, bool &)>;
+
 class Device : public ReferenceTrackedObject<Device>, NEO::NonCopyableAndNonMovableClass {
   public:
     ~Device() override;
@@ -260,6 +262,19 @@ class Device : public ReferenceTrackedObject<Device>, NEO::NonCopyableAndNonMova
     void resetUsmAllocationPool(UsmMemAllocPool *usmMemAllocPool);
     void cleanupUsmAllocationPool();
 
+    std::unordered_map<uint32_t, bool> crossAccessEnabledDevices;
+    bool canAccessPeer(QueryPeerAccessFunc queryPeerAccess, Device *peerDevice, bool &canAccess);
+    static void initializePeerAccessForDevices(QueryPeerAccessFunc queryPeerAccess, const std::vector<NEO::Device *> &devices);
+
+    std::optional<bool> hasAnyPeerAccess() const {
+        return hasPeerAccess;
+    }
+
+    void updatePeerAccessCache(Device *peerDevice, bool value) {
+        this->crossAccessEnabledDevices[peerDevice->getRootDeviceIndex()] = value;
+        peerDevice->crossAccessEnabledDevices[this->getRootDeviceIndex()] = value;
+    }
+
   protected:
     Device() = delete;
     Device(ExecutionEnvironment *executionEnvironment, const uint32_t rootDeviceIndex);
@@ -343,6 +358,8 @@ class Device : public ReferenceTrackedObject<Device>, NEO::NonCopyableAndNonMova
     uint32_t maxBufferPoolCount = 0u;
     uint32_t microsecondResolution = 1000u;
 
+    std::optional<bool> hasPeerAccess = std::nullopt;
+
     struct {
         bool isValid = false;
         std::array<uint8_t, ProductHelper::uuidSize> id;
