@@ -49,7 +49,6 @@ enum class DirectSubmissionSfenceMode : int32_t {
 
 namespace UllsDefaults {
 inline constexpr bool defaultDisableCacheFlush = true;
-inline constexpr bool defaultDisableMonitorFence = true;
 } // namespace UllsDefaults
 
 struct BatchBuffer;
@@ -122,6 +121,8 @@ class DirectSubmissionHw {
         const DirectSubmissionHw<GfxFamily, Dispatcher> &directSubmission;
     };
 
+    static_assert(NEO::NonCopyableAndNonMovable<SemaphoreFenceHelper>);
+
     static constexpr size_t prefetchSize = 8 * MemoryConstants::cacheLineSize;
     static constexpr size_t prefetchNoops = prefetchSize / sizeof(uint32_t);
     bool allocateResources();
@@ -252,7 +253,7 @@ class DirectSubmissionHw {
     void *semaphorePtr = nullptr;
     volatile RingSemaphoreData *semaphoreData = nullptr;
     uint32_t *pciBarrierPtr = nullptr;
-    volatile TagAddressType *tagAddress;
+    volatile TagAddressType *tagAddress = nullptr;
 
     uint32_t currentQueueWorkCount = 1u;
     uint32_t activeTiles = 1u;
@@ -266,7 +267,6 @@ class DirectSubmissionHw {
     bool ringStart = false;
     bool disableCpuCacheFlush = true;
     bool disableCacheFlush = false;
-    bool disableMonitorFence = false;
     bool partitionedMode = false;
     bool partitionConfigSet = true;
     bool miMemFenceRequired = false;
