@@ -14,7 +14,6 @@ const std::vector<unsigned short> adlpDeviceIds{
     0x46A0,
     0x46B0,
     0x46A1,
-    0x46A2,
     0x46A3,
     0x46A6,
     0x46A8,
@@ -23,11 +22,9 @@ const std::vector<unsigned short> adlpDeviceIds{
     0x4626,
     0x4628,
     0x46B1,
-    0x46B2,
     0x46B3,
     0x46C0,
     0x46C1,
-    0x46C2,
     0x46C3,
     0xA7A0,
     0xA720,
