@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022 Intel Corporation
+ * Copyright (C) 2022-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -10,11 +10,12 @@
 #include <vector>
 
 namespace NEO {
-inline const std::vector<unsigned short> adlsDeviceIds{
+const std::vector<unsigned short> adlsDeviceIds{
     0x4680,
     0x4682,
     0x4688,
     0x468A,
+    0x468B,
     0x4690,
     0x4692,
     0x4693,
@@ -24,6 +25,7 @@ inline const std::vector<unsigned short> adlsDeviceIds{
     0xA783,
     0xA788,
     0xA789,
+    0xA78A,
     0xA78B};
 
 } // namespace NEO
