@@ -9,7 +9,7 @@
 
 namespace NEO {
 
-uint64_t GmmResourceInfo::getDriverProtectionBits(uint32_t overrideUsage) {
+uint64_t GmmResourceInfo::getDriverProtectionBits(uint32_t overrideUsage, bool compressionDenied) {
     GMM_OVERRIDE_VALUES overrideValues{};
     if (GMM_RESOURCE_USAGE_UNKNOWN != overrideUsage) {
         overrideValues.Usage = overrideUsage;
@@ -17,6 +17,10 @@ uint64_t GmmResourceInfo::getDriverProtectionBits(uint32_t overrideUsage) {
     return static_cast<uint64_t>(resourceInfo->GetDriverProtectionBits(overrideValues));
 }
 
+bool GmmResourceInfo::isResourceDenyCompressionEnabled() {
+    return false;
+}
+
 bool GmmResourceInfo::isDisplayable() const {
     return false;
 }
