@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2022 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,7 +21,7 @@ bool operator==(const AlignmentSelector::CandidateAlignment &lhs, const Alignmen
 }
 
 void AlignmentSelector::addCandidateAlignment(size_t alignment, bool applyForSmallerSize, float maxMemoryWastage) {
-    this->addCandidateAlignment(alignment, applyForSmallerSize, maxMemoryWastage, HeapIndex::TOTAL_HEAPS);
+    this->addCandidateAlignment(alignment, applyForSmallerSize, maxMemoryWastage, HeapIndex::totalHeaps);
 }
 
 void AlignmentSelector::addCandidateAlignment(size_t alignment, bool applyForSmallerSize, float maxMemoryWastage, HeapIndex heap) {
@@ -42,11 +42,20 @@ void AlignmentSelector::addCandidateAlignment(size_t alignment, bool applyForSma
 }
 
 AlignmentSelector::CandidateAlignment AlignmentSelector::selectAlignment(size_t size) const {
+    constexpr size_t noAlignmentLimit = std::numeric_limits<size_t>::max();
+    return this->selectAlignment(size, noAlignmentLimit);
+}
+
+AlignmentSelector::CandidateAlignment AlignmentSelector::selectAlignment(size_t size, size_t maximumPossibleAlignment) const {
     for (const CandidateAlignment &candidateAlignment : this->candidateAlignments) {
         if (!candidateAlignment.applyForSmallerSize && size < candidateAlignment.alignment) {
             continue;
         }
 
+        if (candidateAlignment.alignment > maximumPossibleAlignment) {
+            continue;
+        }
+
         const size_t alignedSize = alignUp(size, candidateAlignment.alignment);
         const size_t wastedMemory = alignedSize - size;
         const size_t maxWastedMemory = static_cast<size_t>(alignedSize * candidateAlignment.maxMemoryWastage);
