@@ -12,8 +12,8 @@
 namespace NEO {
 
 void MemoryAllocation::overrideMemoryPool(MemoryPool pool) {
-    if (DebugManager.flags.AUBDumpForceAllToLocalMemory.get()) {
-        this->memoryPool = MemoryPool::LocalMemory;
+    if (debugManager.flags.AUBDumpForceAllToLocalMemory.get()) {
+        this->memoryPool = MemoryPool::localMemory;
         return;
     }
     this->memoryPool = pool;
